/*****************************************************************************
 *  Rohde&Schwarz CMW500 Wideband Radio Communication Tester instrument driver
 *  1xEVDO Measurements
 *  VXIpnp Instrument Driver
 *****************************************************************************/

#ifndef __RSCMWEVM_HEADER
#define __RSCMWEVM_HEADER

#include "rsidr_core.h"
#include "rscmwevm_attributes.h"
#include "rscmwevm_utility.h"

#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*
bit - meaning
-------------
0 - Unused
1 - Unused
_2_ - Error queue not empty
3 - Questionable status sum
_4_ - Message available
_5_ - ESB (see ESE mask)
6 - Master status summary
7 - Operation status sum
*/
#define IEEE_488_2_SRE_MASK             0x24   /* 488.2 Event Status Register (ESR) Bits */
#define IEEE_488_2_ERROR_MASK           0x4    /* 488.2 Error queue not empty bit mask */
/*
bit - meaning
-------------
_0_ - Operation Complete
1 - Unused
_2_ - Query Error
_3_ - Device-dependent Error
_4_ - Execution Error
_5_ - Command Error
6 - User Request
7 - Power On
*/
#define IEEE_488_2_ESE_MASK               0x3D    /* 488.2 Event Status Register (ESE) Bits */

/****************************************************************************
 *----------------- Instrument Driver Revision Information -----------------*
 ****************************************************************************/

/* Class Driver Identification */

#define RSCMWEVM_CLASS_DRIVER_DESCRIPTION           ""
#define RSCMWEVM_CLASS_DRIVER_PREFIX                ""
#define RSCMWEVM_CLASS_DRIVER_VENDOR                ""
#define RSCMWEVM_CLASS_DRIVER_REVISION              ""
#define RSCMWEVM_CLASS_SPEC_MAJOR_VERSION           1L    /* Class specification major version */
#define RSCMWEVM_CLASS_SPEC_MINOR_VERSION           0L    /* Class specification minor version */

/* Driver Identification */

#define RSCMWEVM_SPECIFIC_DRIVER_DESCRIPTION        ""
#define RSCMWEVM_SPECIFIC_DRIVER_PREFIX             "RSCMWEVM"
#define RSCMWEVM_SPECIFIC_DRIVER_LOCATOR            ""
#define RSCMWEVM_SPECIFIC_DRIVER_VENDOR             ""
#define RSCMWEVM_MAJOR_VERSION                      3L    /* Instrument driver major version          */
#define RSCMWEVM_MINOR_VERSION                      7L    /* Instrument driver minor version          */
#define RSCMWEVM_MINOR_MINOR_VERSION                100L   /* Instrument driver minor minor version    */

/* Driver Capabilities */          

#define RSCMWEVM_SUPPORTED_INSTRUMENT_MODELS        ""    /* Instrument driver supported model(s)     */
#define RSCMWEVM_GROUP_CAPABILITIES                 ""
#define RSCMWEVM_FUNCTION_CAPABILITIES              ""

/****************************************************************************
 *------------------------------ Useful Macros -----------------------------*
 ****************************************************************************/

/*****************************************************************************
 *- Useful Macros & Constants -----------------------------------------------*
 *****************************************************************************/

#define RSCMWEVM_SIMULATION_ID_QUERY      "Rohde&Schwarz,CMW,123456/789,1.23"  /* Default definition of ID Query Response for simulation */
#define RSCMWEVM_VALID_ID_RESPONSE_STRING "Rohde&Schwarz"      /* Valid response for identification query */
#define RSCMWEVM_SIMULATION_OPT_QUERY     ""      /* Simulated response for *OPT? command */

#define RSCMWEVM_IO_BUFFER_SIZE           1024L   /* I/O buffer size */
#define RSCMWEVM_OPC_TIMEOUT              5000L   /* Maximum time to wait for OPC in milliseconds */
//#define IEEE_488_2_ERROR_MASK             0x3C    /* 488.2 Event Status Register (ESR) Bits */
#define IEEE_488_2_ERROR_MASK             0x4    /* 488.2 STB Bits */   
#define IEEE_488_2_ESE_MASK               0x3D    /* 488.2 Event Status Register (ESE) Bits */

/****************************************************************************
 *---------------------------- Attribute Defines ---------------------------*
 ****************************************************************************/

    /*- Inherent Instrument Specific Attributes ----------------------------*/

        /* User Options */

#define RSCMWEVM_ATTR_RANGE_CHECK                                           RS_ATTR_RANGE_CHECK                                     /* ViBoolean */
#define RSCMWEVM_ATTR_QUERY_INSTRUMENT_STATUS                               RS_ATTR_QUERY_INSTRUMENT_STATUS                         /* ViBoolean */
#define RSCMWEVM_ATTR_CACHE                                                 RS_ATTR_CACHE                                           /* ViBoolean */
#define RSCMWEVM_ATTR_SIMULATE                                              RS_ATTR_SIMULATE                                        /* ViBoolean */
#define RSCMWEVM_ATTR_RECORD_COERCIONS                                      RS_ATTR_RECORD_COERCIONS                                /* ViBoolean */
#define RSCMWEVM_ATTR_INTERCHANGE_CHECK                                     RS_ATTR_INTERCHANGE_CHECK                               /* ViBoolean */
#define RSCMWEVM_ATTR_SPY                                                   RS_ATTR_SPY                                             /* ViBoolean */
#define RSCMWEVM_ATTR_USE_SPECIFIC_SIMULATION                               RS_ATTR_USE_SPECIFIC_SIMULATION                         /* ViBoolean */

        /* Class Driver Identification */

#define RSCMWEVM_ATTR_CLASS_DRIVER_DESCRIPTION                              RS_ATTR_CLASS_DRIVER_DESCRIPTION                        /* ViString, read-only */
#define RSCMWEVM_ATTR_CLASS_DRIVER_PREFIX                                   RS_ATTR_CLASS_DRIVER_PREFIX                             /* ViString, read-only */
#define RSCMWEVM_ATTR_CLASS_DRIVER_VENDOR                                   RS_ATTR_CLASS_DRIVER_VENDOR                             /* ViString, read-only */
#define RSCMWEVM_ATTR_CLASS_DRIVER_REVISION                                 RS_ATTR_CLASS_DRIVER_REVISION                           /* ViString, read-only */
#define RSCMWEVM_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION           /* ViInt32,  read-only */
#define RSCMWEVM_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION           /* ViInt32,  read-only */

        /* Driver Identification */

#define RSCMWEVM_ATTR_SPECIFIC_DRIVER_DESCRIPTION                           RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                     /* ViString, read-only */   
#define RSCMWEVM_ATTR_SPECIFIC_DRIVER_PREFIX                                RS_ATTR_SPECIFIC_DRIVER_PREFIX                          /* ViString, read-only */
#define RSCMWEVM_ATTR_SPECIFIC_DRIVER_LOCATOR                               RS_ATTR_SPECIFIC_DRIVER_LOCATOR                         /* ViString, read-only */
#define RSCMWEVM_ATTR_SPECIFIC_DRIVER_VENDOR                                RS_ATTR_SPECIFIC_DRIVER_VENDOR                          /* ViString, read-only */
#define RSCMWEVM_ATTR_SPECIFIC_DRIVER_REVISION                              RS_ATTR_SPECIFIC_DRIVER_REVISION                        /* ViString, read-only */
#define RSCMWEVM_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION        /* ViInt32,  read-only */
#define RSCMWEVM_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION        /* ViInt32,  read-only */

        /* Driver Capabilities */

#define RSCMWEVM_ATTR_SUPPORTED_INSTRUMENT_MODELS                           RS_ATTR_SUPPORTED_INSTRUMENT_MODELS                     /* ViString, read-only */
#define RSCMWEVM_ATTR_GROUP_CAPABILITIES                                    RS_ATTR_GROUP_CAPABILITIES                              /* ViString, read-only */
#define RSCMWEVM_ATTR_FUNCTION_CAPABILITIES                                 RS_ATTR_FUNCTION_CAPABILITIES                           /* ViString, read-only */
#define RSCMWEVM_ATTR_CHANNEL_COUNT                                         RS_ATTR_CHANNEL_COUNT                                   /* ViInt32,  read-only */

        /* Driver Setup */

#define RSCMWEVM_ATTR_DRIVER_SETUP                                          RS_ATTR_DRIVER_SETUP                                    /* ViString            */

        /* Instrument Identification */

#define RSCMWEVM_ATTR_INSTRUMENT_MANUFACTURER                               RS_ATTR_INSTRUMENT_MANUFACTURER                         /* ViString, read-only */
#define RSCMWEVM_ATTR_INSTRUMENT_MODEL                                      RS_ATTR_INSTRUMENT_MODEL                                /* ViString, read-only */
#define RSCMWEVM_ATTR_INSTRUMENT_FIRMWARE_REVISION                          RS_ATTR_INSTRUMENT_FIRMWARE_REVISION                    /* ViString, read-only */

        /* Advanced Session Information */

#define RSCMWEVM_ATTR_IO_RESOURCE_DESCRIPTOR                                RS_ATTR_IO_RESOURCE_DESCRIPTOR                          /* ViString, read-only */
#define RSCMWEVM_ATTR_LOGICAL_NAME                                          RS_ATTR_LOGICAL_NAME                                    /* ViString, read-only */

    /*- Instrument-Specific Attributes -------------------------------------*/

/* BEGIN GENERATE */  
#define RSCMWEVM_ATTR_INPUT_EXTERNAL_ATTENUTATION                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2
#define RSCMWEVM_ATTR_INPUT_COMBINED_SIGNAL_PATH_SCENARIO                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 3
#define RSCMWEVM_ATTR_MEASURE_PROTOCOL_TEST                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4
#define RSCMWEVM_ATTR_ANALYZER_EXPECTED_NOMINAL_POWER                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 5
#define RSCMWEVM_ATTR_ANALYZER_USER_MARGIN                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 6
#define RSCMWEVM_ATTR_ANALYZER_CENTER_FREQUENCY                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 7
#define RSCMWEVM_ATTR_ANALYZER_BAND_CLASS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 8
#define RSCMWEVM_ATTR_ANALYZER_CHANNEL                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 9
#define RSCMWEVM_ATTR_ANALYZER_FREQUENCY_OFFSET                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 10
#define RSCMWEVM_ATTR_ANALYZER_REMOTE_DISPLAY                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 68
#define RSCMWEVM_ATTR_MULTI_EVAL_MEASUREMENT_CODE_CHANNEL_FILTER            RS_SPECIFIC_PUBLIC_ATTR_BASE + 12
#define RSCMWEVM_ATTR_MULTI_EVAL_MEASUREMENT_CODE_CHANNEL_ACK_DSC_FILTER    RS_SPECIFIC_PUBLIC_ATTR_BASE + 13
#define RSCMWEVM_ATTR_MULTI_EVAL_MEASUREMENT_CODE_CHANNEL_HALF_SLOT         RS_SPECIFIC_PUBLIC_ATTR_BASE + 14
#define RSCMWEVM_ATTR_MULTI_EVAL_MEASUREMENT_DATA_CHANNEL_MODULATION_TYPE   RS_SPECIFIC_PUBLIC_ATTR_BASE + 15
#define RSCMWEVM_ATTR_MULTI_EVAL_MEASUREMENT_RESULT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 16
#define RSCMWEVM_ATTR_MULTI_EVAL_MEASUREMENT_REPETITION_MODE                RS_SPECIFIC_PUBLIC_ATTR_BASE + 17
#define RSCMWEVM_ATTR_MULTI_EVAL_MEASUREMENT_STOP_CONDITION                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 18
#define RSCMWEVM_ATTR_MULTI_EVAL_MEASUREMENT_RESULTS_REJECTION              RS_SPECIFIC_PUBLIC_ATTR_BASE + 19
#define RSCMWEVM_ATTR_MULTI_EVAL_MEASUREMENT_IQ_CROSS_CHECK                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 20
#define RSCMWEVM_ATTR_MULTI_EVAL_MEASUREMENT_PHYSICAL_LAYER_SUBTYPE         RS_SPECIFIC_PUBLIC_ATTR_BASE + 21
#define RSCMWEVM_ATTR_MULTI_EVAL_MEASUREMENT_REF_POWER_MODE                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 53
#define RSCMWEVM_ATTR_QUERY_MULTI_EVAL_MEASUREMENT_SPREADING_FACTOR         RS_SPECIFIC_PUBLIC_ATTR_BASE + 22
#define RSCMWEVM_ATTR_MULTI_EVAL_MEASUREMENT_STATISTIC_COUNT                RS_SPECIFIC_PUBLIC_ATTR_BASE + 23
#define RSCMWEVM_ATTR_MULTI_EVAL_MEASUREMENT_TIMEOUT                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 45
#define RSCMWEVM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_SOURCE                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 24
#define RSCMWEVM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_SLOPE                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 25
#define RSCMWEVM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_THRESHOLD              RS_SPECIFIC_PUBLIC_ATTR_BASE + 26
#define RSCMWEVM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_TIMEOUT                RS_SPECIFIC_PUBLIC_ATTR_BASE + 27
#define RSCMWEVM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_GAP                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 46
#define RSCMWEVM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_DELAY                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 73
#define RSCMWEVM_ATTR_MULTI_EVAL_MEASUREMENT_LIST_MODE_SEGMENT_CMWS_CONNECTOR RS_SPECIFIC_PUBLIC_ATTR_BASE + 72
#define RSCMWEVM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_OFFSET                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 56
#define RSCMWEVM_ATTR_MULTI_EVAL_LIST_MODE_STATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 50
#define RSCMWEVM_ATTR_MULTI_EVAL_LIST_MODE_COUNT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 51
#define RSCMWEVM_ATTR_MULTI_EVAL_RETRIGGER_MODE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 52
#define RSCMWEVM_ATTR_MULTI_EVAL_MEASUREMENT_INIT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 28
#define RSCMWEVM_ATTR_MULTI_EVAL_MEASUREMENT_ABORT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 29
#define RSCMWEVM_ATTR_MULTI_EVAL_MEASUREMENT_STOP                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 30
#define RSCMWEVM_ATTR_MULTI_EVAL_MEASUREMENT_CODE_DOMAIN_LIMIT              RS_SPECIFIC_PUBLIC_ATTR_BASE + 31
#define RSCMWEVM_ATTR_MULTI_EVAL_MEASUREMENT_CDP_IQ_LEAKAGE_CHECK           RS_SPECIFIC_PUBLIC_ATTR_BASE + 32
#define RSCMWEVM_ATTR_MULTI_EVAL_MEASUREMENT_OBW_LIMIT_CHECK                RS_SPECIFIC_PUBLIC_ATTR_BASE + 54
#define RSCMWEVM_ATTR_MULTI_EVAL_MEASUREMENT_OBW_USED_LIMIT_SET             RS_SPECIFIC_PUBLIC_ATTR_BASE + 55
#define RSCMWEVM_ATTR_MULTI_EVAL_MEASUREMENT_UPPER_CP_LIMIT                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 48
#define RSCMWEVM_ATTR_MULTI_EVAL_MEASUREMENT_CODE_DWCP_LIMIT                RS_SPECIFIC_PUBLIC_ATTR_BASE + 49
#define RSCMWEVM_ATTR_MULTI_EVAL_SWITCH_CARRIER                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 33
#define RSCMWEVM_ATTR_MULTI_EVAL_FREQUENCY_CARRIER                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 34
#define RSCMWEVM_ATTR_MULTI_EVAL_OFFSET_CARRIER                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 35
#define RSCMWEVM_ATTR_MULTI_EVAL_SELECT_CARRIER                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 36
#define RSCMWEVM_ATTR_MULTI_EVAL_SETTING_CARRIER                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 37
#define RSCMWEVM_ATTR_MULTI_EVAL_BAND_WIDTH_FILTER_CARRIER                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 38
#define RSCMWEVM_ATTR_OLTR_MEASUREMENT_TIMEOUT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 57
#define RSCMWEVM_ATTR_OLTR_MEASUREMENT_NUMBER_OF_SEQUENCES                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 58
#define RSCMWEVM_ATTR_OLTR_MEASUREMENT_POWER_STEP_DIRECTION                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 59
#define RSCMWEVM_ATTR_OLTR_MEASUREMENT_POWER_STEP                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 60
#define RSCMWEVM_ATTR_OLTR_MEASUREMENT_REF_POWER_INTERVAL                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 61
#define RSCMWEVM_ATTR_OLTR_MEASUREMENT_GUARD_INTERVAL                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 62
#define RSCMWEVM_ATTR_OLTR_MEASUREMENT_RESULTS_REJECTION                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 69
#define RSCMWEVM_ATTR_OLTR_MEASUREMENT_REF_POWER_INTERVAL_TIME              RS_SPECIFIC_PUBLIC_ATTR_BASE + 63
#define RSCMWEVM_ATTR_OLTR_MEASUREMENT_GUARD_INTERVAL_TIME                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 70
#define RSCMWEVM_ATTR_OLTR_MEASUREMENT_REPETITION                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 64
#define RSCMWEVM_ATTR_OLTR_MEASUREMENT_INIT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 65
#define RSCMWEVM_ATTR_OLTR_MEASUREMENT_ABORT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 66
#define RSCMWEVM_ATTR_OLTR_MEASUREMENT_STOP                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 67
#define RSCMWEVM_ATTR_OLTR_MEASUREMENT_LIMITS_ILOWER                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 71
#define RSCMWEVM_ATTR_SYSTEM_VERSION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 39
#define RSCMWEVM_ATTR_SYSTEM_ERROR                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 40
#define RSCMWEVM_ATTR_SYSTEM_ALL_ERRORS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 41
#define RSCMWEVM_ATTR_SYSTEM_PRESET                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 42
#define RSCMWEVM_ATTR_PROCESS_ALL_PREVIOUS_COMMANDS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 74
#define RSCMWEVM_ATTR_ID_QUERY_RESPONSE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 43

// rscmwevm_rngRepMode
#define RSCMWEVM_VAL_REPETITION_SINGLE                                      0
#define RSCMWEVM_VAL_REPETITION_CONT                                        1

// rscmwevm_rngStopCond
#define RSCMWEVM_VAL_NONE                                                   0
#define RSCMWEVM_VAL_LIM_FAIL                                               1

// rscmwevm_rngTrigSlope
#define RSCMWEVM_VAL_TRIGSLOPE_RISING                                       0
#define RSCMWEVM_VAL_TRIGSLOPE_FALLING                                      1

// rscmwevm_rngChannelFilter
#define RSCMWEVM_VAL_FILTER_OFF                                             0
#define RSCMWEVM_VAL_FILTER_ON                                              1
#define RSCMWEVM_VAL_FILTER_DNC                                             2

// rscmwevm_rngChannelACKFilter
#define RSCMWEVM_VAL_FILTER_ACK_OFF                                         0
#define RSCMWEVM_VAL_FILTER_ACK_DSC                                         1
#define RSCMWEVM_VAL_FILTER_ACK_ACK                                         2
#define RSCMWEVM_VAL_FILTER_ACK_DNC                                         3

// rscmwevm_rngHalfSlot
#define RSCMWEVM_VAL_HSLOT_BOTH                                             0
#define RSCMWEVM_VAL_HSLOT_FIRST                                            1
#define RSCMWEVM_VAL_HSLOT_SECOND                                           2

// rscmwevm_rngDataModulationType
#define RSCMWEVM_VAL_DATA_MOD_AUTO                                          0
#define RSCMWEVM_VAL_DATA_MOD_B4                                            1
#define RSCMWEVM_VAL_DATA_MOD_Q4                                            2
#define RSCMWEVM_VAL_DATA_MOD_Q2                                            3
#define RSCMWEVM_VAL_DATA_MOD_Q4Q2                                          4
#define RSCMWEVM_VAL_DATA_MOD_E4E2                                          5

// rscmwevm_rngPLayerSubtype
#define RSCMWEVM_VAL_PLAYER_SUBTYPE_01                                      0
#define RSCMWEVM_VAL_PLAYER_SUBTYPE_2                                       1

// rscmwevm_rngBandClass
#define RSCMWEVM_VAL_BAND_USC                                               0
#define RSCMWEVM_VAL_BAND_KCEL                                              1
#define RSCMWEVM_VAL_BAND_NAPC                                              3
#define RSCMWEVM_VAL_BAND_TACS                                              4
#define RSCMWEVM_VAL_BAND_JTAC                                              5
#define RSCMWEVM_VAL_BAND_KPCS                                              6
#define RSCMWEVM_VAL_BAND_N45T                                              7
#define RSCMWEVM_VAL_BAND_IM2K                                              8
#define RSCMWEVM_VAL_BAND_NA7C                                              9
#define RSCMWEVM_VAL_BAND_B18M                                              10
#define RSCMWEVM_VAL_BAND_NA9C                                              11
#define RSCMWEVM_VAL_BAND_NA8S                                              12
#define RSCMWEVM_VAL_BAND_PA4M                                              13
#define RSCMWEVM_VAL_BAND_PA8M                                              14
#define RSCMWEVM_VAL_BAND_IEXT                                              15
#define RSCMWEVM_VAL_BAND_USPC                                              16
#define RSCMWEVM_VAL_BAND_AWS                                               17
#define RSCMWEVM_VAL_BAND_U25B                                              18
#define RSCMWEVM_VAL_BAND_PS7C                                              19
#define RSCMWEVM_VAL_BAND_LO7C                                              20
#define RSCMWEVM_VAL_BAND_LBAN                                              21
#define RSCMWEVM_VAL_BAND_SBAN                                              22

// rscmwevm_rngCarrierBandWidth
#define RSCMWEVM_VAL_CARRIER_BANDWIDTH_F8M0                                 0
#define RSCMWEVM_VAL_CARRIER_BANDWIDTH_F16M0                                1

// rscmwevm_rngSpreadingFactor
#define RSCMWEVM_VAL_SFACTOR_16                                             0
#define RSCMWEVM_VAL_SFACTOR_32                                             1

// rscmwevm_rngRetriggMode
#define RSCMWEVM_VAL_LIST_RETRIGGER_MODE_ONCE                               0
#define RSCMWEVM_VAL_LIST_RETRIGGER_MODE_SEGM                               1

// rscmwevm_rngPowerMode
#define RSCMWEVM_VAL_AT_POWER                                               0
#define RSCMWEVM_VAL_PILOT_POWER                                            1

// rscmwevm_rngObwUsedLimit
#define RSCMWEVM_VAL_OBW_LIMIT_SET_A                                        0
#define RSCMWEVM_VAL_OBW_LIMIT_SET_B                                        1

// rscmwevm_rngOLTRStepDirection
#define RSCMWEVM_VAL_OLTR_DOWN                                              0
#define RSCMWEVM_VAL_OLTR_UP                                                1

// rscmwevm_rngOLTRRepetition
#define RSCMWEVM_VAL_OLTR_REPETITION_SINGLE                                 0
#define RSCMWEVM_VAL_OLTR_REPETITION_CONT                                   1

// rscmwevm_rngRemoteDisplay
#define RSCMWEVM_VAL_REMOTE_DISPLAY_MEV                                     0
#define RSCMWEVM_VAL_REMOTE_DISPLAY_OLTR                                    1

// rscmwevm_rngMultiEvalMeasurementListSegmentCMWSConnector
#define RSCMWEVM_VAL_ANALYZER_CONN_R11                                      0
#define RSCMWEVM_VAL_ANALYZER_CONN_R12                                      1
#define RSCMWEVM_VAL_ANALYZER_CONN_R13                                      2
#define RSCMWEVM_VAL_ANALYZER_CONN_R14                                      3
#define RSCMWEVM_VAL_ANALYZER_CONN_R15                                      4
#define RSCMWEVM_VAL_ANALYZER_CONN_R16                                      5
#define RSCMWEVM_VAL_ANALYZER_CONN_R17                                      6
#define RSCMWEVM_VAL_ANALYZER_CONN_R18                                      7
#define RSCMWEVM_VAL_ANALYZER_CONN_R21                                      8
#define RSCMWEVM_VAL_ANALYZER_CONN_R22                                      9
#define RSCMWEVM_VAL_ANALYZER_CONN_R23                                      10
#define RSCMWEVM_VAL_ANALYZER_CONN_R24                                      11
#define RSCMWEVM_VAL_ANALYZER_CONN_R25                                      12
#define RSCMWEVM_VAL_ANALYZER_CONN_R26                                      13
#define RSCMWEVM_VAL_ANALYZER_CONN_R27                                      14
#define RSCMWEVM_VAL_ANALYZER_CONN_R28                                      15
#define RSCMWEVM_VAL_ANALYZER_CONN_R31                                      16
#define RSCMWEVM_VAL_ANALYZER_CONN_R32                                      17
#define RSCMWEVM_VAL_ANALYZER_CONN_R33                                      18
#define RSCMWEVM_VAL_ANALYZER_CONN_R34                                      19
#define RSCMWEVM_VAL_ANALYZER_CONN_R35                                      20
#define RSCMWEVM_VAL_ANALYZER_CONN_R36                                      21
#define RSCMWEVM_VAL_ANALYZER_CONN_R37                                      22
#define RSCMWEVM_VAL_ANALYZER_CONN_R38                                      23
#define RSCMWEVM_VAL_ANALYZER_CONN_R41                                      24
#define RSCMWEVM_VAL_ANALYZER_CONN_R42                                      25
#define RSCMWEVM_VAL_ANALYZER_CONN_R43                                      26
#define RSCMWEVM_VAL_ANALYZER_CONN_R44                                      27
#define RSCMWEVM_VAL_ANALYZER_CONN_R45                                      28
#define RSCMWEVM_VAL_ANALYZER_CONN_R46                                      29
#define RSCMWEVM_VAL_ANALYZER_CONN_R47                                      30
#define RSCMWEVM_VAL_ANALYZER_CONN_R48                                      31
#define RSCMWEVM_VAL_ANALYZER_CONN_RA1                                      32
#define RSCMWEVM_VAL_ANALYZER_CONN_RA2                                      33
#define RSCMWEVM_VAL_ANALYZER_CONN_RA3                                      34
#define RSCMWEVM_VAL_ANALYZER_CONN_RA4                                      35
#define RSCMWEVM_VAL_ANALYZER_CONN_RA5                                      36
#define RSCMWEVM_VAL_ANALYZER_CONN_RA6                                      37
#define RSCMWEVM_VAL_ANALYZER_CONN_RA7                                      38
#define RSCMWEVM_VAL_ANALYZER_CONN_RA8                                      39
#define RSCMWEVM_VAL_ANALYZER_CONN_RB1                                      40
#define RSCMWEVM_VAL_ANALYZER_CONN_RB2                                      41
#define RSCMWEVM_VAL_ANALYZER_CONN_RB3                                      42
#define RSCMWEVM_VAL_ANALYZER_CONN_RB4                                      43
#define RSCMWEVM_VAL_ANALYZER_CONN_RB5                                      44
#define RSCMWEVM_VAL_ANALYZER_CONN_RB6                                      45
#define RSCMWEVM_VAL_ANALYZER_CONN_RB7                                      46
#define RSCMWEVM_VAL_ANALYZER_CONN_RB8                                      47
/* END GENERATE */  

/*****************************************************************************
 *- Hidden Attribute Declarations -------------------------------------------*
 *****************************************************************************/

#define RSCMWEVM_ATTR_OPC_TIMEOUT               (RS_ATTR_OPC_TIMEOUT)           /* ViInt32 */
#define RSCMWEVM_ATTR_IO_SESSION                (RS_ATTR_IO_SESSION)            /* ViSession */
#define RSCMWEVM_ATTR_OPC_CALLBACK              (RS_ATTR_OPC_CALLBACK)          /* ViAddr */
#define RSCMWEVM_ATTR_CHECK_STATUS_CALLBACK     (RS_ATTR_CHECK_STATUS_CALLBACK) /* ViAddr */

/****************************************************************************
 *------------------------ Attribute Value Defines -------------------------*
 ****************************************************************************/

    /*- Instrument specific attribute value definitions --------------------*/
#define RSCMWEVM_VAL_RES_EVM  0
#define RSCMWEVM_VAL_RES_MERR 1
#define RSCMWEVM_VAL_RES_PERR 2
#define RSCMWEVM_VAL_RES_ACP  3
#define RSCMWEVM_VAL_RES_CDP  4
#define RSCMWEVM_VAL_RES_CDE  5
#define RSCMWEVM_VAL_RES_POW  6
#define RSCMWEVM_VAL_RES_TXM  7
#define RSCMWEVM_VAL_RES_MODQ 8
#define RSCMWEVM_VAL_RES_CP   9
#define RSCMWEVM_VAL_RES_OBW  10
    
#define RSCMWEVM_VAL_RESULT_CURRENT 0
#define RSCMWEVM_VAL_RESULT_AVERAGE 1
#define RSCMWEVM_VAL_RESULT_MAX     2
#define RSCMWEVM_VAL_RESULT_EXTREME 2
#define RSCMWEVM_VAL_RESULT_MIN     3

#define RSCMWEVM_VAL_TYPE_RMS  0
#define RSCMWEVM_VAL_TYPE_PEAK 1

#define RSCMWEVM_VAL_POWER_MIN 0
#define RSCMWEVM_VAL_POWER_MAX 1

#define RSCMWEVM_VAL_TYPE_LEFT  0
#define RSCMWEVM_VAL_TYPE_RIGHT 1
#define RSCMWEVM_VAL_TYPE_KFILT 2

#define RSCMWEVM_VAL_DOMAIN_POWER  0
#define RSCMWEVM_VAL_DOMAIN_ERROR  1

#define RSCMWEVM_VAL_TYPE_DPCCH  0
#define RSCMWEVM_VAL_TYPE_DPDCH  1   
    
#define RSCMWEVM_VAL_TYPE_ISIG  0
#define RSCMWEVM_VAL_TYPE_QSIG  1
#define RSCMWEVM_VAL_TYPE_INV   2    

#define RSCMWEVM_VAL_MOD      0
#define RSCMWEVM_VAL_SPECTRUM 1

#define RSCMWEVM_VAL_STATE_OFF 0
#define RSCMWEVM_VAL_STATE_ON  1
#define RSCMWEVM_VAL_STATE_VAL 2
    
#define RSCMWEVM_VAL_CARRIER_0  0
#define RSCMWEVM_VAL_CARRIER_1  1
#define RSCMWEVM_VAL_CARRIER_2  2
    
#define RSCMWEVM_VAL_LIM_OK     0
#define RSCMWEVM_VAL_LIM_ULEU   1
#define RSCMWEVM_VAL_LIM_ULEL   2
    
#define RSCMWEVM_VAL_ANALYZER_SAL_CONV_RX1  0
#define RSCMWEVM_VAL_ANALYZER_SAL_CONV_RX2  1 
#define RSCMWEVM_VAL_ANALYZER_SAL_CONV_RX3  2
#define RSCMWEVM_VAL_ANALYZER_SAL_CONV_RX4  3
#define RSCMWEVM_VAL_ANALYZER_SAL_CONV_RX11 4
#define RSCMWEVM_VAL_ANALYZER_SAL_CONV_RX12 5 
#define RSCMWEVM_VAL_ANALYZER_SAL_CONV_RX13 6
#define RSCMWEVM_VAL_ANALYZER_SAL_CONV_RX14 7
#define RSCMWEVM_VAL_ANALYZER_SAL_CONV_RX21 8
#define RSCMWEVM_VAL_ANALYZER_SAL_CONV_RX22 9 
#define RSCMWEVM_VAL_ANALYZER_SAL_CONV_RX23 10
#define RSCMWEVM_VAL_ANALYZER_SAL_CONV_RX24 11
#define RSCMWEVM_VAL_ANALYZER_SAL_CONV_RX31 12
#define RSCMWEVM_VAL_ANALYZER_SAL_CONV_RX32 13 
#define RSCMWEVM_VAL_ANALYZER_SAL_CONV_RX33 14
#define RSCMWEVM_VAL_ANALYZER_SAL_CONV_RX34 15
#define RSCMWEVM_VAL_ANALYZER_SAL_CONV_RX41 16
#define RSCMWEVM_VAL_ANALYZER_SAL_CONV_RX42 17 
#define RSCMWEVM_VAL_ANALYZER_SAL_CONV_RX43 18
#define RSCMWEVM_VAL_ANALYZER_SAL_CONV_RX44 19
        
#define RSCMWEVM_VAL_ANALYZER_CONN_RF1C 0
#define RSCMWEVM_VAL_ANALYZER_CONN_RF2C 1
#define RSCMWEVM_VAL_ANALYZER_CONN_RF3C 2
#define RSCMWEVM_VAL_ANALYZER_CONN_RF4C 3
#define RSCMWEVM_VAL_ANALYZER_CONN_RFAC 4
#define RSCMWEVM_VAL_ANALYZER_CONN_RFBC 5
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R11  6
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R12  7
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R13  8
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R14  9
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R15  10
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R16  11
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R17  12
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R18  13
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R21  14
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R22  15
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R23  16
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R24  17
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R25  18
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R26  19
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R27  20
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R28  21
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R31  22
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R32  23
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R33  24
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R34  25
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R35  26
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R36  27
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R37  28
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R38  29
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_RA1  30
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_RA2  31
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_RA3  32
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_RA4  33
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_RA5  34
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_RA6  35
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_RA7  36
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_RA8  37
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_RB1  38
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_RB2  39
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_RB3  40
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_RB4  41
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R11C 42
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R12C 43
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R13C 44
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R14C 45
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R21C 46
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R22C 47
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R23C 48
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R24C 49
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R31C 50
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R32C 51
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R33C 52
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R34C 53
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R41C 54
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R42C 55
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R43C 56
#define RSCMWEVM_VAL_ANALYZER_CONNECTOR_R44C 57
    
#define RSCMWEVM_VAL_DOMAIN_POW_CP    0
#define RSCMWEVM_VAL_DOMAIN_POW_DWCP  1
    
#define RSCMWEVM_VAL_ST01  0
#define RSCMWEVM_VAL_ST2   1
    
#define RSCMWEVM_VAL_BOTH      0 
#define RSCMWEVM_VAL_FIRST     1
#define RSCMWEVM_VAL_SECOND    2
    
#define RSCMWEVM_VAL_FREQ_OFFSET_LOWER   0 
#define RSCMWEVM_VAL_FREQ_OFFSET_UPPER   1
    
#define RSCMWEVM_VAL_RESULT_SDEV	   4
#define RSCMWEVM_VAL_RESULT_MS_POW_MAX 5
#define RSCMWEVM_VAL_RESULT_MS_POW_MIN 6
	
#define RSCMWEVM_VAL_TYPE_MS_POWER_NARROW 0
#define RSCMWEVM_VAL_TYPE_MS_POWER_WIDE   1
	
#define RSCMWEVM_VAL_DIRECTION_ACPP 0
#define RSCMWEVM_VAL_DIRECTION_ACPM 1
	
#define RSCMWEVM_VAL_RESULT_CP_CHANNEL_RRI   0
#define RSCMWEVM_VAL_RESULT_CP_CHANNEL_PILOT 1
#define RSCMWEVM_VAL_RESULT_CP_CHANNEL_ADSC  2
#define RSCMWEVM_VAL_RESULT_CP_CHANNEL_APIL  3
#define RSCMWEVM_VAL_RESULT_CP_CHANNEL_DRC   4
#define RSCMWEVM_VAL_RESULT_CP_CHANNEL_DATA  5
	
#define RSCMWEVM_VAL_RESULT_LOW 0 
#define RSCMWEVM_VAL_RESULT_UPP 1
	
#define RSCMWEVM_VAL_RESULT_DWC_WOTI  0
#define RSCMWEVM_VAL_RESULT_DWC_WOTQ  1
#define RSCMWEVM_VAL_RESULT_DWC_WTFI  2
#define RSCMWEVM_VAL_RESULT_DWC_WTFQ  3
	
#define RSCMWEVM_VAL_OLTR_TRACE_TYPE_OLTR 0
#define RSCMWEVM_VAL_OLTR_TRACE_TYPE_RPOW 1
	
#define RSCMWEVM_VAL_RBW_F1K0  0
#define RSCMWEVM_VAL_RBW_F6K25 1
#define RSCMWEVM_VAL_RBW_F10K  2
#define RSCMWEVM_VAL_RBW_F12K5 3
#define RSCMWEVM_VAL_RBW_F25K  4
#define RSCMWEVM_VAL_RBW_F30K  5
#define RSCMWEVM_VAL_RBW_F50K  6
#define RSCMWEVM_VAL_RBW_F100k 7
#define RSCMWEVM_VAL_RBW_F1M0  8
#define RSCMWEVM_VAL_RBW_F1M23 9
	
#define RSCMWEVM_VAL_RETRIGGER_IFP 2
#define RSCMWEVM_VAL_RETRIGGER_IFPS 3
	
#define RSCMWEVM_VAL_FAST_SWEEP_NORMAL 0
#define RSCMWEVM_VAL_FAST_SWEEP_FAST   1
	
/****************************************************************************
 *---------------- Instrument Driver Function Declarations -----------------*
 ****************************************************************************/
ViStatus _VI_FUNC rscmwevm_init (ViRsrc resourceName, ViBoolean IDQuery,
                                 ViBoolean resetDevice,
                                 ViSession* instrumentHandle);
ViStatus _VI_FUNC rscmwevm_InitWithOptions (ViRsrc resourceName, ViBoolean IDQuery,
                                            ViBoolean resetDevice,
                                            ViString optionString,
                                            ViSession* instrumentHandle);
ViStatus _VI_FUNC rscmwevm_ConfigureAnalyzerCombinedSignalPathScenario
             (ViSession instrumentHandle, ViInt32 instance, ViString controlledBy);
ViStatus _VI_FUNC rscmwevm_QueryAnalyzerCombinedSignalPathCatalog
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViChar _VI_FAR catalog[]);
ViStatus _VI_FUNC rscmwevm_ConfigureAnalyzerStandAloneScenario
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 RXConnector,
              ViInt32 RFConverter);
ViStatus _VI_FUNC rscmwevm_AnalyzerMeasureProtocolTestScenario
             (ViSession instrumentHandle, ViInt32 instance);
ViStatus _VI_FUNC rscmwevm_QueryAnalyzerRoutingSettings (ViSession instrumentHandle,
                                                         ViInt32 instance,
                                                         ViInt32* scenario,
                                                         ViChar _VI_FAR controller[],
                                                         ViInt32* RXConnector,
                                                         ViInt32* RFConverter);
ViStatus _VI_FUNC rscmwevm_ConfigureAnalyzerExternalAttenuation
             (ViSession instrumentHandle, ViInt32 instance,
              ViReal64 externalAttenuation);
ViStatus _VI_FUNC rscmwevm_ConfigureAnalyzer (ViSession instrumentHandle,
                                              ViInt32 instance,
                                              ViReal64 expectedNominalPower,
                                              ViReal64 margin,
                                              ViReal64 centerFrequency);
ViStatus _VI_FUNC rscmwevm_ConfigureAnalyzerChannel (ViSession instrumentHandle,
                                                     ViInt32 instance, ViInt32 band,
                                                     ViInt32 channel);
ViStatus _VI_FUNC rscmwevm_ConfigureAnalyzerFrequencyOffset
             (ViSession instrumentHandle, ViInt32 instance,
              ViReal64 frequencyOffset);
ViStatus _VI_FUNC rscmwevm_ConfigureAnalyzerRemoteDisplay
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 tab);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalMeasCodeChannelFilter
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 DRC,
              ViInt32 ACKDSC, ViInt32 data, ViInt32 auxPilot, ViInt32 halfSlot);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalMeasACKChannelFilter
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 ACK);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalMeasDataChannelModulationType
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 modulationType);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalMeasStatistics (ViSession instrumentHandle,
                                                         ViInt32 instance,
                                                         ViInt32 repetition,
                                                         ViInt32 stopCondition);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalMeasStatisticsCount
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 measurement,
              ViInt32 statisticCount);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalMeasTimeout (ViSession instrumentHandle,
                                                      ViInt32 instance,
                                                      ViReal64 timeout);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalMeasResults (ViSession instrumentHandle,
                                                      ViInt32 instance,
                                                      ViInt32 measurement,
                                                      ViBoolean state);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalMeasParameters (ViSession instrumentHandle,
                                                         ViInt32 instance,
                                                         ViBoolean measureOnException);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalMeasCodeDomain (ViSession instrumentHandle,
                                                         ViInt32 instance,
                                                         ViString longCodeMaskI,
                                                         ViString longCodeMaskQ,
                                                         ViInt32 physicalLayerSubtype,
                                                         ViInt32 referencePowerMode);
ViStatus _VI_FUNC rscmwevm_QueryMEvalMeasSpreadingFactor (ViSession instrumentHandle,
                                                          ViInt32 instance,
                                                          ViInt32* spreadingFactor);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalMeasResultsAll (ViSession instrumentHandle,
                                                         ViInt32 instance,
                                                         ViInt32 arraySize,
                                                         ViBoolean _VI_FAR states[]);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalMeasTrigger (ViSession instrumentHandle,
                                                      ViInt32 instance,
                                                      ViString source,
                                                      ViInt32 slope,
                                                      ViReal64 threshold,
                                                      ViReal64 timeout);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalMeasurementTriggerGap
             (ViSession instrumentHandle, ViInt32 instance, ViReal64 minTriggerGap);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalMeasMinimumTriggerOffset
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 offset);
ViStatus _VI_FUNC rscmwevm_QueryMEvalMeasTriggerSourceCatalog
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViChar _VI_FAR catalog[]);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalSelectCarrier (ViSession instrumentHandle,
                                                        ViInt32 instance,
                                                        ViInt32 selectCarrier);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalCarrier (ViSession instrumentHandle,
                                                  ViInt32 instance, ViInt32 carrier,
                                                  ViBoolean enable, ViReal64 offset,
                                                  ViReal64 frequency,
                                                  ViInt32 bandwidth);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalACPFrequencyLowerOffset
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViBoolean _VI_FAR states[], ViReal64 _VI_FAR offsets[]);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalACPFrequencyUpperOffset
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViBoolean _VI_FAR states[], ViReal64 _VI_FAR offsets[]);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalACPFrequencyLowerRBW
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViInt32 _VI_FAR RBW[]);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalACPFrequencyUpperRBW
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViInt32 _VI_FAR RBW[]);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalACPFrequencyLowerOffsetExtended
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViBoolean _VI_FAR states[], ViReal64 _VI_FAR offsets[]);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalACPFrequencyUpperOffsetExtended
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViBoolean _VI_FAR states[], ViReal64 _VI_FAR offsets[]);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalACPFrequencyLowerRBWExtended
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViInt32 _VI_FAR RBW[]);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalACPFrequencyUpperRBWExtended
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViInt32 _VI_FAR RBW[]);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalMeasurementListModeState
             (ViSession instrumentHandle, ViInt32 instance, ViBoolean state);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalMeasurementListModeSegmentCount
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 measuredSegments);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalMeasListModeRetriggerMode
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 retriggerMode);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalMeasurementListModeSegmentConnector
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 segment,
              ViInt32 CMWSConnector);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalMeasurementListModeSegment
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 segment,
              ViInt32 segmentLength, ViReal64 nominalPower, ViReal64 frequency,
              ViBoolean retrigger, ViInt32 physicalLayerSubtype,
              ViInt32 evaluatedHalfSlot, ViString longCodeMaskI,
              ViString longCodeMaskQ);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalMeasurementListModeModulationResults
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 segment,
              ViInt32 statisticsLength, ViBoolean _VI_FAR measurementsState[]);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalMeasurementListModeSpectrumResults
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 segment,
              ViInt32 statisticsLength, ViBoolean ACPState,
              ViBoolean occupiedBandwidthState);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalLimitsModulation
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 modulationCharacteristic, ViInt32 type, ViReal64 limitValue,
              ViInt32 limitStatus);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalLimitsIQOffset (ViSession instrumentHandle,
                                                         ViInt32 instance,
                                                         ViReal64 limit,
                                                         ViInt32 limitStatus);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalLimitsIQImbalance
             (ViSession instrumentHandle, ViInt32 instance, ViReal64 limit,
              ViInt32 limitStatus);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalLimitsCarrierFrequencyError
             (ViSession instrumentHandle, ViInt32 instance, ViReal64 limit,
              ViInt32 limitStatus);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalLimitsTransportTimeError
             (ViSession instrumentHandle, ViInt32 instance, ViReal64 limit,
              ViInt32 limitStatus);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalLimitsWaveformQuality
             (ViSession instrumentHandle, ViInt32 instance, ViReal64 limit,
              ViInt32 limitStatus);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalLimitsPower (ViSession instrumentHandle,
                                                      ViInt32 instance,
                                                      ViInt32 power,
                                                      ViReal64 limitValue,
                                                      ViInt32 limitStatus);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalLimitsCodeDomain
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 codeDomain,
              ViReal64 limitValue, ViBoolean IQLeakageCheck);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalLimitsChannelPower
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 channelPower,
              ViReal64 limitValue);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalLimitsOBW (ViSession instrumentHandle,
                                                    ViInt32 instance,
                                                    ViReal64 limitValue,
                                                    ViInt32 limitStatus);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalLimitsOBWLimitSet
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 limitSet,
              ViReal64 oneIsolatedCarrier, ViReal64 twoAdjacentCarriers,
              ViReal64 threeAdjacentCarriers);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalLimitsOBWLimitCheck
             (ViSession instrumentHandle, ViInt32 instance,
              ViBoolean OBWLimitCheck);
ViStatus _VI_FUNC rscmwevm_QueryMEvalLimitsOBWUsedLimitSet
             (ViSession instrumentHandle, ViInt32 instance, ViInt32* limitSet);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalLimitsCarrierLower
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViBoolean _VI_FAR states[], ViReal64 _VI_FAR limits[]);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalLimitsCarrierUpper
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViBoolean _VI_FAR states[], ViReal64 _VI_FAR limits[]);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalLimitsCarrierLowerAbsolute
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViBoolean _VI_FAR states[], ViReal64 _VI_FAR limits[]);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalLimitsCarrierUpperAbsolute
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViBoolean _VI_FAR states[], ViReal64 _VI_FAR limits[]);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalLimitsCarrierLowerExtended
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViBoolean _VI_FAR states[], ViReal64 _VI_FAR limits[]);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalLimitsCarrierUpperExtended
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViBoolean _VI_FAR states[], ViReal64 _VI_FAR limits[]);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalLimitsCarrierLowerAbsoluteExtended
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViBoolean _VI_FAR states[], ViReal64 _VI_FAR limits[]);
ViStatus _VI_FUNC rscmwevm_ConfigureMEvalLimitsCarrierUpperAbsoluteExtended
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViBoolean _VI_FAR states[], ViReal64 _VI_FAR limits[]);
ViStatus _VI_FUNC rscmwevm_MEvalMeasInit (ViSession instrumentHandle,
                                          ViInt32 instance);
ViStatus _VI_FUNC rscmwevm_MEvalMeasAbort (ViSession instrumentHandle,
                                           ViInt32 instance);
ViStatus _VI_FUNC rscmwevm_MEvalMeasStop (ViSession instrumentHandle,
                                          ViInt32 instance);
ViStatus _VI_FUNC rscmwevm_QueryMEvalMeasurementStatus (ViSession instrumentHandle,
                                                        ViInt32 instance,
                                                        ViInt32* mainState,
                                                        ViInt32* syncState,
                                                        ViInt32* resourcesState);
ViStatus _VI_FUNC rscmwevm_ReadMEvalMeasEVMTrace (ViSession instrumentHandle,
                                                  ViInt32 instance,
                                                  ViInt32 resultType,
                                                  ViInt32 arraySize,
                                                  ViInt32* reliability,
                                                  ViReal64 _VI_FAR results[],
                                                  ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasEVMTrace (ViSession instrumentHandle,
                                                   ViInt32 instance,
                                                   ViInt32 resultType,
                                                   ViInt32 arraySize,
                                                   ViInt32* reliability,
                                                   ViReal64 _VI_FAR results[],
                                                   ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_ReadMEvalMeasMagnErrTrace (ViSession instrumentHandle,
                                                      ViInt32 instance,
                                                      ViInt32 resultType,
                                                      ViInt32 arraySize,
                                                      ViInt32* reliability,
                                                      ViReal64 _VI_FAR results[],
                                                      ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasMagnErrTrace (ViSession instrumentHandle,
                                                       ViInt32 instance,
                                                       ViInt32 resultType,
                                                       ViInt32 arraySize,
                                                       ViInt32* reliability,
                                                       ViReal64 _VI_FAR results[],
                                                       ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_ReadMEvalMeasPhaseErrTrace (ViSession instrumentHandle,
                                                       ViInt32 instance,
                                                       ViInt32 resultType,
                                                       ViInt32 arraySize,
                                                       ViInt32* reliability,
                                                       ViReal64 _VI_FAR results[],
                                                       ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasPhaseErrTrace (ViSession instrumentHandle,
                                                        ViInt32 instance,
                                                        ViInt32 resultType,
                                                        ViInt32 arraySize,
                                                        ViInt32* reliability,
                                                        ViReal64 _VI_FAR results[],
                                                        ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_ReadMEvalMeasIQTrace (ViSession instrumentHandle,
                                                 ViInt32 instance,
                                                 ViInt32 arraySize,
                                                 ViInt32* reliability,
                                                 ViReal64 _VI_FAR i[],
                                                 ViReal64 _VI_FAR q[],
                                                 ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasIQTrace (ViSession instrumentHandle,
                                                  ViInt32 instance,
                                                  ViInt32 arraySize,
                                                  ViInt32* reliability,
                                                  ViReal64 _VI_FAR i[],
                                                  ViReal64 _VI_FAR q[],
                                                  ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_ReadMEvalMeasCodeDomainRRITrace
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 resultType,
              ViInt32 codeDomain, ViInt32 type, ViInt32 arraySize,
              ViInt32* reliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasCodeDomainRRITrace
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 resultType,
              ViInt32 codeDomain, ViInt32 type, ViInt32 arraySize,
              ViInt32* reliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_QueryMEvalMeasCodeDomainRRITraceLimitsCheckResults
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 resultType,
              ViInt32 codeDomain, ViInt32 type, ViInt32 arraySize,
              ViInt32* reliability, ViInt32 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasCodeDomainRRITraceCheckLimit
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 codeDomain,
              ViInt32 type, ViInt32 arraySize, ViInt32* reliability,
              ViReal64 _VI_FAR results[], ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasCodeDomainRRITraceCheckStates
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 codeDomain,
              ViInt32 type, ViInt32 arraySize, ViInt32* reliability,
              ViInt32 _VI_FAR results[], ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_ReadMEvalMeasCodeDomainPilotTrace
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 resultType,
              ViInt32 codeDomain, ViInt32 type, ViInt32 arraySize,
              ViInt32* reliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasCodeDomainPilotTrace
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 resultType,
              ViInt32 codeDomain, ViInt32 type, ViInt32 arraySize,
              ViInt32* reliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_FetchMEvalMeasCodeDomainPilotTraceLimitsCheckResults
        (ViSession instrumentHandle, ViInt32 instance, ViInt32 resultType,
         ViInt32 codeDomain, ViInt32 type, ViInt32 arraySize, ViInt32* reliability,
         ViInt32 _VI_FAR results[], ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasCodeDomainPilotTraceCheckLimit
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 codeDomain,
              ViInt32 type, ViInt32 arraySize, ViInt32* reliability,
              ViReal64 _VI_FAR results[], ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasCodeDomainPilotTraceCheckStates
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 codeDomain,
              ViInt32 type, ViInt32 arraySize, ViInt32* reliability,
              ViInt32 _VI_FAR results[], ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_ReadMEvalMeasACPTrace (ViSession instrumentHandle,
                                                  ViInt32 instance,
                                                  ViInt32 resultType,
                                                  ViInt32 arraySize,
                                                  ViInt32* reliability,
                                                  ViReal64 _VI_FAR results[],
                                                  ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasACPTrace (ViSession instrumentHandle,
                                                   ViInt32 instance,
                                                   ViInt32 resultType,
                                                   ViInt32 arraySize,
                                                   ViInt32* reliability,
                                                   ViReal64 _VI_FAR results[],
                                                   ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_QueryMEvalMeasACPTraceLimitCheckResults
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 resultType,
              ViInt32 arraySize, ViInt32* reliability, ViInt32 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_ReadMEvalMeasACPTraceAbsolute (ViSession instrumentHandle,
                                                          ViInt32 instance,
                                                          ViInt32 resultType,
                                                          ViInt32 arraySize,
                                                          ViInt32* reliability,
                                                          ViReal64 _VI_FAR results[],
                                                          ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasACPTraceAbsolute
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 resultType,
              ViInt32 arraySize, ViInt32* reliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_QueryMEvalMeasACPTraceLimitCheckResultsAbsolute
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 resultType,
              ViInt32 arraySize, ViInt32* reliability, ViInt32 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_ReadMEvalMeasACPTraceExtended (ViSession instrumentHandle,
                                                          ViInt32 instance,
                                                          ViInt32 resultType,
                                                          ViInt32 arraySize,
                                                          ViInt32* reliability,
                                                          ViReal64 _VI_FAR results[],
                                                          ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasACPTraceExtended
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 resultType,
              ViInt32 arraySize, ViInt32* reliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_QueryMEvalMeasACPTraceLimitCheckResultsExtended
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 resultType,
              ViInt32 arraySize, ViInt32* reliability, ViInt32 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_ReadMEvalMeasACPTraceAbsoluteExtended
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 resultType,
              ViInt32 arraySize, ViInt32* reliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasACPTraceAbsoluteExtended
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 resultType,
              ViInt32 arraySize, ViInt32* reliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMEvalMeasACPTraceLimitCheckResultsAbsoluteExtended
        (ViSession instrumentHandle, ViInt32 instance, ViInt32 resultType,
         ViInt32 arraySize, ViInt32* reliability, ViInt32 _VI_FAR results[],
         ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_ReadMEvalMeasACPOutofTolerance
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 resultType,
              ViInt32 arraySize, ViInt32* reliability, ViReal64* results,
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasACPOutofTolerance
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 resultType,
              ViInt32 arraySize, ViInt32* reliability, ViReal64* results,
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_QueryMEvalACPOutofToleranceLimitsCheckResult
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 resultType,
              ViInt32 arraySize, ViInt32* reliability, ViInt32 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_ReadMEvalMeasChannelPowerTrace
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 resultType,
              ViInt32 arraySize, ViInt32* reliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasChannelPowerTrace
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 resultType,
              ViInt32 arraySize, ViInt32* reliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_QueryMEvalChannelPowerTraceLimitsCheckResult
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 resultType,
              ViInt32 arraySize, ViInt32* reliability, ViInt32 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalChannelPowerTraceState
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViInt32* reliability, ViInt32 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_ReadMEvalMeasChannelPower (ViSession instrumentHandle,
                                                      ViInt32 instance,
                                                      ViInt32 resultType,
                                                      ViInt32 arraySize,
                                                      ViInt32* reliability,
                                                      ViReal64* results,
                                                      ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasChannelPower (ViSession instrumentHandle,
                                                       ViInt32 instance,
                                                       ViInt32 resultType,
                                                       ViInt32 arraySize,
                                                       ViInt32* reliability,
                                                       ViReal64* results,
                                                       ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_QueryMEvalChannelPowerLimitsCheckResult
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 resultType,
              ViInt32 arraySize, ViInt32* reliability, ViInt32 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_ReadMEvalMeasOccupiedBandwidthTrace
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 carrierNumber,
              ViInt32 resultType, ViInt32 arraySize, ViInt32* reliability,
              ViReal64 _VI_FAR results[], ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasOccupiedBandwidthTrace
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 carrierNumber,
              ViInt32 resultType, ViInt32 arraySize, ViInt32* reliability,
              ViReal64 _VI_FAR results[], ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMEvalMeasOccupiedBandwidthTraceLimitsCheckResult
        (ViSession instrumentHandle, ViInt32 instance, ViInt32 carrierNumber,
         ViInt32 resultType, ViInt32 arraySize, ViInt32* reliability,
         ViInt32 _VI_FAR results[], ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_ReadMEvalMeasOccupiedBandwidth
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 carrierNumber,
              ViInt32 resultType, ViInt32 arraySize, ViInt32* reliability,
              ViReal64* results, ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasOccupiedBandwidth
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 carrierNumber,
              ViInt32 resultType, ViInt32 arraySize, ViInt32* reliability,
              ViReal64* results, ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_QueryMEvalOccupiedBandwidthLimitsCheckResult
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 carrierNumber,
              ViInt32 resultType, ViInt32 arraySize, ViInt32* reliability,
              ViInt32 _VI_FAR results[], ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_ReadMEvalMeasModulationResults
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 resultType,
              ViInt32 arraySize, ViInt32* reliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasModulationResults
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 resultType,
              ViInt32 arraySize, ViInt32* reliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_ReadMEvalMeasModulationStandardDeviation
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViInt32* reliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasModulationStandardDeviation
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViInt32* reliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_QueryMEvalMeasModulationResultsLimitsCheckResult
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 resultType,
              ViInt32 arraySize, ViInt32* reliability, ViInt32 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMEvalMeasModulationResultsStandardDeviationLimitsCheckResult
        (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
         ViInt32* reliability, ViInt32 _VI_FAR results[], ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_ReadMEvalMeasSpectrumTrace (ViSession instrumentHandle,
                                                       ViInt32 instance,
                                                       ViInt32 resultType,
                                                       ViInt32 arraySize,
                                                       ViInt32* reliability,
                                                       ViReal64 _VI_FAR results[],
                                                       ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasSpectrumTrace (ViSession instrumentHandle,
                                                        ViInt32 instance,
                                                        ViInt32 resultType,
                                                        ViInt32 arraySize,
                                                        ViInt32* reliability,
                                                        ViReal64 _VI_FAR results[],
                                                        ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasListModeACPResults
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 segment,
              ViInt32 resultType, ViInt32 arraySize, ViInt32* reliability,
              ViInt32* segmentReliability, ViReal64 _VI_FAR ACPResults[],
              ViReal64* ATPWide, ViReal64* ATPNarrow, ViReal64* outOfTolerance,
              ViInt32* validSlotsCount, ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_QueryMEvalMeasListModeACPLimitsCheckResults
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 segment,
              ViInt32 resultType, ViInt32 arraySize, ViInt32* reliability,
              ViInt32* segmentReliability, ViInt32 _VI_FAR ACPResults[],
              ViInt32* ATPWide, ViInt32* ATPNarrow, ViInt32* outOfTolerance,
              ViInt32* validSlotsCount, ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasListModeACPStandardDeviation
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 segment,
              ViInt32 arraySize, ViInt32* reliability, ViInt32* segmentReliability,
              ViReal64 _VI_FAR ACPResults[], ViReal64* ATPWide, ViReal64* ATPNarrow,
              ViReal64* outOfTolerance, ViInt32* validSlotsCount,
              ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMEvalMeasListModeACPStandardDeviationLimitsCheck
        (ViSession instrumentHandle, ViInt32 instance, ViInt32 segment,
         ViInt32 arraySize, ViInt32* reliability, ViInt32* segmentReliability,
         ViInt32 _VI_FAR ACPResults[], ViInt32* ATPWide, ViInt32* ATPNarrow,
         ViInt32* outOfTolerance, ViInt32* validSlotsCount,
         ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasListModeACPExtendedResults
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 segment,
              ViInt32 resultType, ViInt32 arraySize, ViInt32* reliability,
              ViInt32* segmentReliability, ViReal64 _VI_FAR ACPResults[],
              ViReal64* ATPWide, ViReal64* ATPNarrow, ViReal64* outOfTolerance,
              ViInt32* validSlotsCount, ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMEvalMeasListModeACPLimitsCheckExtendedResults
        (ViSession instrumentHandle, ViInt32 instance, ViInt32 segment,
         ViInt32 resultType, ViInt32 arraySize, ViInt32* reliability,
         ViInt32* segmentReliability, ViInt32 _VI_FAR ACPResults[],
         ViInt32* ATPWide, ViInt32* ATPNarrow, ViInt32* outOfTolerance,
         ViInt32* validSlotsCount, ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasListModeACPStandardDeviationExtended
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 segment,
              ViInt32 arraySize, ViInt32* reliability, ViInt32* segmentReliability,
              ViReal64 _VI_FAR ACPResults[], ViReal64* ATPWide, ViReal64* ATPNarrow,
              ViReal64* outOfTolerance, ViInt32* validSlotsCount,
              ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMEvalMeasListModeACPStandardDeviationLimitsCheckExtended
        (ViSession instrumentHandle, ViInt32 instance, ViInt32 segment,
         ViInt32 arraySize, ViInt32* reliability, ViInt32* segmentReliability,
         ViInt32 _VI_FAR ACPResults[], ViInt32* ATPWide, ViInt32* ATPNarrow,
         ViInt32* outOfTolerance, ViInt32* validSlotsCount,
         ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasListModeChannelPowerResults
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 segment,
              ViInt32 resultType, ViInt32 arraySize, ViInt32* reliability,
              ViInt32* segmentReliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMEvalMeasListModeChannelPowerLimitsCheckResults
        (ViSession instrumentHandle, ViInt32 instance, ViInt32 segment,
         ViInt32 resultType, ViInt32 arraySize, ViInt32* reliability,
         ViInt32* segmentReliability, ViInt32 _VI_FAR results[],
         ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasListModeChannelPowerResultsState
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 segment,
              ViInt32 resultType, ViInt32 arraySize, ViInt32* reliability,
              ViInt32* segmentReliability, ViInt32 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasListModeOBWResults
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 segment,
              ViInt32 carrierNumber, ViInt32 resultType, ViInt32* reliability,
              ViInt32* segmentReliability, ViReal64* occupiedBandwidth,
              ViReal64* lowerFrequency, ViReal64* upperFrequency);
ViStatus _VI_FUNC rscmwevm_QueryMEvalMeasListModeOBWLimitsCheckResults
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 segment,
              ViInt32 carrierNumber, ViInt32 resultType, ViInt32* reliability,
              ViInt32* segmentReliability, ViInt32* occupiedBandwidth,
              ViInt32* lowerFrequency, ViInt32* upperFrequency);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasListModeOBWStandardDeviation
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 segment,
              ViInt32 carrierNumber, ViInt32* reliability,
              ViInt32* segmentReliability, ViReal64* occupiedBandwidth);
ViStatus 
    _VI_FUNC rscmwevm_QueryFetchMEvalMeasListModeOBWStandardDeviationLimitsCheck
        (ViSession instrumentHandle, ViInt32 instance, ViInt32 segment,
         ViInt32 carrierNumber, ViInt32* reliability, ViInt32* segmentReliability,
         ViInt32* occupiedBandwidth);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasListModeModulationResults
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 segment,
              ViInt32 resultType, ViInt32 arraySize, ViInt32* reliability,
              ViInt32* segmentReliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_QueryMEvalMeasListModeModulationLimitsCheckResults
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 segment,
              ViInt32 resultType, ViInt32 arraySize, ViInt32* reliability,
              ViInt32* segmentReliability, ViInt32 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasListModeModulationStandardDeviation
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 segment,
              ViInt32 arraySize, ViInt32* reliability, ViInt32* segmentReliability,
              ViReal64 _VI_FAR results[], ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMEvalMeasListModeModulationStandardDeviationLimitsCheck
        (ViSession instrumentHandle, ViInt32 instance, ViInt32 segment,
         ViInt32 arraySize, ViInt32* reliability, ViInt32* segmentReliability,
         ViInt32 _VI_FAR results[], ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasListModeDWCChannelPowerResults
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 segment,
              ViInt32 resultType, ViInt32 arraySize, ViInt32* reliability,
              ViInt32* segmentReliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMEvalMeasListModeDWCChannelPowerLimitsCheckResults
        (ViSession instrumentHandle, ViInt32 instance, ViInt32 segment,
         ViInt32 resultType, ViInt32 arraySize, ViInt32* reliability,
         ViInt32* segmentReliability, ViInt32 _VI_FAR results[],
         ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasListModeAllReliabilityResults
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 numberOfActiveSegments, ViInt32* reliability,
              ViInt32 _VI_FAR segmentReliability[], ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMEvalMeasListModeAllReliabilityLimitsCheckResult
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32* reliability,
         ViInt32 _VI_FAR segmentReliability[], ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasListModeAllACPResults
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32 arraySize,
              ViInt32* reliability, ViInt32* segmentReliability,
              ViReal64 _VI_FAR ACPResults[], ViReal64* ATPWide, ViReal64* ATPNarrow,
              ViReal64* outOfTolerance, ViInt32* validSlotsCount,
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_QueryMEvalMeasListModeAllACPLimitsCheckResults
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32 arraySize,
              ViInt32* reliability, ViInt32* segmentReliability,
              ViInt32 _VI_FAR ACPResults[], ViInt32* ATPWide, ViInt32* ATPNarrow,
              ViInt32* outOfTolerance, ViInt32* validSlotsCount,
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasListModeAllACPStandardDeviation
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 numberOfActiveSegments, ViInt32 arraySize,
              ViInt32* reliability, ViInt32* segmentReliability,
              ViReal64 _VI_FAR ACPResults[], ViReal64* ATPWide, ViReal64* ATPNarrow,
              ViReal64* outOfTolerance, ViInt32* validSlotsCount,
              ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMEvalMeasListModeAllACPStandardDeviationLimitsCheck
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 arraySize, ViInt32* reliability,
         ViInt32* segmentReliability, ViInt32 _VI_FAR ACPResults[],
         ViInt32* ATPWide, ViInt32* ATPNarrow, ViInt32* outOfTolerance,
         ViInt32* validSlotsCount, ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasListModeAllACPExtendedResults
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32 arraySize,
              ViInt32* reliability, ViInt32* segmentReliability,
              ViReal64 _VI_FAR ACPResults[], ViReal64* ATPWide, ViReal64* ATPNarrow,
              ViReal64* outOfTolerance, ViInt32* validSlotsCount,
              ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMEvalMeasListModeAllACPLimitsCheckExtendedResults
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32 arraySize,
         ViInt32* reliability, ViInt32* segmentReliability,
         ViInt32 _VI_FAR ACPResults[], ViInt32* ATPWide, ViInt32* ATPNarrow,
         ViInt32* outOfTolerance, ViInt32* validSlotsCount,
         ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_FetchMEvalMeasListModeAllACPStandardDeviationExtended
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 arraySize, ViInt32* reliability,
         ViInt32* segmentReliability, ViReal64 _VI_FAR ACPResults[],
         ViReal64* ATPWide, ViReal64* ATPNarrow, ViReal64* outOfTolerance,
         ViInt32* validSlotsCount, ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMEvalMeasListModeAllACPStandardDeviationLimitsCheckExtended
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 arraySize, ViInt32* reliability,
         ViInt32* segmentReliability, ViInt32 _VI_FAR ACPResults[],
         ViInt32* ATPWide, ViInt32* ATPNarrow, ViInt32* outOfTolerance,
         ViInt32* validSlotsCount, ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasListModeAllChannelPowerResults
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32 arraySize,
              ViInt32* reliability, ViInt32* segmentReliability,
              ViReal64 _VI_FAR results[], ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMEvalMeasListModeAllChannelPowerLimitsCheckResults
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32 arraySize,
         ViInt32* reliability, ViInt32* segmentReliability,
         ViInt32 _VI_FAR results[], ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasListModeAllChannelPowerResultsState
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32 arraySize,
              ViInt32* reliability, ViInt32* segmentReliability,
              ViInt32 _VI_FAR results[], ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasListModeAllOBWResults
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 numberOfActiveSegments, ViInt32 carrierNumber,
              ViInt32 resultType, ViInt32* reliability, ViInt32* segmentReliability,
              ViReal64* occupiedBandwidth, ViReal64* lowerEdge,
              ViReal64* upperEdge);
ViStatus _VI_FUNC rscmwevm_QueryMEvalMeasListModeAllOBWLimitsCheckResults
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 numberOfActiveSegments, ViInt32 carrierNumber,
              ViInt32 resultType, ViInt32* reliability, ViInt32* segmentReliability,
              ViInt32* occupiedBandwidth, ViInt32* lowerEdge, ViInt32* upperEdge);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasListModeAllOBWStandardDeviation
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 numberOfActiveSegments, ViInt32 carrierNumber,
              ViInt32* reliability, ViInt32* segmentReliability,
              ViReal64* occupiedBandwidth);
ViStatus 
    _VI_FUNC rscmwevm_QueryFetchMEvalMeasListModeAllOBWStandardDeviationLimitsCheck
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 carrierNumber,
         ViInt32* reliability, ViInt32* segmentReliability,
         ViInt32* occupiedBandwidth);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasListModeAllModulationResults
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32 arraySize,
              ViInt32* reliability, ViInt32* segmentReliability,
              ViReal64 _VI_FAR results[], ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMEvalMeasListModeAllModulationLimitsCheckResults
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32 arraySize,
         ViInt32* reliability, ViInt32* segmentReliability,
         ViInt32 _VI_FAR results[], ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_FetchMEvalMeasListModeAllModulationStandardDeviation
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 arraySize, ViInt32* reliability,
         ViInt32* segmentReliability, ViReal64 _VI_FAR results[],
         ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMEvalMeasListModeAllModulationStandardDeviationLimitsCheck
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 arraySize, ViInt32* reliability,
         ViInt32* segmentReliability, ViInt32 _VI_FAR results[],
         ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasListModeAllDWCChannelPowerResults
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32 arraySize,
              ViInt32* reliability, ViInt32* segmentReliability,
              ViReal64 _VI_FAR results[], ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMEvalMeasListModeAllDWCChannelPowerLimitsCheckResults
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32 arraySize,
         ViInt32* reliability, ViInt32* segmentReliability,
         ViInt32 _VI_FAR results[], ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMultiEvalListModeAllACPSpecificResults
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32 type,
              ViInt32* reliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMultiEvalListModeAllACPSpecificLimitsCheckResults
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32 type,
         ViInt32* reliability, ViInt32 _VI_FAR results[], ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMultiEvalListModeAllACPOffCenterResults
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32 direction,
              ViInt32 frequencyPoint, ViInt32* reliability,
              ViReal64 _VI_FAR results[], ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMultiEvalListModeAllACPOffCenterLimitsCheckResults
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32 direction,
         ViInt32 frequencyPoint, ViInt32* reliability, ViInt32 _VI_FAR results[],
         ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_FetchMultiEvalListModeAllACPOffCenterExtendedResults
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32 direction,
         ViInt32 frequencyPoint, ViInt32* reliability, ViReal64 _VI_FAR results[],
         ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMultiEvalListModeAllACPOffCenterLimitsCheckExtendedResults
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32 direction,
         ViInt32 frequencyPoint, ViInt32* reliability, ViInt32 _VI_FAR results[],
         ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMultiEvalListModeAllACPOutOfToleranceResults
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 numberOfActiveSegments, ViInt32* reliability,
              ViReal64 _VI_FAR results[], ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMultiEvalListModeAllACPStatisticCountResults
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 numberOfActiveSegments, ViInt32* reliability,
              ViReal64 _VI_FAR results[], ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasListModeAllSpecificChannelPowerState
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 numberOfActiveSegments, ViInt32 channelType,
              ViInt32* reliability, ViInt32 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_FetchMEvalMeasListModeAllSpecificChannelPowerResults
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 channelType, ViInt32 resultType,
         ViInt32* reliability, ViReal64 _VI_FAR results[], ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMEvalMeasListModeAllSpecificChannelPowerLimitCheckResults
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 channelType, ViInt32 resultType,
         ViInt32* reliability, ViInt32 _VI_FAR results[], ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMultiEvalListModeAllOBWFrequenciesResults
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 numberOfActiveSegments, ViInt32 frequency,
              ViInt32* reliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMultiEvalListModeAllOBWSpecificResults
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 numberOfActiveSegments, ViInt32 resultType,
              ViInt32* reliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_FetchMultiEvalListModeAllOBWSpecificLimitsCheckResults
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32* reliability,
         ViInt32 _VI_FAR results[], ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMultiEvalListModeAllModulationEVMResults
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32 type,
              ViInt32* reliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMultiEvalListModeAllModulationEVMLimitsCheckResults
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32 type,
         ViInt32* reliability, ViInt32 _VI_FAR results[], ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_FetchMultiEvalListModeAllModulationMagnitudeErrorResults
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32 type,
         ViInt32* reliability, ViReal64 _VI_FAR results[], ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMultiEvalListModeAllModulationMagnitudeErrorLimitsCheckResults
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32 type,
         ViInt32* reliability, ViInt32 _VI_FAR results[], ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_FetchMultiEvalListModeAllModulationPhaseErrorResults
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32 type,
         ViInt32* reliability, ViReal64 _VI_FAR results[], ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMultiEvalListModeAllModulationPhaseErrorLimitsCheckResults
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32 type,
         ViInt32* reliability, ViInt32 _VI_FAR results[], ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_FetchMultiEvalListModeAllModulationIQOriginOffsetResults
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32* reliability,
         ViReal64 _VI_FAR results[], ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMultiEvalListModeAllModulationIQOriginOffsetLimitsCheckResults
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32* reliability,
         ViInt32 _VI_FAR results[], ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_FetchMultiEvalListModeAllModulationIQImbalanceResults
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32* reliability,
         ViReal64 _VI_FAR results[], ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMultiEvalListModeAllModulationIQImbalanceLimitsCheckResults
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32* reliability,
         ViInt32 _VI_FAR results[], ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMultiEvalListModeAllModulationCFEResults
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 numberOfActiveSegments, ViInt32 resultType,
              ViInt32* reliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMultiEvalListModeAllModulationCFELimitsCheckResults
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32* reliability,
         ViInt32 _VI_FAR results[], ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMultiEvalListModeAllModulationTTEResults
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 numberOfActiveSegments, ViInt32 resultType,
              ViInt32* reliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMultiEvalListModeAllModulationTTELimitsCheckResults
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32* reliability,
         ViInt32 _VI_FAR results[], ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMultiEvalListModeAllModulationMSPowerResults
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32 type,
              ViInt32* reliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMultiEvalListModeAllModulationMSPowerLimitsCheckResults
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32 type,
         ViInt32* reliability, ViInt32 _VI_FAR results[], ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_FetchMultiEvalListModeAllModulationWaveformQualityResults
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32* reliability,
         ViReal64 _VI_FAR results[], ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMultiEvalListModeAllModulationWaveformQualityLimitsCheckResults
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 resultType, ViInt32* reliability,
         ViInt32 _VI_FAR results[], ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_FetchMultiEvalListModeAllModulationOutOfToleranceResults
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32* reliability,
         ViReal64 _VI_FAR results[], ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_FetchMultiEvalListModeAllModulationStatisticCountResults
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32* reliability,
         ViReal64 _VI_FAR results[], ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchMEvalMeasListModeAllDWCPowerSpecificResults
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 numberOfActiveSegments, ViInt32 dataType, ViInt32 resultType,
              ViInt32* reliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevm_QueryMEvalMeasListModeAllDWCPowerSpecificLimitsCheckResults
        (ViSession instrumentHandle, ViInt32 instance,
         ViInt32 numberOfActiveSegments, ViInt32 dataType, ViInt32 resultType,
         ViInt32* reliability, ViInt32 _VI_FAR results[], ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_ConfigureOLTRMeasurement (ViSession instrumentHandle,
                                                     ViInt32 instance,
                                                     ViReal64 timeout,
                                                     ViInt32 numberOfSequences,
                                                     ViInt32 direction,
                                                     ViReal64 powerStep,
                                                     ViInt32 powerInterval,
                                                     ViInt32 guardInterval,
                                                     ViBoolean measureOnException);
ViStatus _VI_FUNC rscmwevm_QueryOLTRMeasurementReferencePowerIntervalTime
             (ViSession instrumentHandle, ViInt32 instance,
              ViReal64* powerIntervalTime);
ViStatus _VI_FUNC rscmwevm_QueryOLTRMeasurementGuardIntervalTime
             (ViSession instrumentHandle, ViInt32 instance,
              ViReal64* guardIntervalTime);
ViStatus _VI_FUNC rscmwevm_QueryOLTRMeasurementRepetition
             (ViSession instrumentHandle, ViInt32 instance, ViInt32* repetition);
ViStatus _VI_FUNC rscmwevm_ConfigureOLTRInitialLowerLimit
             (ViSession instrumentHandle, ViInt32 instance,
              ViReal64 initialLowerLimit);
ViStatus _VI_FUNC rscmwevm_OLTRMeasurementInit (ViSession instrumentHandle,
                                                ViInt32 instance);
ViStatus _VI_FUNC rscmwevm_OLTRMeasurementAbort (ViSession instrumentHandle,
                                                 ViInt32 instance);
ViStatus _VI_FUNC rscmwevm_OLTRMeasurementStop (ViSession instrumentHandle,
                                                ViInt32 instance);
ViStatus _VI_FUNC rscmwevm_QueryOLTRMeasurementStatus (ViSession instrumentHandle,
                                                       ViInt32 instance,
                                                       ViInt32* mainState,
                                                       ViInt32* syncState,
                                                       ViInt32* resourcesState);
ViStatus _VI_FUNC rscmwevm_ReadOLTRTraceState (ViSession instrumentHandle,
                                               ViInt32 instance, ViInt32 sequence,
                                               ViInt32 direction, ViInt32 arraySize,
                                               ViInt32* reliability,
                                               ViInt32 _VI_FAR results[],
                                               ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchOLTRTraceState (ViSession instrumentHandle,
                                                ViInt32 instance, ViInt32 sequence,
                                                ViInt32 direction,
                                                ViInt32 arraySize,
                                                ViInt32* reliability,
                                                ViInt32 _VI_FAR results[],
                                                ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_QueryOLTRTraceStateLimitsCheckResults
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 sequence,
              ViInt32 direction, ViInt32 arraySize, ViInt32* reliability,
              ViInt32 _VI_FAR results[], ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_ReadOLTRTrace (ViSession instrumentHandle,
                                          ViInt32 instance, ViInt32 traceType,
                                          ViInt32 sequence, ViInt32 direction,
                                          ViInt32 arraySize, ViInt32* reliability,
                                          ViReal64 _VI_FAR results[],
                                          ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_FetchOLTRTrace (ViSession instrumentHandle,
                                           ViInt32 instance, ViInt32 traceType,
                                           ViInt32 sequence, ViInt32 direction,
                                           ViInt32 arraySize, ViInt32* reliability,
                                           ViReal64 _VI_FAR results[],
                                           ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevm_SetAttributeViInt32 (ViSession instrumentHandle,
                                                ViString repeatedCapabilityName,
                                                ViUInt32 attributeID,
                                                ViInt32 attributeValue);
ViStatus _VI_FUNC rscmwevm_SetAttributeViReal64 (ViSession instrumentHandle,
                                                 ViString repeatedCapabilityName,
                                                 ViUInt32 attributeID,
                                                 ViReal64 attributeValue);
ViStatus _VI_FUNC rscmwevm_SetAttributeViString (ViSession instrumentHandle,
                                                 ViString repeatedCapabilityName,
                                                 ViUInt32 attributeID,
                                                 ViString attributeValue);
ViStatus _VI_FUNC rscmwevm_SetAttributeViBoolean (ViSession instrumentHandle,
                                                  ViString repeatedCapabilityName,
                                                  ViUInt32 attributeID,
                                                  ViBoolean attributeValue);
ViStatus _VI_FUNC rscmwevm_SetAttributeViSession (ViSession instrumentHandle,
                                                  ViString repeatedCapabilityName,
                                                  ViUInt32 attributeID,
                                                  ViSession attributeValue);
ViStatus _VI_FUNC rscmwevm_GetAttributeRepeatedCapabilityIds
             (ViSession instrumentHandle, ViUInt32 attributeID, ViInt32 bufferSize,
              ViChar _VI_FAR repeatedCapabilityId_s[]);
ViStatus _VI_FUNC rscmwevm_GetAttributeRepeatedCapabilityIdNames
             (ViSession instrumentHandle, ViUInt32 attributeID,
              ViString repeatedCapabilityId, ViInt32 bufferSize,
              ViChar _VI_FAR repeatedCapabilityIdName_s[]);
ViStatus _VI_FUNC rscmwevm_GetAttributeViInt32 (ViSession instrumentHandle,
                                                ViString repeatedCapabilityName,
                                                ViUInt32 attributeID,
                                                ViInt32* attributeValue);
ViStatus _VI_FUNC rscmwevm_GetAttributeViReal64 (ViSession instrumentHandle,
                                                 ViString repeatedCapabilityName,
                                                 ViUInt32 attributeID,
                                                 ViReal64* attributeValue);
ViStatus _VI_FUNC rscmwevm_GetAttributeViString (ViSession instrumentHandle,
                                                 ViString repeatedCapabilityName,
                                                 ViUInt32 attributeID,
                                                 ViInt32 bufferSize,
                                                 ViChar _VI_FAR attributeValue[]);
ViStatus _VI_FUNC rscmwevm_GetAttributeViBoolean (ViSession instrumentHandle,
                                                  ViString repeatedCapabilityName,
                                                  ViUInt32 attributeID,
                                                  ViBoolean* attributeValue);
ViStatus _VI_FUNC rscmwevm_GetAttributeViSession (ViSession instrumentHandle,
                                                  ViString repeatedCapabilityName,
                                                  ViUInt32 attributeID,
                                                  ViSession* attributeValue);
ViStatus _VI_FUNC rscmwevm_CheckAttributeViInt32 (ViSession instrumentHandle,
                                                  ViString repeatedCapabilityName,
                                                  ViUInt32 attributeID,
                                                  ViInt32 attributeValue);
ViStatus _VI_FUNC rscmwevm_CheckAttributeViReal64 (ViSession instrumentHandle,
                                                   ViString repeatedCapabilityName,
                                                   ViUInt32 attributeID,
                                                   ViReal64 attributeValue);
ViStatus _VI_FUNC rscmwevm_CheckAttributeViString (ViSession instrumentHandle,
                                                   ViString repeatedCapabilityName,
                                                   ViUInt32 attributeID,
                                                   ViString attributeValue);
ViStatus _VI_FUNC rscmwevm_CheckAttributeViBoolean (ViSession instrumentHandle,
                                                    ViString repeatedCapabilityName,
                                                    ViUInt32 attributeID,
                                                    ViBoolean attributeValue);
ViStatus _VI_FUNC rscmwevm_CheckAttributeViSession (ViSession instrumentHandle,
                                                    ViString repeatedCapabilityName,
                                                    ViUInt32 attributeID,
                                                    ViSession attributeValue);
ViStatus _VI_FUNC rscmwevm_reset (ViSession instrumentHandle);
ViStatus _VI_FUNC rscmwevm_self_test (ViSession instrumentHandle,
                                      ViInt16* selfTestResult,
                                      ViChar _VI_FAR selfTestMessage[]);
ViStatus _VI_FUNC rscmwevm_SelfTestResults (ViSession instrumentHandle,
                                            ViInt32 bufferSize,
                                            ViChar _VI_FAR results[]);
ViStatus _VI_FUNC rscmwevm_revision_query (ViSession instrumentHandle,
                                           ViChar _VI_FAR instrumentDriverRevision[],
                                           ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC rscmwevm_SystemVersion (ViSession instrumentHandle,
                                          ViInt32 length,
                                          ViChar _VI_FAR systemVersion[]);
ViStatus _VI_FUNC rscmwevm_error_query (ViSession instrumentHandle,
                                        ViInt32* errorCode,
                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rscmwevm_ErrorList (ViSession instrumentHandle,
                                      ViInt32 bufferSize, ViChar _VI_FAR errors[]);
ViStatus _VI_FUNC rscmwevm_error_message (ViSession instrumentHandle,
                                          ViStatus errorCode,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rscmwevm_ReliabilityIndicator (ViSession instrumentHandle,
                                                 ViInt32 reliabilityCode,
                                                 ViChar _VI_FAR reliabilityMessage[]);
ViStatus _VI_FUNC rscmwevm_Preset (ViSession instrumentHandle);
ViStatus _VI_FUNC rscmwevm_ConfigureErrorChecking (ViSession instrumentHandle,
                                                   ViBoolean optionChecking,
                                                   ViBoolean rangeChecking,
                                                   ViBoolean statusChecking);
ViStatus _VI_FUNC rscmwevm_SetOPCTimeout (ViSession instrumentHandle,
                                          ViUInt32 OPCTimeout);
ViStatus _VI_FUNC rscmwevm_GetOPCTimeout (ViSession instrumentHandle,
                                          ViUInt32* timeout);
ViStatus _VI_FUNC rscmwevm_SetVISATimeout (ViSession instrumentHandle,
                                           ViUInt32 VISATimeout);
ViStatus _VI_FUNC rscmwevm_GetVISATimeout (ViSession instrumentHandle,
                                           ViUInt32* VISATimeout);
ViStatus _VI_FUNC rscmwevm_ClearStatus (ViSession instrumentHandle);
ViStatus _VI_FUNC rscmwevm_IDQueryResponse (ViSession instrumentHandle,
                                            ViUInt32 bufferSize,
                                            ViChar _VI_FAR IDQueryResponse[]);
ViStatus _VI_FUNC rscmwevm_ProcessAllPreviousCommands (ViSession instrumentHandle);
ViStatus _VI_FUNC rscmwevm_QueryOPC (ViSession instrumentHandle, ViInt32* OPC);
ViStatus _VI_FUNC rscmwevm_setCheckStatus (ViSession instrumentHandle,
                                           ViBoolean statusChecking);
ViStatus _VI_FUNC rscmwevm_setCheckOption (ViSession instrumentHandle,
                                           ViBoolean optionChecking);
ViStatus _VI_FUNC rscmwevm_SetFastSweepMode (ViSession instrumentHandle,
                                             ViInt32 fastSweepMode);
ViStatus _VI_FUNC rscmwevm_GetError (ViSession instrumentHandle, ViStatus* code,
                                     ViInt32 bufferSize,
                                     ViChar _VI_FAR description[]);
ViStatus _VI_FUNC rscmwevm_ClearError (ViSession instrumentHandle);
ViStatus _VI_FUNC rscmwevm_WriteFromFileToInstrument (ViSession instrumentHandle,
                                                      ViString source,
                                                      ViString destination);
ViStatus _VI_FUNC rscmwevm_ReadToFileFromInstrument (ViSession instrumentHandle,
                                                     ViString source,
                                                     ViString destination);
ViStatus _VI_FUNC rscmwevm_WriteInstrData (ViSession instrumentHandle,
                                           ViString writeBuffer);
ViStatus _VI_FUNC rscmwevm_ReadInstrData (ViSession instrumentHandle,
                                          ViInt32 numberOfBytesToRead,
                                          ViChar _VI_FAR readBuffer[],
                                          ViUInt32* numBytesRead);
ViStatus _VI_FUNC rscmwevm_QueryViBoolean (ViSession instrumentHandle,
                                           ViString command, ViBoolean* value);
ViStatus _VI_FUNC rscmwevm_QueryViInt32 (ViSession instrumentHandle,
                                         ViString command, ViInt32* value);
ViStatus _VI_FUNC rscmwevm_QueryViReal64 (ViSession instrumentHandle,
                                          ViString command, ViReal64* value);
ViStatus _VI_FUNC rscmwevm_QueryViString (ViSession instrumentHandle,
                                          ViString command, ViInt32 bufferSize,
                                          ViChar _VI_FAR value[]);
ViStatus _VI_FUNC rscmwevm_close (ViSession instrumentHandle);

/****************************************************************************
 *------------------------ Error And Completion Codes ----------------------*
 ****************************************************************************/

#define RSCMWEVM_WARN_MEASURE_UNCALIBRATED    (RS_CLASS_WARN_BASE + 0x0001L)
#define RSCMWEVM_WARN_OVER_RANGE              (RS_CLASS_WARN_BASE + 0x0002L)

#define RSCMWEVM_ERROR_INCORRECT_STATE        (RS_CLASS_ERROR_BASE + 0x0003L)
#define RSCMWEVM_ERROR_INCORRECT_RESPONSE     (RS_CLASS_ERROR_BASE + 0x0002L)
#define RSCMWEVM_ERROR_MAX_TIME_EXCEEDED      (RS_CLASS_ERROR_BASE + 0x0001L)
#define RSCMWEVM_ERROR_RELIABILITY_INDICATOR  (RS_SPECIFIC_ERROR_BASE + 0x0004L)

#define RSCMWEVM_WARNMSG_MEASURE_UNCALIBRATED "Uncalibrated measurement"
#define RSCMWEVM_WARNMSG_OVER_RANGE           "Measurement overrange"

#define RSCMWEVM_ERRMSG_INCORRECT_STATE       "Instrument in incorrect state"
#define RSCMWEVM_ERRMSG_INCORRECT_RESPONSE    "Response incorrect; report problem to R&S support!"
#define RSCMWEVM_ERRMSG_MAX_TIME_EXCEEDED     "Max Time Exceeded"
#define RSCMWEVM_ERRMSG_RELIABILITY_INDICATOR "Reliability Indicator error"

#define RSCMWEVM_ERROR_CODES_AND_MSGS \
    {RSCMWEVM_WARN_MEASURE_UNCALIBRATED,  RSCMWEVM_WARNMSG_MEASURE_UNCALIBRATED},\
    {RSCMWEVM_WARN_OVER_RANGE,            RSCMWEVM_WARNMSG_OVER_RANGE},\
    {RSCMWEVM_ERROR_INCORRECT_STATE ,   RSCMWEVM_ERRMSG_INCORRECT_STATE },\
    {RSCMWEVM_ERROR_INCORRECT_RESPONSE,     RSCMWEVM_ERRMSG_INCORRECT_RESPONSE},\
    {RSCMWEVM_ERROR_MAX_TIME_EXCEEDED,    RSCMWEVM_ERRMSG_MAX_TIME_EXCEEDED},\
    {RSCMWEVM_ERROR_RELIABILITY_INDICATOR, RSCMWEVM_ERRMSG_RELIABILITY_INDICATOR}

/****************************************************************************
 *---------------------------- End Include File ----------------------------*
 ****************************************************************************/

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif
#endif /* __RSCMWEVM_HEADER */

