/*****************************************************************************
 *------------------------ Utility  -----------------------------------------*
 *****************************************************************************/
#include <float.h>
#include <math.h>
#include "rscmwevm.h"
#pragma warning(disable:4152)
static ViString arrayCodes[] = {"OK", "ULEU", "ULEL", NULL}; 

/*****************************************************************************
 *- Callback Declarations ---------------------------------------------------*
 *****************************************************************************/
ViStatus rscmwevm_CheckStatusCallback (ViSession io);
ViStatus rscmwevm_WaitForOPCCallback (ViSession io);

/*****************************************************************************
 * Function: rscmwevm_InitAttributes
 * Purpose:  This function inits attributes to the desired values if needed.
 *****************************************************************************/
ViStatus rscmwevm_InitAttributes (ViSession instrSession)
{
    ViStatus    error           = VI_SUCCESS;
    ViInt32     p2value         = 0;
    void        *p2void;
    ViChar      buffer[RS_MAX_MESSAGE_BUF_SIZE],
                revision[RS_MAX_MESSAGE_BUF_SIZE],
                manufacturer[RS_MAX_MESSAGE_BUF_SIZE],
                model[RS_MAX_MESSAGE_BUF_SIZE],
                tmp_model[RS_MAX_MESSAGE_BUF_SIZE],
                idQ[RS_MAX_MESSAGE_BUF_SIZE],
                options_list[RS_MAX_MESSAGE_BUF_SIZE];

    buffer[RS_MAX_MESSAGE_BUF_SIZE -1] = 0;

    /*- Misc -*/

    if (!Rs_Simulating(instrSession))
        {
        /* Instrument identification */
        viCheckErr (viQueryf (instrSession, "*IDN?\n", "%[^\r\n]", idQ));
        idQ[RS_MAX_MESSAGE_BUF_SIZE - 1] = 0;
        checkErr (Rs_SetAttribute (instrSession, "", RSCMWEVM_ATTR_ID_QUERY_RESPONSE, 0, idQ));
        
        /* Option(s) string */
        viCheckErr (viQueryf (instrSession, "*OPT?\n", "%[^\r\n]", options_list));
        options_list[RS_MAX_MESSAGE_BUF_SIZE - 1] = 0;
        }
    else /* Simulating */
        {
        /* Instrument identification */
        strncpy (idQ, RSCMWEVM_SIMULATION_ID_QUERY, RS_MAX_MESSAGE_BUF_SIZE - 1);
        checkErr (Rs_SetAttribute (instrSession, "", RSCMWEVM_ATTR_ID_QUERY_RESPONSE, 0, idQ));
        
        /* Option(s) string */
        strncpy (options_list, RSCMWEVM_SIMULATION_OPT_QUERY, RS_MAX_MESSAGE_BUF_SIZE - 1);
        }

    /*- Inherent Instrument Specific Attributes ----------------------------*/

    /*- User Options -*/

    /*
    RS_ATTR_RANGE_CHECK             ... Rs_SpecificDriverNew
    RS_ATTR_QUERY_INSTRUMENT_STATUS ... Rs_SpecificDriverNew
    RS_ATTR_CACHE                   ... Rs_SpecificDriverNew
    RS_ATTR_SIMULATE                ... Rs_SpecificDriverNew
    RS_ATTR_RECORD_COERCIONS        ... not supported
    RS_ATTR_INTERCHANGE_CHECK       ... not supported
    RS_ATTR_SPY                     ... not supported
    RS_ATTR_USE_SPECIFIC_SIMULATION ... not supported
    */

    /*- Class Driver Identification -*/

    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_CLASS_DRIVER_DESCRIPTION, 0, RSCMWEVM_CLASS_DRIVER_DESCRIPTION));
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_CLASS_DRIVER_PREFIX, 0, RSCMWEVM_CLASS_DRIVER_PREFIX));
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_CLASS_DRIVER_VENDOR, 0, RSCMWEVM_CLASS_DRIVER_VENDOR));
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_CLASS_DRIVER_REVISION, 0, RSCMWEVM_CLASS_DRIVER_REVISION));
    p2value = RSCMWEVM_CLASS_SPEC_MAJOR_VERSION;
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION, 0, &p2value));
    p2value = RSCMWEVM_CLASS_SPEC_MINOR_VERSION;
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION, 0, &p2value));

    /*- Driver Identification -*/
                                                        
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION, 0, RSCMWEVM_SPECIFIC_DRIVER_DESCRIPTION));
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_SPECIFIC_DRIVER_PREFIX, 0, RSCMWEVM_SPECIFIC_DRIVER_PREFIX));
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_SPECIFIC_DRIVER_LOCATOR, 0, RSCMWEVM_SPECIFIC_DRIVER_LOCATOR));
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_SPECIFIC_DRIVER_VENDOR, 0, RSCMWEVM_SPECIFIC_DRIVER_VENDOR));

    sprintf (buffer, 
             "Driver: %s %ld.%ld.%ld, Compiler: %s %3.2f, "
             "Components: RSEngine %.2f, VISA-Spec %.2f",
             RSCMWEVM_SPECIFIC_DRIVER_PREFIX,
             RSCMWEVM_MAJOR_VERSION, RSCMWEVM_MINOR_VERSION,RSCMWEVM_MINOR_MINOR_VERSION,
             RS_COMPILER_NAME, RS_COMPILER_VER_NUM, 
             RS_ENGINE_MAJOR_VERSION + RS_ENGINE_MINOR_VERSION/10.0, 
             Rs_ConvertVISAVer(VI_SPEC_VERSION));

    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_SPECIFIC_DRIVER_REVISION, 0, buffer));
    p2value = RSCMWEVM_CLASS_SPEC_MAJOR_VERSION;
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION, 0, &p2value));
    p2value = RSCMWEVM_CLASS_SPEC_MINOR_VERSION;
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION, 0, &p2value));

    /*- Driver Capabilities -*/
                                   
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_SUPPORTED_INSTRUMENT_MODELS, 0, RSCMWEVM_SUPPORTED_INSTRUMENT_MODELS));
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_GROUP_CAPABILITIES, 0, RSCMWEVM_GROUP_CAPABILITIES));
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_FUNCTION_CAPABILITIES, 0, RSCMWEVM_FUNCTION_CAPABILITIES));
    /* RS_ATTR_CHANNEL_COUNT        ... Rs_BuildRepCapTable */

    /*- Driver Setup -*/

    /* RS_ATTR_DRIVER_SETUP         ... Rs_SpecificDriverNew */

    /*- Instrument Identification -*/

    checkErr (Rs_GetAttribute (instrSession, "", RSCMWEVM_ATTR_ID_QUERY_RESPONSE, 0, RSCMWEVM_IO_BUFFER_SIZE, idQ));
    sscanf (idQ, "%[^,],%[^,],%*[^,],%256[^\n]", manufacturer, tmp_model, revision);
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_INSTRUMENT_MANUFACTURER, 0, manufacturer));
    sscanf (tmp_model,"%[^-]",model);
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_INSTRUMENT_MODEL, 0, model));
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_INSTRUMENT_FIRMWARE_REVISION, 0, revision));
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_OPTIONS_LIST, 0, options_list));

    /*- Advanced Session Information -*/
                                  
    /*  
    RS_ATTR_IO_RESOURCE_DESCRIPTOR  ... rscmwevm_InitWithOptions
    RS_ATTR_LOGICAL_NAME            ... not supported
    */

    /*- Inherent Vendor Specific Attributes --------------------------------*/

    /*- Error Info -*/

    /*
    RS_ATTR_PRIMARY_ERROR           ... Rs_SetErrorInfo
    RS_ATTR_SECONDARY_ERROR         ... Rs_SetErrorInfo
    RS_ATTR_ERROR_ELABORATION       ... Rs_SetErrorInfo
    */

    /*- Session I/O -*/

    /*
    RS_ATTR_VISA_RM_SESSION         ... rscmwevm_RsInit
    RS_ATTR_IO_SESSION              ... Rs_UpdateIOSession
    RS_ATTR_IO_SESSION_TYPE         ... not supported
    */

    /*- Version Info -*/                     

    p2value = RSCMWEVM_MAJOR_VERSION;
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_SPECIFIC_DRIVER_MAJOR_VERSION, 0, &p2value));
    p2value = RSCMWEVM_MINOR_VERSION;
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_SPECIFIC_DRIVER_MINOR_VERSION, 0, &p2value));
    p2value = RSCMWEVM_MINOR_MINOR_VERSION;
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_SPECIFIC_DRIVER_MINOR_MINOR_VERSION, 0, &p2value));
    p2value = RSCMWEVM_CLASS_SPEC_MAJOR_VERSION;
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_CLASS_DRIVER_MAJOR_VERSION, 0, &p2value));
    p2value = RSCMWEVM_CLASS_SPEC_MINOR_VERSION;
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_CLASS_DRIVER_MINOR_VERSION, 0, &p2value));
    p2value = RS_ENGINE_MAJOR_VERSION;
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_ENGINE_MAJOR_VERSION, 0, &p2value));
    p2value = RS_ENGINE_MINOR_VERSION;
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_ENGINE_MINOR_VERSION, 0, &p2value));
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_ENGINE_REVISION, 0, RS_ENGINE_REVISION));

    /*- Session Callbacks -*/                

    p2void = rscmwevm_WaitForOPCCallback;
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_OPC_CALLBACK, 0, &p2void));
    p2void = rscmwevm_CheckStatusCallback;
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_CHECK_STATUS_CALLBACK, 0, &p2void));
    p2value = RSCMWEVM_OPC_TIMEOUT;
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_OPC_TIMEOUT, 0, &p2value));

    /*----------------------------------------------------------------------*/

Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwevm_DefaultInstrSetup
 * Purpose:  This function sends a default setup to the instrument. The
 *           rscmwevm_reset function calls this function. The
 *           rscmwevm_RsInit function calls this function when the
 *           user passes VI_FALSE for the reset parameter. This function is
 *           useful for configuring settings that other instrument driver
 *           functions require.
 *
 *           Note:  Call this function only when the session is locked.
 *****************************************************************************/
ViStatus rscmwevm_DefaultInstrSetup (ViSession instrSession)
{
    ViStatus    error = VI_SUCCESS;

    /* Set all the attributes to the default state. Do not update inherent attributes! */
    checkErr (Rs_ApplyAttributeDefaults (instrSession, VI_FALSE));

    /* Init attributes */
    checkErr( rscmwevm_InitAttributes (instrSession));

    if (!Rs_Simulating(instrSession))
    {
        viCheckErr( viPrintf (instrSession, "*CLS;*ESE %hu;*SRE 0", IEEE_488_2_ESE_MASK));
    }

Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwevm_CheckStatus
 * Purpose:  This function checks the status of the instrument to detect
 *           whether the instrument has encountered an error. This function
 *           is called at the end of most exported driver functions. If the
 *           instrument reports an error, this function returns
 *           RS_ERROR_INSTRUMENT_SPECIFIC. The user can set the
 *           rscmwevm_ATTR_QUERY_INSTRUMENT_STATUS attribute to VI_FALSE to disable this
 *           check and increase execution speed.
 *
 *           Note:  Call this function only when the session is locked.
 *****************************************************************************/
ViStatus rscmwevm_CheckStatus (ViSession instrSession)
{
    ViStatus    error = VI_SUCCESS;

    if (Rs_QueryInstrStatus (instrSession) && !Rs_Simulating (instrSession))
        {
        checkErr( rscmwevm_CheckStatusCallback (instrSession));
        }
	if (error == VI_SUCCESS_MAX_CNT)
		error = VI_SUCCESS;
Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwevm_WaitForOPC
 * Purpose:  This function waits for the instrument to complete the
 *           execution of all pending operations. This function is a
 *           wrapper for the WaitForOPCCallback. It can be called from
 *           other instrument driver functions.
 *
 *           The maxTime parameter specifies the maximum time to wait for
 *           operation complete in milliseconds.
 *
 *           Note:  Call this function only when the session is locked.
 *****************************************************************************/
ViStatus rscmwevm_WaitForOPC (ViSession instrSession, ViUInt32 maxTime)
{
    ViStatus    error = VI_SUCCESS;
    
    if (!Rs_Simulating(instrSession))
        {
        ViInt32  oldOPCTimeout;

        checkErr( Rs_GetAttribute (instrSession, NULL, RSCMWEVM_ATTR_OPC_TIMEOUT, 0,
                                   sizeof (oldOPCTimeout), &oldOPCTimeout));

        Rs_SetAttribute (instrSession, NULL, RSCMWEVM_ATTR_OPC_TIMEOUT, 0, &maxTime);

        error = rscmwevm_WaitForOPCCallback (instrSession);

        Rs_SetAttribute (instrSession, NULL, RSCMWEVM_ATTR_OPC_TIMEOUT, 0, &oldOPCTimeout);

        viCheckErr( error);
        }
Error:
    return error;
}
 
/*===========================================================================*/
/* Function: String Index                                                    */
/* Purpose:  Returns the index of string in string array                     */
/*===========================================================================*/
ViInt32 rscmwevm_StringIndex(ViString array[], ViChar buff[])
{
    ViInt32 index = 0;

    while (array[index]){
        if (!strcmp(buff, array[index]))
            break; 
        index++;    
    }        
    /* If found string is not found returns -1. */
    if (!array[index]) return -1;

    return index;
}

/*===========================================================================*/
/* Function: Long Signed Integer Value Out Of Range - ViInt32                */
/* Purpose:  This function checks a long signed integer value to see if it   */
/*           lies between a minimum and maximum value.  If the value is out  */
/*           of range, the return value is VI_TRUE, otherwise the return     */
/*           value is VI_FALSE.                                              */
/*===========================================================================*/
ViStatus rscmwevm_invalidViInt32Range (ViSession instrSession, ViInt32 val, ViInt32 min, ViInt32 max)
{
    return (Rs_RangeChecking (instrSession) && (ViBoolean)(val < min || val > max)) ? RS_ERROR_INVALID_PARAMETER : VI_SUCCESS;
}

/*===========================================================================*/
/* Function: Long Signed Integer Value Out Of Range - ViInt32                */
/* Purpose:  This function checks a long signed integer value to see if it   */
/*           lies between a minimum and maximum value.  If the value is out  */
/*           of range, the return value is VI_TRUE, otherwise the return     */
/*           value is VI_FALSE.                                              */
/*===========================================================================*/
ViStatus rscmwevm_invalidViUInt16Range (ViSession instrSession, ViUInt16 val, ViUInt16 min, ViUInt16 max)
{
    return (Rs_RangeChecking (instrSession) && (ViBoolean)(val < min || val > max)) ? RS_ERROR_INVALID_PARAMETER : VI_SUCCESS;
}

/*===========================================================================*/
/* Function: Real (Double) Value Out Of Range - ViReal64                     */
/* Purpose:  This function checks a real (double) value to see if it lies    */
/*           between a minimum and maximum value.  If the value is out of    */
/*           range, the return value is VI_TRUE, otherwise the return value  */
/*           is VI_FALSE.                                                    */
/*===========================================================================*/
ViStatus rscmwevm_invalidViReal64Range (ViSession instrSession, ViReal64 val, ViReal64 min, ViReal64 max)
{
    return (Rs_RangeChecking (instrSession) && (ViBoolean)(val < min || val > max)) ? RS_ERROR_INVALID_PARAMETER : VI_SUCCESS;
}
/*****************************************************************************
 * Function: rscmwevm_CheckBeforeRead
 * Purpose:  This function waits for the instrument to complete the
 *           execution of all pending operations and returns data. 
 *
 *           The maxTime parameter specifies the maximum time to wait for
 *           operation complete in milliseconds.
 *
 *           Note:  Call this function only when the session is locked.
 *****************************************************************************/
ViStatus rscmwevm_CheckBeforeRead (ViSession instrSession, ViUInt32 maxTime)
{
    ViStatus    error = VI_SUCCESS;
    ViUInt16    response    = 0;
    ViUInt32    counter     = 0;
    ViUInt16    intfc   = VI_INTF_GPIB;
 
    viCheckErr( viGetAttribute (instrSession, VI_ATTR_INTF_TYPE, &intfc));

    /* intfc specific operations */
    switch (intfc)
        {
        case VI_INTF_ASRL: /* Serial intfc */

            /* Not supported */

        break;
        default: /* Default case */

            /* Check STB for errors. */
            do
            {
                error = viReadSTB (instrSession, &response);

                Rs_Delay (0.01);
                counter++;

                if (counter >= maxTime)
                    return VI_ERROR_TMO;

                /* Wait while STB is non zero value. Only Error/Event Queue
                   and ESB bits are taken into consideration. */
            
            } while ((response & 0x14) == 0);

            /* (check Error(Event) Queue bit in STB) */
            /* sometimes instrument sets both bits, but error queue is empty */
            return (((response & 0x4) != 0) && ((response & 0x10) == 0)) ? RS_ERROR_INSTRUMENT_STATUS : error;
        }

Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwevm_instanceRepCap
 * Purpose:  This function checks instance repeated capability and 
 *           creates proper string.
 *****************************************************************************/
ViStatus rscmwevm_instanceRepCap (ViSession instrSession, ViInt32 instance, ViChar rep_cap[])
{
    ViStatus    error   = VI_SUCCESS;
    
    viCheckParm (rscmwevm_invalidViInt32Range (instrSession, instance, 1, 16), 2, "Instance");
    sprintf (rep_cap, "i%d", instance);
Error:    
    return error;
}

/*****************************************************************************
 * Function: rscmwevm_instance_mevMeasRepCap
 * Purpose:  This function checks mevMeas repeated capability and 
 *           creates proper string.
 *****************************************************************************/
ViStatus rscmwevm_instance_mevMeasRepCap (ViSession instrSession, 
                                        ViInt32 instance, 
                                        ViInt32 measurement, 
                                        ViChar rep_cap[])
{
    ViStatus    error   = VI_SUCCESS;
    ViString      mevMeasArr[] = {"mevMeasPVT","mevMeasMOD","mevMeasSMOD","mevMeasSSW"};
    
    viCheckParm (rscmwevm_invalidViInt32Range (instrSession, instance, 1, 4), 2, "Instance");
    viCheckParm (rscmwevm_invalidViInt32Range (instrSession, measurement, 0, 3), 3, "Measurement");
    
    sprintf (rep_cap, "i%d,%s", instance, mevMeasArr[measurement]);
Error:    
    return error;
}

/*****************************************************************************
 * Function: rscmwevm_QueryMeasStatus
 * Purpose:  This function queries measurement status
 *****************************************************************************/
ViStatus _VI_FUNC rscmwevm_QueryMeasStatus(
    ViSession   instrSession,
    ViString    command,
    ViInt32*    mainState,
    ViInt32*    syncState,
    ViInt32*    resourcesState
    )
{
    ViStatus error = VI_SUCCESS;
    ViChar   response [150] = "";
    ViChar*  p2buf;
    ViString mainStateArr[] = {"OFF","RDY","RUN",NULL};
    ViString syncStateArr[] = {"PEND","ADJ","INV",NULL};
    ViString resStateArr[] = {"QUE","ACT","INV",NULL};

    strcpy (response, command);
    strcat (response, "\n");
    
    checkErr (viWrite (instrSession, (ViBuf) response, (ViUInt32) strlen (response), NULL));
    checkErr (viRead (instrSession, (ViBuf) response, 150, NULL));
    
    p2buf = strtok (response, ",");
    if (p2buf == NULL)
        return RSCMWEVM_ERROR_INCORRECT_STATE;
    *mainState = rscmwevm_StringIndex (mainStateArr,p2buf);
    if (*mainState < 0)
        return RSCMWEVM_ERROR_INCORRECT_STATE;

    p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        return RSCMWEVM_ERROR_INCORRECT_STATE;
    *syncState = rscmwevm_StringIndex (syncStateArr,p2buf);
    if (*syncState < 0)
        return RSCMWEVM_ERROR_INCORRECT_STATE;

    p2buf = strtok (NULL, ",\n");
    if (p2buf == NULL)
        return RSCMWEVM_ERROR_INCORRECT_STATE;
    *resourcesState = rscmwevm_StringIndex (resStateArr,p2buf);
    if (*resourcesState < 0)
        return RSCMWEVM_ERROR_INCORRECT_STATE;

Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwevm_GetMeasTrace
 * Purpose:  This function queries measurement data trace
 *****************************************************************************/
ViStatus _VI_FUNC rscmwevm_GetMeasTrace(
    ViSession   instrSession,
    ViString    command,
    ViInt32     timeout,
    ViInt32     arraySize,
    ViInt32*    reliability,
    ViReal64    result[],
    ViInt32     *returnedValues
    )
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer [150] = "";
    ViChar*  ext_buf=NULL;
    ViChar*  p2buf;
    ViUInt32 ret_cnt = 0;
    ViInt32  i = 0;

    checkErr (Rs_ClearBeforeRead(instrSession));     

    strcpy (buffer, command);
    strcat (buffer, ";*OPC\n");
    checkErr (viWrite (instrSession, (ViBuf) buffer, (ViUInt32) strlen (buffer), NULL));
    
    checkErr (rscmwevm_CheckBeforeRead (instrSession, timeout));
    checkErr (Rs_ReadDataUnknownLength(instrSession, &ext_buf, &ret_cnt));

    p2buf = strtok (ext_buf, ",");
    if (p2buf == NULL)
        return RSCMWEVM_ERROR_INCORRECT_RESPONSE;
    if (reliability != NULL)
    *reliability = atol (p2buf);

    p2buf = strtok (NULL, ",\n");
    while (p2buf != NULL)
    {
        if (i<arraySize)
        {
            result[i++] = rscmwevm_atof (p2buf);
        }   
        p2buf = strtok (NULL, ",\n");
    }
    if (returnedValues) *returnedValues=i;

    checkErr( rscmwevm_CheckStatus (instrSession));
Error:
    return error;
}
/*****************************************************************************
 * Function: rscmwevm_GetMeasTraceLimits
 * Purpose:  This function queries limits measurement data
 *****************************************************************************/
ViStatus _VI_FUNC rscmwevm_GetMeasTraceLimits(
    ViSession   instrSession,
    ViString    command,
    ViInt32     timeout,
    ViInt32     arraySize,
    ViInt32*    reliability,
    ViInt32     result[],
    ViInt32     *returnedValues
    )
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer [150] = "";
    ViChar*  ext_buf=NULL;
    ViChar*  p2buf;
    ViUInt32 ret_cnt = 0;
    ViInt32  i = 0;

    checkErr (Rs_ClearBeforeRead(instrSession));     

    strcpy (buffer, command);
    strcat (buffer, ";*OPC\n");
    checkErr (viWrite (instrSession, (ViBuf) buffer, (ViUInt32) strlen (buffer), NULL));
    
    checkErr (rscmwevm_CheckBeforeRead (instrSession, timeout));
    checkErr (Rs_ReadDataUnknownLength(instrSession, &ext_buf, &ret_cnt));

    p2buf = strtok (ext_buf, ",");
    if (p2buf == NULL)
        return RSCMWEVM_ERROR_INCORRECT_RESPONSE;
    if (reliability != NULL)
    *reliability = atol (p2buf);

    p2buf = strtok (NULL, ",\n");
    while (p2buf != NULL)
    {
        if (i<arraySize)
        {
            result[i++] = rscmwevm_strCode(p2buf, arrayCodes);
        }   
        p2buf = strtok (NULL, ",\n");
    }
    if (returnedValues) *returnedValues=i;

    checkErr( rscmwevm_CheckStatus (instrSession));
Error:
    return error;
}



/*****************************************************************************
 * Function: rscmwevm_GetMeas
 * Purpose:  This function queries measurement data
 *****************************************************************************/
ViStatus _VI_FUNC rscmwevm_GetMeas(
    ViSession   instrSession,
    ViString    command,
    ViInt32     timeout,
    ViInt32*    reliability,
    ViReal64    result[]
    )
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer [150] = "";
    ViChar*  ext_buf=NULL;
    ViChar*  p2buf;
    ViUInt32 ret_cnt = 0;
    ViInt32  i = 0;

    checkErr (Rs_ClearBeforeRead(instrSession));     

    strcpy (buffer, command);
    strcat (buffer, ";*OPC\n");
    checkErr (viWrite (instrSession, (ViBuf) command, (ViUInt32) strlen (command), NULL));
    
    checkErr (rscmwevm_CheckBeforeRead (instrSession, timeout));
    checkErr (Rs_ReadDataUnknownLength(instrSession, &ext_buf, &ret_cnt));

    p2buf = strtok (ext_buf, ",");
    if (p2buf == NULL)
        return RSCMWEVM_ERROR_INCORRECT_RESPONSE;
    if (reliability != NULL)
    *reliability = atol (p2buf);

    p2buf = strtok (NULL, ",\n");
    while (p2buf != NULL)
    {
        result[i++] = rscmwevm_atof (p2buf);
        p2buf = strtok (NULL, ",\n");
    }
    
    checkErr( rscmwevm_CheckStatus (instrSession));
Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwevm_GetMeasList
 * Purpose:  This function queries limits measurement data
 *****************************************************************************/
ViStatus _VI_FUNC rscmwevm_GetMeasList(
    ViSession   instrSession,
    ViString    command,
    ViInt32     timeout,
    ViInt32     arraySize,
    ViInt32*    reliability,
    ViInt32     *segmentReliability,
    ViReal64     results[],
    ViInt32     *returnedValues
    )
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer [150] = "";
    ViChar*  ext_buf=NULL;
    ViChar*  p2buf;
    ViUInt32 ret_cnt = 0;
    ViInt32  i = 0;
    

    checkErr (Rs_ClearBeforeRead(instrSession));     

    strcpy (buffer, command);
    strcat (buffer, ";*OPC\n");
    checkErr (viWrite (instrSession, (ViBuf) command, (ViUInt32) strlen (command), NULL));
    
    checkErr (rscmwevm_CheckBeforeRead (instrSession, timeout));
    checkErr (Rs_ReadDataUnknownLength(instrSession, &ext_buf, &ret_cnt));

    p2buf = strtok (ext_buf, ",");
    if (p2buf == NULL)
        return RSCMWEVM_ERROR_INCORRECT_RESPONSE;
    if (reliability != NULL)
    *reliability = atol (p2buf);

    p2buf = strtok (NULL, ",\n");
    
    *segmentReliability = rscmwevm_atol (p2buf);

    p2buf = strtok (NULL, ",\n");
    
    while (p2buf != NULL)
    {
        if (i<arraySize)
        {
            results[i++] = rscmwevm_atof (p2buf);
        }   
        p2buf = strtok (NULL, ",\n");
    }
    if (returnedValues) *returnedValues=i;
 
    checkErr( rscmwevm_CheckStatus (instrSession));
Error:
    return error;
} 


/*****************************************************************************
 * Function: rscmwevm_GetMeasListState
 * Purpose:  This function queries limits measurement data
 *****************************************************************************/
ViStatus _VI_FUNC rscmwevm_GetMeasListState(
    ViSession   instrSession,
    ViString    command,
    ViInt32     timeout,
    ViInt32     arraySize,
    ViInt32*    reliability,
    ViInt32     *segmentReliability,
    ViInt32     results[],
    ViInt32     *returnedValues
    )

{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer [150] = "";
    ViChar*  ext_buf=NULL;
    ViChar*  p2buf;
    ViUInt32 ret_cnt = 0;
    ViInt32  i = 0;
    ViString ResultStateArr[] = {"INV","ACT","IAC",NULL};

    checkErr (Rs_ClearBeforeRead(instrSession));     
    strcpy (buffer, command);
    strcat (buffer, ";*OPC\n");
    checkErr (viWrite (instrSession, (ViBuf) command, (ViUInt32) strlen (command), NULL));
    
    checkErr (rscmwevm_CheckBeforeRead (instrSession, timeout));
    checkErr (Rs_ReadDataUnknownLength(instrSession, &ext_buf, &ret_cnt));

    p2buf = strtok (ext_buf, ",");
    if (p2buf == NULL)
        return RSCMWEVM_ERROR_INCORRECT_RESPONSE;
    if (reliability != NULL)
    *reliability = atol (p2buf);

    p2buf = strtok (NULL, ",\n");
    
    *segmentReliability = rscmwevm_atol (p2buf);

    p2buf = strtok (NULL, ",\n");
    
    while (p2buf != NULL)
    {
        if (i<arraySize)
        {
            results[i++] = rscmwevm_StringIndex (ResultStateArr,p2buf);
        }   
        p2buf = strtok (NULL, ",\n");
    }
    if (returnedValues) *returnedValues=i;
 
    checkErr( rscmwevm_CheckStatus (instrSession));
Error:
    return error;
} 

/*****************************************************************************
 * Function: rscmwevm_GetMeasListAll
 * Purpose:  This function queries limits measurement data
 *****************************************************************************/
ViStatus _VI_FUNC rscmwevm_GetMeasListAll(
    ViSession   instrSession,
    ViString    command,
    ViInt32     timeout,
    ViInt32     ActiveSegmentsCount,
    ViInt32     arraySize,
    ViInt32*    reliability,
    ViInt32     segmentReliability[],
    ViReal64    results[],
    ViInt32     *returnedValues
    )
{
    
   ViStatus error = VI_SUCCESS;
    ViChar   buffer [150] = "";
    ViChar*  ext_buf=NULL;
    ViChar*  p2buf;
    ViUInt32 ret_cnt = 0;
    ViInt32  i = 0,
             n = 0;
    

   	checkErr (Rs_ClearBeforeRead(instrSession));     

    strcpy (buffer, command);
    strcat (buffer, ";*OPC\n");
    checkErr (viWrite (instrSession, (ViBuf) command, (ViUInt32) strlen (command), NULL));
    
    checkErr (rscmwevm_CheckBeforeRead (instrSession, timeout));
    checkErr (Rs_ReadDataUnknownLength(instrSession, &ext_buf, &ret_cnt));

    p2buf = strtok (ext_buf, ",");
    if (p2buf == NULL)
        return RSCMWEVM_ERROR_INCORRECT_RESPONSE;
    if (reliability != NULL)
    *reliability = atol (p2buf);

    p2buf = strtok (NULL, ",\n");
    
    while (p2buf != NULL && i < ActiveSegmentsCount)
    {
        segmentReliability[i] = rscmwevm_atol (p2buf);
        p2buf = strtok (NULL, ",\n");
            
        for (n = 0; n < arraySize; n++);
        {
            results[arraySize*i + n] = rscmwevm_atof (p2buf);
            p2buf = strtok (NULL, ",\n");
        }
        i++;
    }
    if (returnedValues) *returnedValues=i;
 
    checkErr( rscmwevm_CheckStatus (instrSession));
Error:
    return error;   
}

/*****************************************************************************
 * Function: rscmwevm_QueryMeasListAll
 * Purpose:  This function queries limits measurement data
 *****************************************************************************/
ViStatus _VI_FUNC rscmwevm_QueryMeasListAll(
    ViSession   instrSession,
    ViString    command,
    ViInt32     timeout,
    ViInt32     ActiveSegmentsCount,
    ViInt32     arraySize,
    ViInt32*    reliability,
    ViInt32     segmentReliability[],
    ViInt32     results[],
    ViInt32     *returnedValues
    )
{
    
   ViStatus error = VI_SUCCESS;
    ViChar   buffer [150] = "";
    ViChar*  ext_buf=NULL;
    ViChar*  p2buf;
    ViString ResultStateArr[] = {"OK","ULEU","ULEL",NULL};  
    ViUInt32 ret_cnt = 0;
    ViInt32  i = 0,
             n = 0;
    

    checkErr (Rs_ClearBeforeRead(instrSession));     

    strcpy (buffer, command);
    strcat (buffer, ";*OPC\n");
    checkErr (viWrite (instrSession, (ViBuf) command, (ViUInt32) strlen (command), NULL));
    
    checkErr (rscmwevm_CheckBeforeRead (instrSession, timeout));
    checkErr (Rs_ReadDataUnknownLength(instrSession, &ext_buf, &ret_cnt));

    p2buf = strtok (ext_buf, ",");
    if (p2buf == NULL)
        return RSCMWEVM_ERROR_INCORRECT_RESPONSE;
    if (reliability != NULL)
    *reliability = atol (p2buf);

    p2buf = strtok (NULL, ",\n");
    
    while (p2buf != NULL && i < ActiveSegmentsCount)
    {
        segmentReliability[i] = rscmwevm_atol (p2buf);
        p2buf = strtok (NULL, ",\n");
            
        for (n = 0; n < arraySize; n++);
        {
            results[i*arraySize + n] = rscmwevm_StringIndex (ResultStateArr,p2buf);
            p2buf = strtok (NULL, ",\n");
        }
        i++;
    }
    if (returnedValues) *returnedValues=i;
 
 
    checkErr( rscmwevm_CheckStatus (instrSession));
Error:
    return error;   
}

/*****************************************************************************
 * Function: rscmwevm_GetMeasListStateAll
 * Purpose:  This function queries limits measurement data
 *****************************************************************************/
ViStatus _VI_FUNC rscmwevm_GetMeasListStateAll(
    ViSession   instrSession,
    ViString    command,
    ViInt32     timeout,
    ViInt32     ActiveSegmentsCount,
    ViInt32     arraySize,
    ViInt32*    reliability,
    ViInt32     segmentReliability[],
    ViInt32     results[],
    ViInt32     *returnedValues
    )
{
    
   ViStatus error = VI_SUCCESS;
    ViChar   buffer [150] = "";
    ViChar*  ext_buf=NULL;
    ViChar*  p2buf;
    ViUInt32 ret_cnt = 0;
    ViInt32  i = 0,
             n = 0;
    ViString ResultStateArr[] = {"INV","ACT","IAC",NULL};
	
    checkErr (Rs_ClearBeforeRead(instrSession));     

    strcpy (buffer, command);
    strcat (buffer, ";*OPC\n");
    checkErr (viWrite (instrSession, (ViBuf) command, (ViUInt32) strlen (command), NULL));
    
    checkErr (rscmwevm_CheckBeforeRead (instrSession, timeout));
    checkErr (Rs_ReadDataUnknownLength(instrSession, &ext_buf, &ret_cnt));

    p2buf = strtok (ext_buf, ",");
    if (p2buf == NULL)
        return RSCMWEVM_ERROR_INCORRECT_RESPONSE;
    if (reliability != NULL)
    *reliability = atol (p2buf);

    p2buf = strtok (NULL, ",\n");
    
    while (p2buf != NULL && i < ActiveSegmentsCount)
    {
        segmentReliability[i] = rscmwevm_atol (p2buf);
        p2buf = strtok (NULL, ",\n");
            
        for (n = 0; n < arraySize; n++);
        {
            results[i*arraySize + n] = rscmwevm_StringIndex (ResultStateArr,p2buf);
            p2buf = strtok (NULL, ",\n");
        }
        i++;
    }
    if (returnedValues) *returnedValues=i;
 
    checkErr( rscmwevm_CheckStatus (instrSession));
Error:
    return error;   
}


/*****************************************************************************
 * Function: rscmwevm_GetMeasTraceLimitsAll
 * Purpose:  This function queries limits measurement data
 *****************************************************************************/
ViStatus _VI_FUNC rscmwevm_GetMeasTraceLimitsAll(
    ViSession   instrSession,
    ViString    command,
    ViInt32     timeout,
    ViInt32     arraySize,
    ViInt32*    reliability,
    ViInt32     *segmentReliability,
    ViInt32     result[],
    ViInt32     *returnedValues
    )
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer [150] = "";
    ViChar*  ext_buf=NULL;
    ViChar*  p2buf;
    ViUInt32 ret_cnt = 0;
    ViInt32  i = 0;
    

    checkErr (Rs_ClearBeforeRead(instrSession));     

    strcpy (buffer, command);
    strcat (buffer, ";*OPC\n");
    checkErr (viWrite (instrSession, (ViBuf) command, (ViUInt32) strlen (command), NULL));
    
    checkErr (rscmwevm_CheckBeforeRead (instrSession, timeout));
    checkErr (Rs_ReadDataUnknownLength(instrSession, &ext_buf, &ret_cnt));

    p2buf = strtok (ext_buf, ",");
    if (p2buf == NULL)
        return RSCMWEVM_ERROR_INCORRECT_RESPONSE;
    if (reliability != NULL)
    *reliability = atol (p2buf);

    p2buf = strtok (NULL, ",\n");
    
    *segmentReliability = rscmwevm_atol (p2buf);

    p2buf = strtok (NULL, ",\n");
    
    while (p2buf != NULL)
    {
        if (i<arraySize)
        {
            result[i++] = rscmwevm_strCode(p2buf, arrayCodes);
        }   
        p2buf = strtok (NULL, ",\n");
    }
    if (returnedValues) *returnedValues=i;

    checkErr( rscmwevm_CheckStatus (instrSession));
Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwevm_GetCatalog
 * Purpose:  This function queries catalog data
 *****************************************************************************/
ViStatus _VI_FUNC rscmwevm_GetCatalog(
    ViSession   instrSession,
    ViString    command,
    ViInt32     timeout,
    ViInt32     arraySize,
    ViChar      catalog[]
    )
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer [150] = "";
    ViChar*  ext_buf=NULL;
    ViUInt32 ret_cnt = 0;

    checkErr (Rs_ClearBeforeRead(instrSession));     

    strcpy (buffer, command);
    strcat (buffer, ";*OPC\n");
    checkErr (viWrite (instrSession, (ViBuf) command, (ViUInt32) strlen (command), NULL));
    
    checkErr (rscmwevm_CheckBeforeRead (instrSession, timeout));
    checkErr (Rs_ReadDataUnknownLength(instrSession, &ext_buf, &ret_cnt));
    strncpy (catalog, ext_buf, arraySize);

    checkErr( rscmwevm_CheckStatus (instrSession));
Error:
    if (ext_buf != NULL)
        free (ext_buf);
    return error;
}

/*****************************************************************************
 * Function: rscmwevm_GetMeasTraceStates
 * Purpose:  This function queries limits measurement data
 *****************************************************************************/
ViStatus _VI_FUNC rscmwevm_GetMeasTraceStates(
    ViSession   instrSession,
    ViString    command,
    ViInt32     timeout,
    ViInt32     arraySize,
    ViInt32*    reliability,
    ViInt32     result[],
    ViInt32     *returnedValues
    )
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer [150] = "";
    ViChar*  ext_buf=NULL;
    ViChar*  p2buf;
    ViUInt32 ret_cnt = 0;
    ViInt32  i = 0;
    ViString arrayTraceCodes[] = {"NAV","ACT","INAC",NULL};

    checkErr (Rs_ClearBeforeRead(instrSession));     

    strcpy (buffer, command);
    strcat (buffer, ";*OPC\n");
    checkErr (viWrite (instrSession, (ViBuf) buffer, (ViUInt32) strlen (buffer), NULL));
    
    checkErr (rscmwevm_CheckBeforeRead (instrSession, timeout));
    checkErr (Rs_ReadDataUnknownLength(instrSession, &ext_buf, &ret_cnt));

    p2buf = strtok (ext_buf, ",");
    if (p2buf == NULL)
        return RSCMWEVM_ERROR_INCORRECT_RESPONSE;
    if (reliability != NULL)
    *reliability = atol (p2buf);

    p2buf = strtok (NULL, ",\n");
    while (p2buf != NULL)
    {
        if (i<arraySize)
        {
            result[i++] = rscmwevm_strCode(p2buf, arrayTraceCodes);
        }   
        p2buf = strtok (NULL, ",\n");
    }
    if (returnedValues) *returnedValues=i;

    checkErr( rscmwevm_CheckStatus (instrSession));
Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwevm_atof
 * Purpose:  This function converts a string to float number. Instrument
 *           may return also string indicating invalid value
 *****************************************************************************/
ViReal64 rscmwevm_atof (ViChar *p2buf)
{
    ViReal64 value = 0.0;
    ViInt32  returned = 0;
    
    returned = sscanf (p2buf, "%le", &value);
    
    if (returned == 0)
        value = RSCMW_NAN;
    
    return value;
}
/*****************************************************************************
 * Function: rscmwevm_strCode
 * Purpose:  This function converts a string to int enumeration value.
 *****************************************************************************/
ViInt32 rscmwevm_strCode(ViChar *pBuffer, ViString arrayOfCodes[])
{
   ViInt32 nIndex = 0;
   ViString pCode = arrayOfCodes[nIndex];

   while ( pCode != NULL )
   {
      ViChar *pPos = strstr(pBuffer, pCode);
      if ( pPos != NULL )
      {
         return nIndex;
      }
      nIndex++;

      pCode = arrayOfCodes[nIndex];
   }

   return -1;
}

/*****************************************************************************
 * Function: rscmwevm_atof
 * Purpose:  This function converts a string to float number. Instrument
 *           may return also string indicating invalid value
 *****************************************************************************/
ViInt32 rscmwevm_atol (ViChar *p2buf)
{
    ViInt32 value = 0;
    ViInt32 returned = 0;
    
    returned = sscanf (p2buf, "%ld", &value);
    
    if (returned == 0)
        value = 0xFFFFFFFF;
    
    return value;
}

/*****************************************************************************
 * Function: rscmwevm_hex_ReadCallback
 * Purpose:  This function overrides standard calback funtion.
 *****************************************************************************/
ViStatus rscmwevm_hex_ReadCallback(ViSession instrSession, ViConstString repCapName, ViAttr attributeId, ViInt32 bufSize, void *value)
{
    RsSessionPropertiesPtr  sessionProperties = Rs_ViSession (instrSession);
    ViStatus    error = VI_SUCCESS;
    ViInt32     idx             = 0;
    ViChar      *cmd            = NULL,
                *buffer         = NULL;
	bufSize;

    viCheckErr (Rs_GetAttributeIndex (instrSession, attributeId, &idx));

    /* If no command available, exit the function */
    if (sessionProperties -> attr[idx].command == NULL)
        return VI_SUCCESS;

    /* Check if attribute uses repeated capabilities */
    if (sessionProperties -> attr[idx].usercaps == VI_TRUE)
        {
        if (!repCapName)
            viCheckErr (RS_ERROR_INVALID_REPEATED_CAPABILITY_NAME);

        if (strlen (repCapName) == 0)
            viCheckErr (RS_ERROR_INVALID_REPEATED_CAPABILITY_NAME);
        }

    /* Build the command string */
    viCheckErr (Rs_BuildCommandString (instrSession, attributeId, idx, repCapName, &cmd));  

   /* --- Attribute data type is used for VISA I/O --- */
    switch (sessionProperties -> attr[idx].dataType)
    {
        case RS_VAL_INT32:
            if ((sessionProperties -> attr[idx].access==RS_VAL_READ_ONLY)) 
            {
                viCheckErr (viPrintf(instrSession, "%s\n", cmd));
            }
            else
            {
                viCheckErr (viPrintf(instrSession, "%s?\n", cmd));
            }
            viCheckErr (viScanf(instrSession, "#H%X", value));
            break;
        default:
            viCheckErr (RS_ERROR_INVALID_TYPE);
    }

Error:

    if (buffer)
        free (buffer);

    if (cmd)
        free (cmd);

    return error;
};

/*****************************************************************************
 * Function: rscmwevm_hex_WriteCallback
 * Purpose:  This function overrides standard calback funtion.
 *****************************************************************************/
ViStatus rscmwevm_hex_WriteCallback(ViSession instrSession, ViConstString repCapName, ViAttr attributeId, void *value)
{
    RsSessionPropertiesPtr  sessionProperties = Rs_ViSession (instrSession);
    ViStatus    error = VI_SUCCESS;
    ViInt32     idx                 = 0;
    ViChar      *cmd                = NULL;
    
    viCheckErr (Rs_GetAttributeIndex (instrSession, attributeId, &idx));

    /* If no command available, exit the function */
    if (sessionProperties -> attr[idx].command == NULL)
        return VI_SUCCESS;

    /* Check if attribute uses repeated capabilities */
    if (sessionProperties -> attr[idx].usercaps == VI_TRUE)
        {
        if (!repCapName)
            viCheckErr (RS_ERROR_INVALID_REPEATED_CAPABILITY_NAME);

        if (strlen (repCapName) == 0)
            viCheckErr (RS_ERROR_INVALID_REPEATED_CAPABILITY_NAME);
        }

    /* Build the command string */
    viCheckErr (Rs_BuildCommandString (instrSession, attributeId, idx, repCapName, &cmd));  

    switch (sessionProperties -> attr[idx].dataType)
    {
        case RS_VAL_INT32:
            viCheckErr (viPrintf(instrSession, "%s #H%X\n", cmd, *(ViInt32 *)value));
            break;
        default:
            viCheckErr (RS_ERROR_INVALID_TYPE);
    }
Error:

    if (cmd)
        free (cmd);

    return error;

};

/*****************************************************************************
 * Function: rscmwevm_doubleQuotedString_ReadCallback
 * Purpose:  This function overrides standard calback funtion. Reads string 
 *           returned with apostrophes
 *****************************************************************************/
 ViStatus rscmwevm_doubleQuotedString_ReadCallback(ViSession instrSession, ViConstString repCapName, ViAttr attributeId, ViInt32 bufSize, void *value)
{
    RsSessionPropertiesPtr  sessionProperties = Rs_ViSession (instrSession);
    ViStatus    error           = VI_SUCCESS;
    ViUInt32    count           = bufSize;
    ViInt32     idx             = 0;
    ViChar      *cmd            = NULL,
                *buffer         = NULL;

    viCheckErr (Rs_GetAttributeIndex (instrSession, attributeId, &idx));

    /* If no command available, exit the function */
    if (sessionProperties -> attr[idx].command == NULL)
        return VI_SUCCESS;

    /* Check if attribute uses repeated capabilities */
    if (sessionProperties -> attr[idx].usercaps == VI_TRUE)
        {
        if (!repCapName)
            viCheckErr (RS_ERROR_INVALID_REPEATED_CAPABILITY_NAME);

        if (strlen (repCapName) == 0)
            viCheckErr (RS_ERROR_INVALID_REPEATED_CAPABILITY_NAME);
        }

    /* Build the command string */
    viCheckErr (Rs_BuildCommandString (instrSession, attributeId, idx, repCapName, &cmd));  

    /* --- If the range table for the attribute exists, revert 'command string'
       back to the 'discreteOrMinValue' and return it as attribute value. --- */
    
    /* Range Table Callback */
    if (sessionProperties -> attr[idx].rangeTableCallback)
    {                                                          
        viCheckErr ((sessionProperties -> attr[idx].rangeTableCallback)(instrSession, repCapName, attributeId, &(sessionProperties -> attr[idx].rangeTable)));
    }
    
    if (sessionProperties -> attr[idx].rangeTable)
        if (sessionProperties -> attr[idx].rangeTable -> type == RS_VAL_DISCRETE)
            {
            ViUInt16    i = 0;
            ViChar      *p2string;
            ViInt32     found;

            viCheckAlloc (buffer = (ViChar*) malloc (RS_MAX_MESSAGE_BUF_SIZE));
            count = RS_MAX_MESSAGE_BUF_SIZE;

            if ((sessionProperties -> attr[idx].access==RS_VAL_READ_ONLY)) 
            {
                viCheckErr (viPrintf(instrSession, "%s\n", cmd));
            }
            else
            {
                viCheckErr (viPrintf(instrSession, "%s?\n", cmd));
            }
            viCheckErr (viScanf(instrSession, "\"%#[^\"]\"", &count, buffer));

            /* Go over range table values and check if the command string is present */
            do
                {
                p2string = sessionProperties -> attr[idx].rangeTable -> rangeValues[i].cmdString;

                if (sessionProperties -> attr[idx].rangeTable -> rangeValues[i].cmdString == RS_RANGE_TABLE_END_STRING)
                    return RS_ERROR_INVALID_VALUE;
#ifdef RS_LONG_RESPONSE            
                if ((strlen (p2string) <= 3) || (strlen (buffer) > 4))
                    found = strcmp (buffer,p2string);
                else
                    found = strncmp (buffer, p2string, strlen (p2string));
#else
                found = strcmp (buffer,p2string);
#endif
                if (found == 0)
                    break;

                i++;

                } while (i);

            /* Return value from range table */
            switch (sessionProperties -> attr[idx].dataType)
                {
                case RS_VAL_INT32:
                    *(ViInt32 *)value = (ViInt32) sessionProperties -> attr[idx].rangeTable -> rangeValues[i].discreteOrMinValue;
                    break;
                case RS_VAL_REAL64:
                    *(ViReal64 *)value = sessionProperties -> attr[idx].rangeTable -> rangeValues[i].discreteOrMinValue;
                    break;
                case RS_VAL_STRING:
                case RS_VAL_BOOLEAN:
                case RS_VAL_ADDR:
                case RS_VAL_SESSION:
                case RS_VAL_EVENT:
                case RS_VAL_UNKNOWN_TYPE:
                default:
                    viCheckErr (RS_ERROR_INVALID_TYPE);
                }
            
            goto Error;
            }

        /* --- Attribute data type is used for VISA I/O --- */
        switch (sessionProperties -> attr[idx].dataType)
            {
            case RS_VAL_STRING:
                if ((sessionProperties -> attr[idx].access==RS_VAL_READ_ONLY)) 
            {
                viCheckErr (viPrintf(instrSession, "%s\n", cmd));
            }
            else
            {
                viCheckErr (viPrintf(instrSession, "%s?\n", cmd));
            }
                viCheckErr (viScanf(instrSession, "\"%#[^\"]\"", &count, value));
                break;
            case RS_VAL_INT32:
            case RS_VAL_REAL64:                
            case RS_VAL_BOOLEAN:
            case RS_VAL_ADDR:
            case RS_VAL_SESSION:
            case RS_VAL_EVENT:
            case RS_VAL_UNKNOWN_TYPE:
            default:
                viCheckErr (RS_ERROR_INVALID_TYPE);
            }

Error:

    if (buffer)
        free (buffer);

    if (cmd)
        free (cmd);

    return error;
}

/*****************************************************************************
 * Function: rscmwevm_GetMeasReliabilitiesAll
 * Purpose:  This function queries measurement reliablities
 *****************************************************************************/
ViStatus _VI_FUNC rscmwevm_GetMeasReliabilitiesAll(
    ViSession   instrSession,
    ViString    command,
    ViInt32     timeout,
    ViInt32     ActiveSegmentsCount,
    ViInt32*    reliability,
    ViInt32     segmentReliability[],
    ViInt32     *returnedValues
    )
{
    
   ViStatus error = VI_SUCCESS;
    ViChar   buffer [150] = "";
    ViChar*  ext_buf=NULL;
    ViChar*  p2buf;
    ViUInt32 ret_cnt = 0;
    ViInt32  i = 0;
    

    checkErr (Rs_ClearBeforeRead(instrSession));     

    strcpy (buffer, command);
    strcat (buffer, ";*OPC\n");
    checkErr (viWrite (instrSession, (ViBuf) command, (ViUInt32) strlen (command), NULL));
    
    checkErr (rscmwevm_CheckBeforeRead (instrSession, timeout));
    checkErr (Rs_ReadDataUnknownLength (instrSession, &ext_buf, &ret_cnt));

    p2buf = strtok (ext_buf, ",");
    if (p2buf == NULL)
        return RSCMWEVM_ERROR_INCORRECT_RESPONSE;
    if (reliability != NULL)
    *reliability = atol (p2buf);

    p2buf = strtok (NULL, ",\n");
    
    while (p2buf != NULL && i < ActiveSegmentsCount)
    {
        segmentReliability[i] = rscmwevm_atol (p2buf);
        p2buf = strtok (NULL, ",\n"); 
        i++;
    }
    if (returnedValues) *returnedValues=i;
 
    checkErr( rscmwevm_CheckStatus (instrSession));
Error:
    return error;   
}

/*****************************************************************************
 * Function: rscmwevm_GetMeasTraceState
 * Purpose:  This function queries measurement data trace state
 *****************************************************************************/
 ViStatus _VI_FUNC rscmwevm_GetMeasTraceState(
    ViSession   instrSession,
    ViString    command,
    ViInt32     timeout,
    ViInt32     arraySize,
    ViInt32*    reliability,
    ViInt32     result[],
    ViInt32     *returnedValues
    )
 {
    ViStatus error = VI_SUCCESS;
    ViChar   buffer [150] = "";
    ViChar*  ext_buf=NULL;
    ViChar*  p2buf;
    ViUInt32 ret_cnt = 0;
    ViInt32  i = 0;
    ViString ResultStateArr[] = {"INV","ACT","IAC","ALI",NULL};
    
	checkErr (Rs_ClearBeforeRead(instrSession));     

    strcpy (buffer, command);
    strcat (buffer, ";*OPC\n");
    checkErr (viWrite (instrSession, (ViBuf) command, (ViUInt32) strlen (command), NULL));
    
    checkErr (rscmwevm_CheckBeforeRead (instrSession, timeout));
    checkErr (Rs_ReadDataUnknownLength (instrSession, &ext_buf, &ret_cnt));
 
    p2buf = strtok (ext_buf, ",");
    if (p2buf == NULL)
        return RSCMWEVM_ERROR_INCORRECT_RESPONSE;
    if (reliability != NULL)
    *reliability = atol (p2buf);

    p2buf = strtok (NULL, ",\n");
    while (p2buf != NULL)
    {
        if (i<arraySize)
        {
            result[i++] = rscmwevm_StringIndex (ResultStateArr,p2buf);
        }   
        p2buf = strtok (NULL, ",\n");
    }
    if (returnedValues) *returnedValues=i;

    checkErr( rscmwevm_CheckStatus (instrSession));
Error:
    return error;
 }
