/*****************************************************************************
 *  Rohde&Schwarz CMW500 Wideband Radio Communication Tester instrument driver
 *  EVDO Signaling
 *  VXIpnp Instrument Driver
 *  Original Release: February 2010
 *  By: Martin Krcmar
 *****************************************************************************/

#ifndef __RSCMWEVS_HEADER
#define __RSCMWEVS_HEADER

#include "rsidr_core.h"
#include "rscmwevs_attributes.h"
#include "rscmwevs_utility.h"

#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************
 *- Useful Macros & Constants -----------------------------------------------*
 *****************************************************************************/

#define RSCMWEVS_SIMULATION_ID_QUERY      "Rohde&Schwarz,CMW,123456/789,1.23"  /* Default definition of ID Query Response for simulation */
#define RSCMWEVS_VALID_ID_RESPONSE_STRING "Rohde&Schwarz"      /* Valid response for identification query */
#define RSCMWEVS_SIMULATION_OPT_QUERY     ""      /* Simulated response for *OPT? command */

#define RSCMWEVS_IO_BUFFER_SIZE           1024L   /* I/O buffer size */
#define RSCMWEVS_OPC_TIMEOUT              5000L   /* Maximum time to wait for OPC in milliseconds */
//#define IEEE_488_2_ERROR_MASK             0x3C    /* 488.2 Event Status Register (ESR) Bits */
#define IEEE_488_2_ERROR_MASK             0x4    /* 488.2 STB Bits */   
#define IEEE_488_2_ESE_MASK               0x3D    /* 488.2 Event Status Register (ESE) Bits */
#define IEEE_488_2_SRE_MASK               0x24   /* 488.2 Event Status Register (ESR) Bits */

/****************************************************************************
 *----------------- Instrument Driver Revision Information -----------------*
 ****************************************************************************/

/* Class Driver Identification */

#define RSCMWEVS_CLASS_DRIVER_DESCRIPTION           ""
#define RSCMWEVS_CLASS_DRIVER_PREFIX                ""
#define RSCMWEVS_CLASS_DRIVER_VENDOR                ""
#define RSCMWEVS_CLASS_DRIVER_REVISION              ""
#define RSCMWEVS_CLASS_SPEC_MAJOR_VERSION           1L    /* Class specification major version */
#define RSCMWEVS_CLASS_SPEC_MINOR_VERSION           0L    /* Class specification minor version */

/* Driver Identification */

#define RSCMWEVS_SPECIFIC_DRIVER_DESCRIPTION        ""
#define RSCMWEVS_SPECIFIC_DRIVER_PREFIX             "RSCMWEVS"
#define RSCMWEVS_SPECIFIC_DRIVER_LOCATOR            ""
#define RSCMWEVS_SPECIFIC_DRIVER_VENDOR             ""
#define RSCMWEVS_MAJOR_VERSION                      3L    /* Instrument driver major version          */
#define RSCMWEVS_MINOR_VERSION                      7L   /* Instrument driver minor version          */
#define RSCMWEVS_MINOR_MINOR_VERSION                100L    /* Instrument driver minor minor version    */

/* Driver Capabilities */          

#define RSCMWEVS_SUPPORTED_INSTRUMENT_MODELS        ""    /* Instrument driver supported model(s)     */
#define RSCMWEVS_GROUP_CAPABILITIES                 ""
#define RSCMWEVS_FUNCTION_CAPABILITIES              ""

/****************************************************************************
 *------------------------------ Useful Macros -----------------------------*
 ****************************************************************************/


/****************************************************************************
 *---------------------------- Attribute Defines ---------------------------*
 ****************************************************************************/

    /*- Inherent Instrument Specific Attributes ----------------------------*/

        /* User Options */

#define RSCMWEVS_ATTR_RANGE_CHECK                                           RS_ATTR_RANGE_CHECK                                     /* ViBoolean */
#define RSCMWEVS_ATTR_QUERY_INSTRUMENT_STATUS                               RS_ATTR_QUERY_INSTRUMENT_STATUS                         /* ViBoolean */
#define RSCMWEVS_ATTR_CACHE                                                 RS_ATTR_CACHE                                           /* ViBoolean */
#define RSCMWEVS_ATTR_SIMULATE                                              RS_ATTR_SIMULATE                                        /* ViBoolean */
#define RSCMWEVS_ATTR_RECORD_COERCIONS                                      RS_ATTR_RECORD_COERCIONS                                /* ViBoolean */
#define RSCMWEVS_ATTR_INTERCHANGE_CHECK                                     RS_ATTR_INTERCHANGE_CHECK                               /* ViBoolean */
#define RSCMWEVS_ATTR_SPY                                                   RS_ATTR_SPY                                             /* ViBoolean */
#define RSCMWEVS_ATTR_USE_SPECIFIC_SIMULATION                               RS_ATTR_USE_SPECIFIC_SIMULATION                         /* ViBoolean */

        /* Class Driver Identification */

#define RSCMWEVS_ATTR_CLASS_DRIVER_DESCRIPTION                              RS_ATTR_CLASS_DRIVER_DESCRIPTION                        /* ViString, read-only */
#define RSCMWEVS_ATTR_CLASS_DRIVER_PREFIX                                   RS_ATTR_CLASS_DRIVER_PREFIX                             /* ViString, read-only */
#define RSCMWEVS_ATTR_CLASS_DRIVER_VENDOR                                   RS_ATTR_CLASS_DRIVER_VENDOR                             /* ViString, read-only */
#define RSCMWEVS_ATTR_CLASS_DRIVER_REVISION                                 RS_ATTR_CLASS_DRIVER_REVISION                           /* ViString, read-only */
#define RSCMWEVS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION           /* ViInt32,  read-only */
#define RSCMWEVS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION           /* ViInt32,  read-only */

        /* Driver Identification */

#define RSCMWEVS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                           RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                     /* ViString, read-only */
#define RSCMWEVS_ATTR_SPECIFIC_DRIVER_PREFIX                                RS_ATTR_SPECIFIC_DRIVER_PREFIX                          /* ViString, read-only */
#define RSCMWEVS_ATTR_SPECIFIC_DRIVER_LOCATOR                               RS_ATTR_SPECIFIC_DRIVER_LOCATOR                         /* ViString, read-only */
#define RSCMWEVS_ATTR_SPECIFIC_DRIVER_VENDOR                                RS_ATTR_SPECIFIC_DRIVER_VENDOR                          /* ViString, read-only */
#define RSCMWEVS_ATTR_SPECIFIC_DRIVER_REVISION                              RS_ATTR_SPECIFIC_DRIVER_REVISION                        /* ViString, read-only */
#define RSCMWEVS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION        /* ViInt32,  read-only */
#define RSCMWEVS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION        /* ViInt32,  read-only */

        /* Driver Capabilities */

#define RSCMWEVS_ATTR_SUPPORTED_INSTRUMENT_MODELS                           RS_ATTR_SUPPORTED_INSTRUMENT_MODELS                     /* ViString, read-only */
#define RSCMWEVS_ATTR_GROUP_CAPABILITIES                                    RS_ATTR_GROUP_CAPABILITIES                              /* ViString, read-only */
#define RSCMWEVS_ATTR_FUNCTION_CAPABILITIES                                 RS_ATTR_FUNCTION_CAPABILITIES                           /* ViString, read-only */
#define RSCMWEVS_ATTR_CHANNEL_COUNT                                         RS_ATTR_CHANNEL_COUNT                                   /* ViInt32,  read-only */

        /* Driver Setup */

#define RSCMWEVS_ATTR_DRIVER_SETUP                                          RS_ATTR_DRIVER_SETUP                                    /* ViString            */

        /* Instrument Identification */

#define RSCMWEVS_ATTR_INSTRUMENT_MANUFACTURER                               RS_ATTR_INSTRUMENT_MANUFACTURER                         /* ViString, read-only */
#define RSCMWEVS_ATTR_INSTRUMENT_MODEL                                      RS_ATTR_INSTRUMENT_MODEL                                /* ViString, read-only */
#define RSCMWEVS_ATTR_INSTRUMENT_FIRMWARE_REVISION                          RS_ATTR_INSTRUMENT_FIRMWARE_REVISION                    /* ViString, read-only */

        /* Advanced Session Information */

#define RSCMWEVS_ATTR_IO_RESOURCE_DESCRIPTOR                                RS_ATTR_IO_RESOURCE_DESCRIPTOR                          /* ViString, read-only */
#define RSCMWEVS_ATTR_LOGICAL_NAME                                          RS_ATTR_LOGICAL_NAME                                    /* ViString, read-only */

    /*- Instrument-Specific Attributes -------------------------------------*/

//#define RSCMWEVS_ATTR_ID_QUERY_RESPONSE                                     (RS_SPECIFIC_PUBLIC_ATTR_BASE + 1L)                     /* ViString (Read Only)              */

/* BEGIN GENERATE */
#define RSCMWEVS_ATTR_OUTPUT_EXTERNAL_ATTENUATION                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1
#define RSCMWEVS_ATTR_INPUT_EXTERNAL_ATTENUATION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2
#define RSCMWEVS_ATTR_RF_CARRIER_SETTING                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 115
#define RSCMWEVS_ATTR_RF_CARRIER_CHANNEL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 116
#define RSCMWEVS_ATTR_RF_CARRIER_CHANNEL_OFFSET                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 117
#define RSCMWEVS_ATTR_RF_CARRIER_FORWARD_LINK_FREQUENCY                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 118
#define RSCMWEVS_ATTR_RF_CARRIER_REVERSE_LINK_FREQUENCY                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 119
#define RSCMWEVS_ATTR_RF_CARRIER_POWER_LEVEL                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 120
#define RSCMWEVS_ATTR_RF_CARRIER_PILOT_SETTING                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 121
#define RSCMWEVS_ATTR_RF_CARRIER_ACTIVE_ON_AN                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 122
#define RSCMWEVS_ATTR_RF_CARRIER_ASSIGNED_TO_AT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 123
#define RSCMWEVS_ATTR_RF_CARRIER_PILOT_AT_STATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 124
#define RSCMWEVS_ATTR_SIGNALING_UNIVERSAL_UNIT_HYBRID_MODE_STATE            RS_SPECIFIC_PUBLIC_ATTR_BASE + 174
#define RSCMWEVS_ATTR_DATA_END_TO_END_STATE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 156
#define RSCMWEVS_ATTR_OPERATING_BAND_CLASS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3
#define RSCMWEVS_ATTR_RF_CHANNEL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 4
#define RSCMWEVS_ATTR_QUERY_FORWARD_LINK_FREQUENCY                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 5
#define RSCMWEVS_ATTR_QUERY_REVERSE_LINK_FREQUENCY                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 6
#define RSCMWEVS_ATTR_FREQUENCY_OFFSET                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 7
#define RSCMWEVS_ATTR_SIGNAL_RF_POWER                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 8
#define RSCMWEVS_ATTR_QUERY_RF_SIGNAL_OUTPUT_POWER                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 9
#define RSCMWEVS_ATTR_EXPECTED_POWER_MODE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 10
#define RSCMWEVS_ATTR_MANUAL_EXPECTED_POWER                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 11
#define RSCMWEVS_ATTR_QUERY_RF_SIGNAL_EXPECTED_POWER                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 12
#define RSCMWEVS_ATTR_AWGN_GENERATOR_MODE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 13
#define RSCMWEVS_ATTR_AWGN_GENERATOR_LEVEL                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 14
#define RSCMWEVS_ATTR_REVERSE_POWER_CONTROL_BITS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 15
#define RSCMWEVS_ATTR_REVERSE_POWER_CONTROL_STEP_SIZE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 16
#define RSCMWEVS_ATTR_REVERSE_POWER_CONTROL_RUN                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 218
#define RSCMWEVS_ATTR_POWER_CONTROL_SEGMENT_BITS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 219
#define RSCMWEVS_ATTR_POWER_CONTROL_SEGMENT_LENGTH                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 220
#define RSCMWEVS_ATTR_REVERSE_POWER_CONTROL_REPETITION                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 221
#define RSCMWEVS_ATTR_TIME_SOURCE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 157
#define RSCMWEVS_ATTR_TIME_SYNC_CODE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 158
#define RSCMWEVS_ATTR_APPLY_TIME_AT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 159
#define RSCMWEVS_ATTR_CONFIGURE_LEAP_SECOND_CORRECTION                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 175
#define RSCMWEVS_ATTR_QUERY_LOCAL_TIME_OFFSET                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 176
#define RSCMWEVS_ATTR_ACTIVE_SCENARIO                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 17
#define RSCMWEVS_ATTR_LAYER_FORWARD_TRAFFIC_CHANNEL_INDEX                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 18
#define RSCMWEVS_ATTR_QUERY_LAYER_FORWARD_TRAFFIC_CHANNEL_DATA_RATE         RS_SPECIFIC_PUBLIC_ATTR_BASE + 19
#define RSCMWEVS_ATTR_QUERY_LAYER_FORWARD_TRAFFIC_CHANNEL_SLOTS             RS_SPECIFIC_PUBLIC_ATTR_BASE + 20
#define RSCMWEVS_ATTR_QUERY_LAYER_FORWARD_TRAFFIC_CHANNEL_LOOPBACK_ENABLE   RS_SPECIFIC_PUBLIC_ATTR_BASE + 21
#define RSCMWEVS_ATTR_LAYER_ACK_TRAFFIC_CHANNEL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 22
#define RSCMWEVS_ATTR_LAYER_ACK_TRAFFIC_CHANNEL_MAX_INDEX                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 23
#define RSCMWEVS_ATTR_LAYER_ACK_TRAFFIC_CHANNEL_MIN_INDEX                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 24
#define RSCMWEVS_ATTR_QUERY_LAYER_ACK_TRAFFIC_CHANNEL_DATA_RATE_MAX         RS_SPECIFIC_PUBLIC_ATTR_BASE + 25
#define RSCMWEVS_ATTR_QUERY_LAYER_ACK_TRAFFIC_CHANNEL_DATA_RATE_MIN         RS_SPECIFIC_PUBLIC_ATTR_BASE + 26
#define RSCMWEVS_ATTR_LAYER_FORWARD_TRAFFIC_CHANNEL_A_PACKET_TYPE           RS_SPECIFIC_PUBLIC_ATTR_BASE + 27
#define RSCMWEVS_ATTR_QUERY_LAYER_FORWARD_TRAFFIC_CHANNEL_A_INDEX           RS_SPECIFIC_PUBLIC_ATTR_BASE + 28
#define RSCMWEVS_ATTR_QUERY_LAYER_FORWARD_TRAFFIC_CHANNEL_A_PACKET_SIZE     RS_SPECIFIC_PUBLIC_ATTR_BASE + 29
#define RSCMWEVS_ATTR_QUERY_LAYER_FORWARD_TRAFFIC_CHANNEL_A_DATA_RATE       RS_SPECIFIC_PUBLIC_ATTR_BASE + 30
#define RSCMWEVS_ATTR_QUERY_LAYER_FORWARD_TRAFFIC_CHANNEL_A_SLOTS           RS_SPECIFIC_PUBLIC_ATTR_BASE + 31
#define RSCMWEVS_ATTR_QUERY_LAYER_FORWARD_TRAFFIC_CHANNEL_A_LOOPBACK_ENABLE RS_SPECIFIC_PUBLIC_ATTR_BASE + 32
#define RSCMWEVS_ATTR_LAYER_FORWARD_TRAFFIC_CHANNEL_A_DSC_VALUE             RS_SPECIFIC_PUBLIC_ATTR_BASE + 33
#define RSCMWEVS_ATTR_LAYER_FORWARD_TRAFFIC_CHANNEL_A_DSC_GAIN_BASE         RS_SPECIFIC_PUBLIC_ATTR_BASE + 34
#define RSCMWEVS_ATTR_LAYER_ACK_TRAFFIC_CHANNEL_A                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 35
#define RSCMWEVS_ATTR_QUERY_LAYER_ACK_TRAFFIC_CHANNEL_A                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 36
#define RSCMWEVS_ATTR_LAYER_ACK_CHANNEL_A_MAX_INDEX                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 37
#define RSCMWEVS_ATTR_LAYER_ACK_CHANNEL_A_MIN_INDEX                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 38
#define RSCMWEVS_ATTR_QUERY_LAYER_ACK_CHANNEL_A_DATA_RATE_MAX               RS_SPECIFIC_PUBLIC_ATTR_BASE + 39
#define RSCMWEVS_ATTR_QUERY_LAYER_ACK_CHANNEL_A_DATA_RATE_MIN               RS_SPECIFIC_PUBLIC_ATTR_BASE + 40
#define RSCMWEVS_ATTR_LAYER_ACK_CHANNEL_A_TERMINATION_TARGET                RS_SPECIFIC_PUBLIC_ATTR_BASE + 160
#define RSCMWEVS_ATTR_LAYER_ACK_CHANNEL_A_PREFERED_APPLICATION              RS_SPECIFIC_PUBLIC_ATTR_BASE + 161
#define RSCMWEVS_ATTR_LAYER_FORWARD_TRAFFIC_CHANNEL_B_PACKET_TYPE           RS_SPECIFIC_PUBLIC_ATTR_BASE + 125
#define RSCMWEVS_ATTR_QUERY_LAYER_FORWARD_TRAFFIC_CHANNEL_B_INDEX           RS_SPECIFIC_PUBLIC_ATTR_BASE + 126
#define RSCMWEVS_ATTR_QUERY_LAYER_FORWARD_TRAFFIC_CHANNEL_B_PACKET_SIZE     RS_SPECIFIC_PUBLIC_ATTR_BASE + 127
#define RSCMWEVS_ATTR_QUERY_LAYER_FORWARD_TRAFFIC_CHANNEL_B_DATA_RATE       RS_SPECIFIC_PUBLIC_ATTR_BASE + 128
#define RSCMWEVS_ATTR_QUERY_LAYER_FORWARD_TRAFFIC_CHANNEL_B_SLOTS           RS_SPECIFIC_PUBLIC_ATTR_BASE + 129
#define RSCMWEVS_ATTR_QUERY_LAYER_FORWARD_TRAFFIC_CHANNEL_B_LOOPBACK_ENABLE RS_SPECIFIC_PUBLIC_ATTR_BASE + 130
#define RSCMWEVS_ATTR_LAYER_ACK_TRAFFIC_CHANNEL_B                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 131
#define RSCMWEVS_ATTR_QUERY_LAYER_ACK_TRAFFIC_CHANNEL_B                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 132
#define RSCMWEVS_ATTR_LAYER_ACK_CHANNEL_B_MAX_INDEX                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 133
#define RSCMWEVS_ATTR_LAYER_ACK_CHANNEL_B_MIN_INDEX                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 134
#define RSCMWEVS_ATTR_LAYER_RMCTAP_MIN_PACKET_SIZE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 135
#define RSCMWEVS_ATTR_LAYER_RMCTAP_MAX_PACKET_SIZE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 136
#define RSCMWEVS_ATTR_SESSION_LAYER_INACTIVE_SESSION_TIMEOUT                RS_SPECIFIC_PUBLIC_ATTR_BASE + 41
#define RSCMWEVS_ATTR_SESSION_LAYER_SUBNET_INCLUDED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 42
#define RSCMWEVS_ATTR_CONNECTION_LAYER_PILOT_DROP_THRESHOLD                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 43
#define RSCMWEVS_ATTR_CONNECTION_LAYER_REVERSE_LINK_FRAME_OFFSET            RS_SPECIFIC_PUBLIC_ATTR_BASE + 44
#define RSCMWEVS_ATTR_CONNECTION_LAYER_REDIRECT_OVERHEAD_MESSAGES           RS_SPECIFIC_PUBLIC_ATTR_BASE + 45
#define RSCMWEVS_ATTR_MAC_LAYER_T2P_VALUE_OPTIMIZATION                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 211
#define RSCMWEVS_ATTR_MAC_LAYER_PROTOCOL_DATA_RATE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 46
#define RSCMWEVS_ATTR_MAC_LAYER_PROTOCOL_MAX_PROBE_SEQUENCES                RS_SPECIFIC_PUBLIC_ATTR_BASE + 47
#define RSCMWEVS_ATTR_MAC_LAYER_PROTOCOL_INTER_PROBE_BACKOFF                RS_SPECIFIC_PUBLIC_ATTR_BASE + 48
#define RSCMWEVS_ATTR_MAC_LAYER_PROTOCOL_INTER_PROBE_SEQUENCE_BACKOFF       RS_SPECIFIC_PUBLIC_ATTR_BASE + 49
#define RSCMWEVS_ATTR_QUERY_MAC_LAYER_ACCES_SESSION_SEED                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 50
#define RSCMWEVS_ATTR_MAC_LAYER_PROTOCOL_DRC_COVER                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 51
#define RSCMWEVS_ATTR_MAC_LAYER_PROTOCOL_DRC_LENGTH                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 52
#define RSCMWEVS_ATTR_MAC_LAYER_PROTOCOL_DRC_CHANNEL_GAIN                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 53
#define RSCMWEVS_ATTR_MAC_LAYER_PROTOCOL_ACK_CHANNEL_GAIN                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 54
#define RSCMWEVS_ATTR_MAC_LAYER_SUBTYPE2_PROTOCOL_DRC_COVER                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 55
#define RSCMWEVS_ATTR_MAC_LAYER_SUBTYPE2_PROTOCOL_DRC_LENGTH                RS_SPECIFIC_PUBLIC_ATTR_BASE + 56
#define RSCMWEVS_ATTR_MAC_LAYER_SUBTYPE2_PROTOCOL_DRC_CHANNEL_GAIN          RS_SPECIFIC_PUBLIC_ATTR_BASE + 57
#define RSCMWEVS_ATTR_MAC_LAYER_SUBTYPE2_PROTOCOL_ACK_CHANNEL_GAIN          RS_SPECIFIC_PUBLIC_ATTR_BASE + 58
#define RSCMWEVS_ATTR_NETWORK_RELEASE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 59
#define RSCMWEVS_ATTR_NETWORK_SYSTEM_ID                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 60
#define RSCMWEVS_ATTR_NETWORK_ACCESS_PROPERTIES_PN_OFFSET                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 61
#define RSCMWEVS_ATTR_NETWORK_ACCESS_PROPERTIES_CALL_LOSS_DETECT_TIME       RS_SPECIFIC_PUBLIC_ATTR_BASE + 62
#define RSCMWEVS_ATTR_NETWORK_ACCESS_PROPERTIES_AT_FORWARD_PACKET_ACTIVITY  RS_SPECIFIC_PUBLIC_ATTR_BASE + 63
#define RSCMWEVS_ATTR_NETWORK_ACCESS_PROPERTIES_IRAT_ENABLED                RS_SPECIFIC_PUBLIC_ATTR_BASE + 185
#define RSCMWEVS_ATTR_NETWORK_SECTOR_COLOR_CODE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 64
#define RSCMWEVS_ATTR_NETWORK_SECTOR_SUBNET_MASK                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 65
#define RSCMWEVS_ATTR_NETWORK_SECTOR_COUNTRY_CODE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 66
#define RSCMWEVS_ATTR_NETWORK_SECTOR_FORMAT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 67
#define RSCMWEVS_ATTR_NETWORK_ANSI_41_SECTOR_ID                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 68
#define RSCMWEVS_ATTR_NETWORK_ANSI_41_NUMBER_OF_PARITY_BITS                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 69
#define RSCMWEVS_ATTR_QUERY_NETWORK_ANSI_41_OVERALL_ID                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 70
#define RSCMWEVS_ATTR_NETWORK_MANUAL_OVERALL_ID                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 71
#define RSCMWEVS_ATTR_NETWORK_ACCESS_PROBE_STATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 72
#define RSCMWEVS_ATTR_NETWORK_ACCESS_PROBES_INITIAL_ADJUST                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 73
#define RSCMWEVS_ATTR_NETWORK_ACCESS_PROBES_OPEN_LOOP_ADJUST                RS_SPECIFIC_PUBLIC_ATTR_BASE + 74
#define RSCMWEVS_ATTR_NETWORK_ACCESS_PROBES_INCREMENT                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 75
#define RSCMWEVS_ATTR_NETWORK_ACCESS_PROBES_PER_SEQUENCE                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 76
#define RSCMWEVS_ATTR_NETWORK_ACCESS_PROBES_PREAMBLE_LENGTH                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 77
#define RSCMWEVS_ATTR_NETWORK_ACCESS_PROBES_CYCLE_DURATION                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 78
#define RSCMWEVS_ATTR_NETWORK_ACCESS_PROBES_PREAMBLE_LENGTH_SLOTS           RS_SPECIFIC_PUBLIC_ATTR_BASE + 79
#define RSCMWEVS_ATTR_NETWORK_ACCESS_PROBES_SECTOR_ACCESS_MAXIMUM_RATE      RS_SPECIFIC_PUBLIC_ATTR_BASE + 80
#define RSCMWEVS_ATTR_NETWORK_SECURITY_SECRET_KEY                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 162
#define RSCMWEVS_ATTR_NETWORK_SECURITY_OPERATOR_VARIANT_KEY                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 164
#define RSCMWEVS_ATTR_NETWORK_SECURITY_AUTHENTICATION_FIELD                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 165
#define RSCMWEVS_ATTR_NETWORK_SECURITY_SEQUENCE_NUMBER                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 166
#define RSCMWEVS_ATTR_NETWORK_NEIGHBOR_CELL_RX_LEVEL_MIN_LTE                RS_SPECIFIC_PUBLIC_ATTR_BASE + 186
#define RSCMWEVS_ATTR_NETWORK_NEIGHBOR_CELL_TRESH_SERVING                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 187
#define RSCMWEVS_ATTR_NETWORK_NEIGHBOR_CELL_MAX_RESELECTION_TIMER           RS_SPECIFIC_PUBLIC_ATTR_BASE + 188
#define RSCMWEVS_ATTR_NETWORK_NEIGHBOR_CELL_LOW_THRESHOLD                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 177
#define RSCMWEVS_ATTR_NETWORK_NEIGHBOR_CELL_LTE_TRESHX                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 189
#define RSCMWEVS_ATTR_FADING_SIMULATOR_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 190
#define RSCMWEVS_ATTR_FADING_SIMULATOR_PROFILE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 191
#define RSCMWEVS_ATTR_FADING_SIMULATOR_START_SEED                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 192
#define RSCMWEVS_ATTR_FADING_SIMULATOR_INSERTION_LOSS_MODE                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 193
#define RSCMWEVS_ATTR_FADING_SIMULATOR_INSERTION_LOSS                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 194
#define RSCMWEVS_ATTR_FADING_SIMULATOR_RESTART_MODE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 195
#define RSCMWEVS_ATTR_FADING_SIMULATOR_RESTART                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 196
#define RSCMWEVS_ATTR_FADING_SIMULATOR_CLIPPED_SAMPLES                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 197
#define RSCMWEVS_ATTR_FADING_SIMULATOR_POWER_NOISE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 198
#define RSCMWEVS_ATTR_FADING_SIMULATOR_POWER_NOISE_TOTAL                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 199
#define RSCMWEVS_ATTR_FADING_SIMULATOR_POWER_NOISE_SUM                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 200
#define RSCMWEVS_ATTR_FADING_AWGN_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 201
#define RSCMWEVS_ATTR_FADING_AWGN_BANDWIDTH_RATIO                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 202
#define RSCMWEVS_ATTR_FADING_AWGN_SIGNAL_TO_NOISE_RATIO                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 203
#define RSCMWEVS_ATTR_FADING_AWGN_NOISE_BANDWIDTH                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 204
#define RSCMWEVS_ATTR_SIGNALING_TO_LOGGING_STATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 167
#define RSCMWEVS_ATTR_SIGNALING_MESSAGES_IP_ADDRESS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 168
#define RSCMWEVS_ATTR_GENERATOR_STATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 81
#define RSCMWEVS_ATTR_CONNECTION_STATE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 82
#define RSCMWEVS_ATTR_QUERY_CONNECTION_STATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 83
#define RSCMWEVS_ATTR_QUERY_PACKET_DATA_STATE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 169
#define RSCMWEVS_ATTR_TEST_APPLICATION_STREAM                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 84
#define RSCMWEVS_ATTR_TEST_APPLICATION_MODE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 85
#define RSCMWEVS_ATTR_TEST_APPLICATION_PREFERRED_PACKET_MODE                RS_SPECIFIC_PUBLIC_ATTR_BASE + 205
#define RSCMWEVS_ATTR_TEST_APPLICATION_INFO                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 170
#define RSCMWEVS_ATTR_QUERY_INTER_RAT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 171
#define RSCMWEVS_ATTR_QUERY_RX_POWER                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 206
#define RSCMWEVS_ATTR_QUERY_ACTIVE_APPLICATION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 172
#define RSCMWEVS_ATTR_QUERY_NEGOTIATED_MODE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 207
#define RSCMWEVS_ATTR_QUERY_PHYSICAL_LAYER_SUBTYPE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 86
#define RSCMWEVS_ATTR_QUERY_UATI                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 87
#define RSCMWEVS_ATTR_TEST_ESN                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 208
#define RSCMWEVS_ATTR_QUERY_ESN                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 88
#define RSCMWEVS_ATTR_TEST_MEID                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 209
#define RSCMWEVS_ATTR_QUERY_MEID                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 89
#define RSCMWEVS_ATTR_QUERY_EHRPD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 212
#define RSCMWEVS_ATTR_QUERY_PREFERRED_CONTROL_CHANNEL_CYCLE                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 90
#define RSCMWEVS_ATTR_QUERY_PREFERRED_CONTROL_CHANNEL_STATUS                RS_SPECIFIC_PUBLIC_ATTR_BASE + 91
#define RSCMWEVS_ATTR_QUERY_ACTIVE_FORWARD_LINK_CARRIERS                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 137
#define RSCMWEVS_ATTR_QUERY_ACTIVE_REVERSE_LINK_CARRIERS                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 138
#define RSCMWEVS_ATTR_QUERY_LONG_CODE_MASK_I                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 139
#define RSCMWEVS_ATTR_QUERY_LONG_CODE_MASK_Q                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 140
#define RSCMWEVS_ATTR_QUERY_MAX_REVERSE_BANDWIDTH                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 213
#define RSCMWEVS_ATTR_QUERY_DATA_APPLICATION_UNIT_IP_ADDRESS                RS_SPECIFIC_PUBLIC_ATTR_BASE + 178
#define RSCMWEVS_ATTR_HANDOFF_BAND_CLASS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 92
#define RSCMWEVS_ATTR_HANDOFF_CHANNEL                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 93
#define RSCMWEVS_ATTR_HANDOFF_CARRIER_CHANNEL_TARGET                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 141
#define RSCMWEVS_ATTR_HANDOFF_CHANNEL_OFFSET                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 142
#define RSCMWEVS_ATTR_HANDOFF_FORWARD_LINK_FREQUENCY                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 143
#define RSCMWEVS_ATTR_HANDOFF_REVERSE_LINK_FREQUENCY                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 144
#define RSCMWEVS_ATTR_HANDOFF_PILOT_ACTIVE_ON_AN                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 145
#define RSCMWEVS_ATTR_HANDOFF_PILOT_ASSIGNED_TO_AT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 146
#define RSCMWEVS_ATTR_INITIATE_HANDOFF                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 94
#define RSCMWEVS_ATTR_USE_EXTERNAL_DAU                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 214
#define RSCMWEVS_ATTR_EXTERNAL_DAU_NETWORK_SEGMENT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 215
#define RSCMWEVS_ATTR_EXTERNAL_DAU_SUBNET_NODE_ID                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 216
#define RSCMWEVS_ATTR_RX_QUALITY_PER_REPETITION                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 95
#define RSCMWEVS_ATTR_RX_QUALITY_PER_TIMEOUT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 222
#define RSCMWEVS_ATTR_RX_QUALITY_THROUGHPUT_REPETITION                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 147
#define RSCMWEVS_ATTR_RX_QUALITY_THROUGHPUT_TIMEOUT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 223
#define RSCMWEVS_ATTR_RX_QUALITY_UPDATE_PERIOD                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 96
#define RSCMWEVS_ATTR_RX_QUALITY_LINK_STOP_CONDITION                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 97
#define RSCMWEVS_ATTR_RX_QUALITY_FORWARD_MAX_TEST_PACKETS_SENT              RS_SPECIFIC_PUBLIC_ATTR_BASE + 98
#define RSCMWEVS_ATTR_RX_QUALITY_REVERSE_MAX_PACKETS_SENT                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 148
#define RSCMWEVS_ATTR_RX_QUALITY_FORWARD_LINK_PERFORMANCE_MAX_FRAMES        RS_SPECIFIC_PUBLIC_ATTR_BASE + 99
#define RSCMWEVS_ATTR_RX_QUALITY_REVERSE_LINK_PERFORMANCE_MAX_FRAMES        RS_SPECIFIC_PUBLIC_ATTR_BASE + 149
#define RSCMWEVS_ATTR_RX_QUALITY_SELECT_CARRIER_FOR_RESULTS                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 150
#define RSCMWEVS_ATTR_RX_QUALITY_ASSIGN_VIEWS_FORWARD_LINK_PER              RS_SPECIFIC_PUBLIC_ATTR_BASE + 100
#define RSCMWEVS_ATTR_RX_QUALITY_ASSIGN_VIEWS_REVERSE_LINK_PER              RS_SPECIFIC_PUBLIC_ATTR_BASE + 152
#define RSCMWEVS_ATTR_RX_QUALITY_ASSIGN_VIEWS_FORWARD_LINK_PERFORMANCE      RS_SPECIFIC_PUBLIC_ATTR_BASE + 101
#define RSCMWEVS_ATTR_RX_QUALITY_ASSIGN_VIEWS_REVERSE_LINK_PERFORMANCE      RS_SPECIFIC_PUBLIC_ATTR_BASE + 153
#define RSCMWEVS_ATTR_RX_QUALITY_MAX_PER_LIMIT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 102
#define RSCMWEVS_ATTR_RX_QUALITY_MIN_CONFIDENCE_LEVEL                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 103
#define RSCMWEVS_ATTR_RX_QUALITY_EVALUATION_DECISION                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 151
#define RSCMWEVS_ATTR_RX_QUALITY_INIT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 104
#define RSCMWEVS_ATTR_RX_QUALITY_ABORT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 105
#define RSCMWEVS_ATTR_RX_QUALITY_STOP                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 106
#define RSCMWEVS_ATTR_RX_QUALITY_CLEAR                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 107
#define RSCMWEVS_ATTR_RX_QUALITY_REMOTE_DISPLAY                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 210
#define RSCMWEVS_ATTR_FETCH_RX_QUALITY_FORWARD_LINK_PER_MEASUREMENT_STATUS  RS_SPECIFIC_PUBLIC_ATTR_BASE + 108
#define RSCMWEVS_ATTR_FETCH_RX_QUALITY_FORWARD_LINK_PERFORMANCE_MEASUREMENT_STATUS RS_SPECIFIC_PUBLIC_ATTR_BASE + 109
#define RSCMWEVS_ATTR_FETCH_RX_QUALITY_REVERSE_LINK_PER_MEASUREMENT_STATUS  RS_SPECIFIC_PUBLIC_ATTR_BASE + 154
#define RSCMWEVS_ATTR_FETCH_RX_QUALITY_REVERSE_LINK_PERFORMANCE_MEASUREMENT_STATUS RS_SPECIFIC_PUBLIC_ATTR_BASE + 155
#define RSCMWEVS_ATTR_RX_QUALITY_IP_STATISTIC_STATUS                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 173
#define RSCMWEVS_ATTR_RX_QUALITY_DATA_RLP_TABLE_RESULTS_STATE               RS_SPECIFIC_PUBLIC_ATTR_BASE + 179
#define RSCMWEVS_ATTR_SYSTEM_VERSION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 110
#define RSCMWEVS_ATTR_SYSTEM_ERROR                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 111
#define RSCMWEVS_ATTR_SYSTEM_ALL_ERRORS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 112
#define RSCMWEVS_ATTR_SYSTEM_PRESET                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 113
#define RSCMWEVS_ATTR_PROCESS_ALL_PREVIOUS_COMMANDS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 217
#define RSCMWEVS_ATTR_ID_QUERY_RESPONSE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 114

// rscmwevs_rngOperBandClass
#define RSCMWEVS_VAL_BAND_USC                                               0
#define RSCMWEVS_VAL_BAND_KCEL                                              1
#define RSCMWEVS_VAL_BAND_NAPC                                              2
#define RSCMWEVS_VAL_BAND_TACS                                              3
#define RSCMWEVS_VAL_BAND_JTAC                                              4
#define RSCMWEVS_VAL_BAND_KPCS                                              5
#define RSCMWEVS_VAL_BAND_N45T                                              6
#define RSCMWEVS_VAL_BAND_IM2K                                              7
#define RSCMWEVS_VAL_BAND_NA7C                                              8
#define RSCMWEVS_VAL_BAND_B18M                                              9
#define RSCMWEVS_VAL_BAND_NA9C                                              10
#define RSCMWEVS_VAL_BAND_NA8S                                              11
#define RSCMWEVS_VAL_BAND_PA4M                                              12
#define RSCMWEVS_VAL_BAND_PA8M                                              13
#define RSCMWEVS_VAL_BAND_IEXT                                              14
#define RSCMWEVS_VAL_BAND_USPC                                              15
#define RSCMWEVS_VAL_BAND_AWS                                               16
#define RSCMWEVS_VAL_BAND_U25B                                              17
#define RSCMWEVS_VAL_BAND_U25F                                              18
#define RSCMWEVS_VAL_BAND_PS7C                                              19
#define RSCMWEVS_VAL_BAND_LO7C                                              20
#define RSCMWEVS_VAL_BAND_LBAN                                              21
#define RSCMWEVS_VAL_BAND_SBAN                                              22

// rscmwevs_rngExpectedPowMode
#define RSCMWEVS_VAL_RF_POWER_MODE_MANUAL                                   0
#define RSCMWEVS_VAL_RF_POWER_MODE_OLRULE                                   1
#define RSCMWEVS_VAL_RF_POWER_MODE_MAX                                      2
#define RSCMWEVS_VAL_RF_POWER_MODE_MIN                                      3
#define RSCMWEVS_VAL_RF_POWER_MODE_AUTO                                     4

// rscmwevs_rngAWGNMode
#define RSCMWEVS_VAL_RF_POWER_AWGN_NORMAL                                   0
#define RSCMWEVS_VAL_RF_POWER_AWGN_HIGH                                     1

// rscmwevs_rngPowControlBits
#define RSCMWEVS_VAL_RF_POWER_CTRL_BITS_AUTO                                0
#define RSCMWEVS_VAL_RF_POWER_CTRL_BITS_AUP                                 1
#define RSCMWEVS_VAL_RF_POWER_CTRL_BITS_ADOW                                2
#define RSCMWEVS_VAL_RF_POWER_CTRL_BITS_HOLD                                3
#define RSCMWEVS_VAL_RF_POWER_CTRL_BITS_RTES                                4
#define RSCMWEVS_VAL_RF_POWER_CTRL_BITS_PATT                                5

// rscmwevs_rngAckTrafficChan
#define RSCMWEVS_VAL_LAYER_FTAP_ACK_MODE_NUS                                0
#define RSCMWEVS_VAL_LAYER_FTAP_ACK_MODE_AALW                               1
#define RSCMWEVS_VAL_LAYER_FTAP_ACK_MODE_NAAL                               2

// rscmwevs_rngLayerMacProtocolDrate
#define RSCMWEVS_VAL_LAYER_MAC_DRATE_R384                                   0
#define RSCMWEVS_VAL_LAYER_MAC_DRATE_R768                                   1

// rscmwevs_rngConnections
#define RSCMWEVS_VAL_CONNECT                                                0
#define RSCMWEVS_VAL_DISCONNECT                                             1
#define RSCMWEVS_VAL_CLOSE                                                  2
#define RSCMWEVS_VAL_HANDOFF                                                3

// rscmwevs_rngQueryConnectionState
#define RSCMWEVS_VAL_CSWITCHED_STATE_OFF                                    0
#define RSCMWEVS_VAL_CSWITCHED_STATE_ON                                     1
#define RSCMWEVS_VAL_CSWITCHED_STATE_IDLE                                   2
#define RSCMWEVS_VAL_CSWITCHED_STATE_SNEG                                   3
#define RSCMWEVS_VAL_CSWITCHED_STATE_SOP                                    4
#define RSCMWEVS_VAL_CSWITCHED_STATE_PAG                                    5
#define RSCMWEVS_VAL_CSWITCHED_STATE_CONN                                   6

// rscmwevs_rngTestApplicationMode
#define RSCMWEVS_VAL_TEST_APP_MODE_FWD                                      0
#define RSCMWEVS_VAL_TEST_APP_MODE_REV                                      1
#define RSCMWEVS_VAL_TEST_APP_MODE_FAR                                      2
#define RSCMWEVS_VAL_TEST_APP_MODE_PACK                                     3

// rscmwevs_rngPhysicalLayerSubtype
#define RSCMWEVS_VAL_PL_SUBTYPE_ST01                                        0
#define RSCMWEVS_VAL_PL_SUBTYPE_ST2                                         2

// rscmwevs_rngRXQRepetition
#define RSCMWEVS_VAL_REPETITION_SINGLE                                      0
#define RSCMWEVS_VAL_REPETITION_CONT                                        1

// rscmwevs_rngRXQStopCondition
#define RSCMWEVS_VAL_NONE                                                   0
#define RSCMWEVS_VAL_LIM_FAIL                                               1
#define RSCMWEVS_VAL_MIN_LEVEL_EXC                                          2
#define RSCMWEVS_VAL_MAX_PER_EXC                                            3

// rscmwevs_rngNetworkRelease
#define RSCMWEVS_VAL_NETWORK_GENERAL_RELEASE_0                              0
#define RSCMWEVS_VAL_NETWORK_GENERAL_RELEASE_A                              1
#define RSCMWEVS_VAL_NETWORK_GENERAL_RELEASE_B                              2

// rscmwevs_rngNetworkFormat
#define RSCMWEVS_VAL_NETWORK_SECTOR_FORMAT_A41N                             0
#define RSCMWEVS_VAL_NETWORK_SECTOR_FORMAT_MAN                              1

// rscmwevs_rngNetworkAccessProbesState
#define RSCMWEVS_VAL_ACCESS_PROBES_ACK                                      0
#define RSCMWEVS_VAL_ACCESS_PROBES_IGN                                      1

// rscmwevs_rngNetworkAccessProbesCycleDuration
#define RSCMWEVS_VAL_ACCESS_PROBES_SLOTS_16                                 1
#define RSCMWEVS_VAL_ACCESS_PROBES_SLOTS_32                                 2
#define RSCMWEVS_VAL_ACCESS_PROBES_SLOTS_64                                 3
#define RSCMWEVS_VAL_ACCESS_PROBES_SLOTS_128                                4

// rscmwevs_rngNetworkAccessProbesPreambleLengthSlots
#define RSCMWEVS_VAL_ACCESS_PROBES_SLOTS_4                                  0

// rscmwevs_rngNetworkAccessProbesSectorAccessMaxRate
#define RSCMWEVS_VAL_ACCESS_PROBES_MAX_RATE_R9K                             0
#define RSCMWEVS_VAL_ACCESS_PROBES_MAX_RATE_R19K                            1
#define RSCMWEVS_VAL_ACCESS_PROBES_MAX_RATE_R38K                            2

// rscmwevs_rngActiveScenario
#define RSCMWEVS_VAL_SCENARIO_SCEL                                          0
#define RSCMWEVS_VAL_SCENARIO_HMODE                                         1
#define RSCMWEVS_VAL_SCENARIO_SCF                                           2
#define RSCMWEVS_VAL_SCENARIO_HMLITE                                        3

// rscmwevs_rngLayer_ACK_Traffic_Channel_B
#define RSCMWEVS_VAL_LAYER_FMCTAP_ACK_MODE_NUS                              0
#define RSCMWEVS_VAL_LAYER_FMCTAP_ACK_MODE_AALW                             1
#define RSCMWEVS_VAL_LAYER_FMCTAP_ACK_MODE_NAAL                             2

// rscmwevs_rngRX_Quality_Evaluation_Decision
#define RSCMWEVS_VAL_EVALUATION_PER_CARRIER                                 0
#define RSCMWEVS_VAL_EVALUATION_ALL_CARRIER                                 1

// rscmwevs_rngTimeSource
#define RSCMWEVS_VAL_TIME_SOURCE_CMW_TIME                                   0
#define RSCMWEVS_VAL_TIME_SOURCE_DATE                                       1
#define RSCMWEVS_VAL_TIME_SOURCE_SYNC                                       2

// rscmwevs_rngApplyTimeAt
#define RSCMWEVS_VAL_APPLY_TIME_SUSO                                        0
#define RSCMWEVS_VAL_APPLY_TIME_EVER                                        1
#define RSCMWEVS_VAL_APPLY_TIME_NEXT                                        2

// rscmwevs_rngPreferedApplication
#define RSCMWEVS_VAL_LAYER_PACKET_APP_EMPA                                  0
#define RSCMWEVS_VAL_LAYER_PACKET_APP_DPA                                   1

// rscmwevs_rngSignalingIPAddress
#define RSCMWEVS_VAL_IP_ADDRESS_IP1                                         1
#define RSCMWEVS_VAL_IP_ADDRESS_IP2                                         2
#define RSCMWEVS_VAL_IP_ADDRESS_IP3                                         3

// rscmwevs_rngPacketDataState
#define RSCMWEVS_VAL_PACKET_DATA_STATE_OFF                                  0
#define RSCMWEVS_VAL_PACKET_DATA_STATE_ON                                   1
#define RSCMWEVS_VAL_PACKET_DATA_STATE_DORM                                 2
#define RSCMWEVS_VAL_PACKET_DATA_STATE_CONN                                 3

// rscmwevs_rngFadingSimulatorProfile
#define RSCMWEVS_VAL_FADING_PROFILE_P1                                      1
#define RSCMWEVS_VAL_FADING_PROFILE_P2                                      2
#define RSCMWEVS_VAL_FADING_PROFILE_P3                                      3
#define RSCMWEVS_VAL_FADING_PROFILE_P4                                      4
#define RSCMWEVS_VAL_FADING_PROFILE_P5                                      5
#define RSCMWEVS_VAL_FADING_PROFILE_P6                                      6

// rscmwevs_rngFadingSimulatorInsertionLossMode
#define RSCMWEVS_VAL_FADING_INSERTION_LOSS_MODE_NORMAL                      0
#define RSCMWEVS_VAL_FADING_INSERTION_LOSS_MODE_USER                        1

// rscmwevs_rngFadingSimulatorRestartMode
#define RSCMWEVS_VAL_FADING_RESTART_MODE_AUTO                               0
#define RSCMWEVS_VAL_FADING_RESTART_MODE_MANUAL                             1
#define RSCMWEVS_VAL_FADING_RESTART_MODE_TRIGGER                            2

// rscmwevs_rngTestApplicationPreferedPacketMode
#define RSCMWEVS_VAL_PACKET_MODE_EHRP                                       1
#define RSCMWEVS_VAL_PACKET_MODE_HRPD                                       2
#define RSCMWEVS_VAL_PACKET_MODE_INV                                        0

// rscmwevs_rngQueryRXPower
#define RSCMWEVS_VAL_RX_POWER_NAV                                           0
#define RSCMWEVS_VAL_RX_POWER_LOW                                           1
#define RSCMWEVS_VAL_RX_POWER_OK                                            2
#define RSCMWEVS_VAL_RX_POWER_HIGH                                          3

// rscmwevs_rngRXQualityRemoteDisplay
#define RSCMWEVS_VAL_MEASUREMENT_PER                                        0
#define RSCMWEVS_VAL_MEASUREMENT_THR                                        1
#define RSCMWEVS_VAL_MEASUREMENT_DATA                                       2
#define RSCMWEVS_VAL_MEASUREMENT_OVER                                       3

// rscmwevs_rngExternalDAUNetworkSegment
#define RSCMWEVS_VAL_EDAU_NETWORK_SEGMENT_A                                 0
#define RSCMWEVS_VAL_EDAU_NETWORK_SEGMENT_B                                 1
#define RSCMWEVS_VAL_EDAU_NETWORK_SEGMENT_C                                 2

// rscmwevs_rngMACLayerT2PValueOptimization
#define RSCMWEVS_VAL_LAYER_MAC_T2P_THROUGHPUT_OPT                           0
#define RSCMWEVS_VAL_LAYER_MAC_T2P_RF_CONFORMANCE                           1

// rscmwevs_rngRPCRepetition
#define RSCMWEVS_VAL__SINGLESHOT                                            0
#define RSCMWEVS_VAL__CONTINUOUS                                            1

// rscmwevs_rngSegmentBits
#define RSCMWEVS_VAL_PCB_DOWN                                               0
#define RSCMWEVS_VAL_PCB_UP                                                 1
#define RSCMWEVS_VAL_PCB_ALTERNATING                                        2
/* END GENERATE */

/*****************************************************************************
 *- Hidden Attribute Declarations -------------------------------------------*
 *****************************************************************************/

#define RSCMWEVS_ATTR_OPC_TIMEOUT               (RS_ATTR_OPC_TIMEOUT)           /* ViInt32 */
#define RSCMWEVS_ATTR_IO_SESSION                (RS_ATTR_IO_SESSION)            /* ViSession */
#define RSCMWEVS_ATTR_OPC_CALLBACK              (RS_ATTR_OPC_CALLBACK)          /* ViAddr */
#define RSCMWEVS_ATTR_CHECK_STATUS_CALLBACK     (RS_ATTR_CHECK_STATUS_CALLBACK) /* ViAddr */

/****************************************************************************
 *---------------- Constant definition  ------------------------------------*
 ****************************************************************************/

#define RSCMWEVS_VAL_LAYER_MAC_SUBTYPE01  0
#define RSCMWEVS_VAL_LAYER_MAC_SUBTYPE2   1
    
#define RSCMWEVS_VAL_PACKET_SIZE_S128     0
#define RSCMWEVS_VAL_PACKET_SIZE_S256     1
#define RSCMWEVS_VAL_PACKET_SIZE_S512     2
#define RSCMWEVS_VAL_PACKET_SIZE_S1K      3
#define RSCMWEVS_VAL_PACKET_SIZE_S2K      4
#define RSCMWEVS_VAL_PACKET_SIZE_S3K      5
#define RSCMWEVS_VAL_PACKET_SIZE_S4K      6
#define RSCMWEVS_VAL_PACKET_SIZE_S5K      7
#define RSCMWEVS_VAL_PACKET_SIZE_TOTAL    8
#define RSCMWEVS_VAL_PACKET_SIZE_ALL      9


#define RSCMWEVS_VAL_CONN_RF1C  0
#define RSCMWEVS_VAL_CONN_RF2C  1
#define RSCMWEVS_VAL_CONN_RF3C  2
#define RSCMWEVS_VAL_CONN_RF4C  3
#define RSCMWEVS_VAL_CONN_RFAC  4
#define RSCMWEVS_VAL_CONN_RFBC  5
#define RSCMWEVS_VAL_CONN_RF1O  6
#define RSCMWEVS_VAL_CONN_RF3O  7
#define RSCMWEVS_VAL_CONN_RFAO  8
#define RSCMWEVS_VAL_CONN_R11C  9
#define RSCMWEVS_VAL_CONN_R12C  10
#define RSCMWEVS_VAL_CONN_R13C  11
#define RSCMWEVS_VAL_CONN_R14C  12
#define RSCMWEVS_VAL_CONN_R21C  13
#define RSCMWEVS_VAL_CONN_R22C  14
#define RSCMWEVS_VAL_CONN_R23C  15
#define RSCMWEVS_VAL_CONN_R24C  16
#define RSCMWEVS_VAL_CONN_R31C  17
#define RSCMWEVS_VAL_CONN_R32C  18
#define RSCMWEVS_VAL_CONN_R33C  19
#define RSCMWEVS_VAL_CONN_R34C  20
#define RSCMWEVS_VAL_CONN_R41C  21
#define RSCMWEVS_VAL_CONN_R42C  22
#define RSCMWEVS_VAL_CONN_R43C  23
#define RSCMWEVS_VAL_CONN_R44C  24
#define RSCMWEVS_VAL_CONN_R11O  25
#define RSCMWEVS_VAL_CONN_R13O  26
#define RSCMWEVS_VAL_CONN_R21O  27
#define RSCMWEVS_VAL_CONN_R23O  28
#define RSCMWEVS_VAL_CONN_R31O  29
#define RSCMWEVS_VAL_CONN_R33O  30
#define RSCMWEVS_VAL_CONN_R41O  31
#define RSCMWEVS_VAL_CONN_R43O  32

#define RSCMWEVS_VAL_CONV_RX1   0
#define RSCMWEVS_VAL_CONV_RX2   1
#define RSCMWEVS_VAL_CONV_RX3   2
#define RSCMWEVS_VAL_CONV_RX4   3
#define RSCMWEVS_VAL_CONV_RX11  4
#define RSCMWEVS_VAL_CONV_RX12  5
#define RSCMWEVS_VAL_CONV_RX13  6
#define RSCMWEVS_VAL_CONV_RX14  7
#define RSCMWEVS_VAL_CONV_RX21  8
#define RSCMWEVS_VAL_CONV_RX22  9
#define RSCMWEVS_VAL_CONV_RX23  10
#define RSCMWEVS_VAL_CONV_RX24  11
#define RSCMWEVS_VAL_CONV_RX31  12
#define RSCMWEVS_VAL_CONV_RX32  13
#define RSCMWEVS_VAL_CONV_RX33  14
#define RSCMWEVS_VAL_CONV_RX34  15
#define RSCMWEVS_VAL_CONV_RX41  16
#define RSCMWEVS_VAL_CONV_RX42  17
#define RSCMWEVS_VAL_CONV_RX43  18
#define RSCMWEVS_VAL_CONV_RX44  19

#define RSCMWEVS_VAL_CONV_TX1   0
#define RSCMWEVS_VAL_CONV_TX2   1
#define RSCMWEVS_VAL_CONV_TX3   2
#define RSCMWEVS_VAL_CONV_TX4   3
#define RSCMWEVS_VAL_CONV_TX11  4
#define RSCMWEVS_VAL_CONV_TX12  5
#define RSCMWEVS_VAL_CONV_TX13  6
#define RSCMWEVS_VAL_CONV_TX14  7
#define RSCMWEVS_VAL_CONV_TX21  8
#define RSCMWEVS_VAL_CONV_TX22  9
#define RSCMWEVS_VAL_CONV_TX23  10
#define RSCMWEVS_VAL_CONV_TX24  11
#define RSCMWEVS_VAL_CONV_TX31  12
#define RSCMWEVS_VAL_CONV_TX32  13
#define RSCMWEVS_VAL_CONV_TX33  14
#define RSCMWEVS_VAL_CONV_TX34  15
#define RSCMWEVS_VAL_CONV_TX41  16
#define RSCMWEVS_VAL_CONV_TX42  17
#define RSCMWEVS_VAL_CONV_TX43  18
#define RSCMWEVS_VAL_CONV_TX44  19
    
#define RSCMWEVS_VAL_LINK_FORWARD   0
#define RSCMWEVS_VAL_LINK_REVERSE   1
    
#define RSCMWEVS_VAL_DATA_RATE_R0K0    0
#define RSCMWEVS_VAL_DATA_RATE_R19K2   1
#define RSCMWEVS_VAL_DATA_RATE_R38K4   2
#define RSCMWEVS_VAL_DATA_RATE_R76K8   3
#define RSCMWEVS_VAL_DATA_RATE_R115k2  4
#define RSCMWEVS_VAL_DATA_RATE_R153k6  5
#define RSCMWEVS_VAL_DATA_RATE_R230k4  6
#define RSCMWEVS_VAL_DATA_RATE_R307k2  7
#define RSCMWEVS_VAL_DATA_RATE_R460k8  8
#define RSCMWEVS_VAL_DATA_RATE_R614k4  9
#define RSCMWEVS_VAL_DATA_RATE_R921k6  10
#define RSCMWEVS_VAL_DATA_RATE_R1228k8 11
#define RSCMWEVS_VAL_DATA_RATE_R1843k2 12
#define RSCMWEVS_VAL_DATA_RATE_TOTAL   13
    
#define RSCMWEVS_VAL_RF_POWER_ABSOLUTE  0
#define RSCMWEVS_VAL_RF_POWER_RELATIVE  1

#define RSCMWEVS_VAL_FLP  0
#define RSCMWEVS_VAL_RLP  1
	
#define RSCMWEVS_VAL_DATA_RLP_RESULT_RESET     0
#define RSCMWEVS_VAL_DATA_RLP_RESULT_RESET_ACK 1
#define RSCMWEVS_VAL_DATA_RLP_RESULT_NAK       2
#define RSCMWEVS_VAL_DATA_RLP_RESULT_SUMMARY   3
	
#define RSCMWEVS_VAL_DATA_IP_TABLE_PPPT 0
#define RSCMWEVS_VAL_DATA_IP_TABLE_DRAT 1
	
#define	RSCMWEVS_VAL_NEG 0
#define	RSCMWEVS_VAL_POS 1

#define RSCMWEVS_VAL_EVDO  0
#define RSCMWEVS_VAL_CDMA  1
#define RSCMWEVS_VAL_LTE   2
	
#define RSCMWEVS_VAL_BAND_OB1   1
#define RSCMWEVS_VAL_BAND_OB2   2
#define RSCMWEVS_VAL_BAND_OB3   3
#define RSCMWEVS_VAL_BAND_OB4   4	
#define RSCMWEVS_VAL_BAND_OB5   5
#define RSCMWEVS_VAL_BAND_OB6   6
#define RSCMWEVS_VAL_BAND_OB7   7	
#define RSCMWEVS_VAL_BAND_OB8   8	
#define RSCMWEVS_VAL_BAND_OB9   9	
#define RSCMWEVS_VAL_BAND_OB10  10	
#define RSCMWEVS_VAL_BAND_OB11  11	
#define RSCMWEVS_VAL_BAND_OB12  12	
#define RSCMWEVS_VAL_BAND_OB13  13	
#define RSCMWEVS_VAL_BAND_OB14  14
#define RSCMWEVS_VAL_BAND_OB15  15	
#define RSCMWEVS_VAL_BAND_OB16  16	
#define RSCMWEVS_VAL_BAND_OB17  17	
#define RSCMWEVS_VAL_BAND_OB18  18
#define RSCMWEVS_VAL_BAND_OB19  19	
#define RSCMWEVS_VAL_BAND_OB20  20	
#define RSCMWEVS_VAL_BAND_OB21  21	
#define RSCMWEVS_VAL_BAND_OB22  22	
#define RSCMWEVS_VAL_BAND_OB23  23	
#define RSCMWEVS_VAL_BAND_OB24  24	
#define RSCMWEVS_VAL_BAND_OB25  25	
#define RSCMWEVS_VAL_BAND_OB26  26	
#define RSCMWEVS_VAL_BAND_OB27  27	
#define RSCMWEVS_VAL_BAND_OB28  28	
#define RSCMWEVS_VAL_BAND_OB29  29	
#define RSCMWEVS_VAL_BAND_OB30  30	
#define RSCMWEVS_VAL_BAND_OB31  31	
#define RSCMWEVS_VAL_BAND_OB32  32	
#define RSCMWEVS_VAL_BAND_OB33  33
#define RSCMWEVS_VAL_BAND_OB34  34
#define RSCMWEVS_VAL_BAND_OB35  35
#define RSCMWEVS_VAL_BAND_OB36  36
#define RSCMWEVS_VAL_BAND_OB37  37
#define RSCMWEVS_VAL_BAND_OB38  38
#define RSCMWEVS_VAL_BAND_OB39  39
#define RSCMWEVS_VAL_BAND_OB40  40
#define RSCMWEVS_VAL_BAND_OB41  41
#define RSCMWEVS_VAL_BAND_OB42  42
#define RSCMWEVS_VAL_BAND_OB43  43	
#define RSCMWEVS_VAL_BAND_OB44  44	
#define RSCMWEVS_VAL_BAND_UDEF  45	

#define RSCMWEVS_VAL_OFFSET_N24  0
#define RSCMWEVS_VAL_OFFSET_N22  1
#define RSCMWEVS_VAL_OFFSET_N20  2
#define RSCMWEVS_VAL_OFFSET_N18  3
#define RSCMWEVS_VAL_OFFSET_N16  4
#define RSCMWEVS_VAL_OFFSET_N14  5
#define RSCMWEVS_VAL_OFFSET_N12  6
#define RSCMWEVS_VAL_OFFSET_N10  7
#define RSCMWEVS_VAL_OFFSET_N8   8
#define RSCMWEVS_VAL_OFFSET_N6   9
#define RSCMWEVS_VAL_OFFSET_N5   10
#define RSCMWEVS_VAL_OFFSET_N4   11
#define RSCMWEVS_VAL_OFFSET_N3   12
#define RSCMWEVS_VAL_OFFSET_N2   13
#define RSCMWEVS_VAL_OFFSET_N1   14
#define RSCMWEVS_VAL_OFFSET_ZERO 15
#define RSCMWEVS_VAL_OFFSET_P1   16
#define RSCMWEVS_VAL_OFFSET_P2   17
#define RSCMWEVS_VAL_OFFSET_P3   18
#define RSCMWEVS_VAL_OFFSET_P4   19
#define RSCMWEVS_VAL_OFFSET_P5   20
#define RSCMWEVS_VAL_OFFSET_P6   21
#define RSCMWEVS_VAL_OFFSET_P8   22
#define RSCMWEVS_VAL_OFFSET_P10  23 
#define RSCMWEVS_VAL_OFFSET_P12  24
#define RSCMWEVS_VAL_OFFSET_P14  25
#define RSCMWEVS_VAL_OFFSET_P16  26
#define RSCMWEVS_VAL_OFFSET_P18  27	
#define RSCMWEVS_VAL_OFFSET_P20  28		
#define RSCMWEVS_VAL_OFFSET_P22  29
#define RSCMWEVS_VAL_OFFSET_P24  30
	
#define RSCMWEVS_VAL_IP_VERSION_4 0
#define RSCMWEVS_VAL_IP_VERSION_6 1
	
#define RSCMWEVS_VAL_CONN_IQ2O 0
#define RSCMWEVS_VAL_CONN_IQ4O 1
#define RSCMWEVS_VAL_CONN_IQ6O 2
#define RSCMWEVS_VAL_CONN_IQ8O 3
#define RSCMWEVS_VAL_CONN_I12O 4
#define RSCMWEVS_VAL_CONN_I14O 5
#define RSCMWEVS_VAL_CONN_I16O 6
#define RSCMWEVS_VAL_CONN_I18O 7
#define RSCMWEVS_VAL_CONN_I22O 8
#define RSCMWEVS_VAL_CONN_I24O 9
#define RSCMWEVS_VAL_CONN_I26O 10
#define RSCMWEVS_VAL_CONN_I28O 11
#define RSCMWEVS_VAL_CONN_I32O 12
#define RSCMWEVS_VAL_CONN_I34O 13
#define RSCMWEVS_VAL_CONN_I36O 14
#define RSCMWEVS_VAL_CONN_I38O 15
#define RSCMWEVS_VAL_CONN_I42O 16
#define RSCMWEVS_VAL_CONN_I44O 17
#define RSCMWEVS_VAL_CONN_I46O 18
#define RSCMWEVS_VAL_CONN_I48O 19

/****************************************************************************
 *---------------- Instrument Driver Function Declarations -----------------*
 ****************************************************************************/

ViStatus _VI_FUNC rscmwevs_init (ViRsrc resourceName, ViBoolean IDQuery,
                                 ViBoolean resetDevice,
                                 ViSession* instrumentHandle);
ViStatus _VI_FUNC rscmwevs_InitWithOptions (ViRsrc resourceName, ViBoolean IDQuery,
                                            ViBoolean resetDevice,
                                            ViString optionString,
                                            ViSession* instrumentHandle);
ViStatus _VI_FUNC rscmwevs_ConfigureRouting (ViSession instrumentHandle,
                                             ViInt32 instance,
                                             ViInt32 RFInputConnector,
                                             ViInt32 RFInputConverter,
                                             ViInt32 RFOutputConnector,
                                             ViInt32 RFOutputConverter);
ViStatus _VI_FUNC rscmwevs_QuerySignalRouting (ViSession instrumentHandle,
                                               ViInt32 instance, ViInt32* scenario,
                                               ViChar _VI_FAR controller[],
                                               ViInt32* RXConnector,
                                               ViInt32* RXConverter,
                                               ViInt32* TXConnector,
                                               ViInt32* TXConverter,
                                               ViInt32* IQOutputConnector);
ViStatus _VI_FUNC rscmwevs_QueryRFSignalActiveScenario (ViSession instrumentHandle,
                                                        ViInt32 instance,
                                                        ViInt32* scenario);
ViStatus _VI_FUNC rscmwevs_QueryRFSignalActiveScenarioFader
             (ViSession instrumentHandle, ViInt32 instance, ViInt32* scenario,
              ViInt32* fader);
ViStatus _VI_FUNC rscmwevs_ConfigureHybridMode (ViSession instrumentHandle,
                                                ViInt32 instance,
                                                ViInt32 RFInputConnector,
                                                ViInt32 RFInputConverter,
                                                ViInt32 RFOutputConnector,
                                                ViInt32 RFOutputConverter);
ViStatus _VI_FUNC rscmwevs_ConfigureHybridModeLite (ViSession instrumentHandle,
                                                    ViInt32 instance,
                                                    ViInt32 RFInputConnector,
                                                    ViInt32 RFInputConverter,
                                                    ViInt32 RFOutputConnector,
                                                    ViInt32 RFOutputConverter);
ViStatus _VI_FUNC rscmwevs_ConfigureSignalRoutingStandardCellFading
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 RFInputConnector, ViInt32 RFInputConverter,
              ViInt32 RFOutputConnector, ViInt32 RFOutputConverter);
ViStatus _VI_FUNC rscmwevs_ConfigureSignalRoutingStandardCellFadingExternal
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 RFInputConnector, ViInt32 RFInputConverter,
              ViInt32 RFOutputConnector, ViInt32 RFOutputConverter,
              ViInt32 IQOutputConnector);
ViStatus _VI_FUNC rscmwevs_ConfigureIQInput (ViSession instrumentHandle,
                                             ViInt32 instance, ViInt32 path,
                                             ViReal64 PEP, ViReal64 level);
ViStatus _VI_FUNC rscmwevs_QueryIQOutput (ViSession instrumentHandle,
                                          ViInt32 instance, ViInt32 path,
                                          ViInt32* sampleRate, ViReal64* PEP,
                                          ViReal64* crestFactor);
ViStatus _VI_FUNC rscmwevs_ConfigureDataEndToEndState (ViSession instrumentHandle,
                                                       ViInt32 instance,
                                                       ViBoolean enableDataEndToEnd);
ViStatus _VI_FUNC rscmwevs_ConfigureRFSignalFrequency (ViSession instrumentHandle,
                                                       ViInt32 instance,
                                                       ViInt32 bandClass,
                                                       ViInt32 channel);
ViStatus _VI_FUNC rscmwevs_QueryRFSignalLinkFrequency (ViSession instrumentHandle,
                                                       ViInt32 instance,
                                                       ViReal64* forwardLinkFrequency,
                                                       ViReal64* reverseLinkFrequency);
ViStatus _VI_FUNC rscmwevs_ConfigureRFSignalFrequencyOffset
             (ViSession instrumentHandle, ViInt32 instance,
              ViReal64 frequencyOffset);
ViStatus _VI_FUNC rscmwevs_ConfigureRFSignalRFPower (ViSession instrumentHandle,
                                                     ViInt32 instance,
                                                     ViReal64 _1xEVDOPower);
ViStatus _VI_FUNC rscmwevs_QueryRFSignalTotalOutputPower (ViSession instrumentHandle,
                                                          ViInt32 instance,
                                                          ViReal64* outputPower);
ViStatus _VI_FUNC rscmwevs_ConfigureRFSignalExpectedPower
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 expectedPowerMode, ViReal64 manualExpectedPower);
ViStatus _VI_FUNC rscmwevs_QueryRFSignalExpectedPower (ViSession instrumentHandle,
                                                       ViInt32 instance,
                                                       ViReal64* expectedNominalPower);
ViStatus _VI_FUNC rscmwevs_ConfigureRFSignalAWGN (ViSession instrumentHandle,
                                                  ViInt32 instance,
                                                  ViInt32 AWGNMode,
                                                  ViReal64 AWGNLevel);
ViStatus _VI_FUNC rscmwevs_ConfigureForwardTrafficChannel
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 MACIndexRev0,
              ViInt32 MACIndexRevA, ViInt32 MACIndexRevB);
ViStatus _VI_FUNC rscmwevs_ConfigureReversePowerControl (ViSession instrumentHandle,
                                                         ViInt32 instance,
                                                         ViInt32 powerControlBits,
                                                         ViReal64 stepSize);

ViStatus _VI_FUNC rscmwevs_ConfigureReversePowerControlRepetition (ViSession instrumentHandle,
                                                                   ViInt32 instance,
                                                                   ViInt32 repetition);

ViStatus _VI_FUNC rscmwevs_ConfigureReversePowerControlSegment (ViSession instrumentHandle,
                                                                ViInt32 instance,
                                                                ViInt32 segment,
                                                                ViInt32 powerControlBits,
                                                                ViInt32 segmentLength);

ViStatus _VI_FUNC rscmwevs_StartReversePowerControl (ViSession instrumentHandle,
                                                     ViInt32 instance,
                                                     ViBoolean runSequenceState);

ViStatus _VI_FUNC rscmwevs_ConfigureTimeSettings (ViSession instrumentHandle,
                                                  ViInt32 instance,
                                                  ViInt32 timeSource,
                                                  ViString syncCode,
                                                  ViInt32 applyTimeAt);
ViStatus _VI_FUNC rscmwevs_ConfigureLeapSecondCorrection (ViSession instrumentHandle,
                                                          ViInt32 instance,
                                                          ViInt32 leapSeconds);
ViStatus _VI_FUNC rscmwevs_ConfigureLocalTimeOffset (ViSession instrumentHandle,
                                                     ViInt32 instance, ViInt32 sign,
                                                     ViInt32 hour, ViInt32 minute);
ViStatus _VI_FUNC rscmwevs_QueryLocalTimeOffset (ViSession instrumentHandle,
                                                 ViInt32 instance,
                                                 ViChar _VI_FAR localTimeOffset[]);
ViStatus _VI_FUNC rscmwevs_ConfigureExternalDAU (ViSession instrumentHandle,
                                                 ViInt32 instance,
                                                 ViBoolean useExternalDAU,
                                                 ViInt32 networkSegment,
                                                 ViInt32 subnetNodeID);
ViStatus _VI_FUNC rscmwevs_ConfigureTime (ViSession instrumentHandle,
                                          ViInt32 instance, ViInt32 hour,
                                          ViInt32 minute, ViInt32 second);
ViStatus _VI_FUNC rscmwevs_ConfigureDate (ViSession instrumentHandle,
                                          ViInt32 instance, ViInt32 day,
                                          ViInt32 month, ViInt32 year);
ViStatus _VI_FUNC rscmwevs_ConfigureRFOutputSignalAttenuation
             (ViSession instrumentHandle, ViInt32 instance,
              ViReal64 externalAttenuation);
ViStatus _VI_FUNC rscmwevs_ConfigureRFInputSignalAttenuation
             (ViSession instrumentHandle, ViInt32 instance,
              ViReal64 externalAttenuation);
ViStatus _VI_FUNC rscmwevs_ConfigureRFCarrierChannel (ViSession instrumentHandle,
                                                      ViInt32 instance,
                                                      ViInt32 carrier,
                                                      ViInt32 carrierChannel,
                                                      ViInt32 carrierChannelOffset);
ViStatus _VI_FUNC rscmwevs_QueryRFCarrierLinkFrequency (ViSession instrumentHandle,
                                                        ViInt32 instance,
                                                        ViReal64* forwardLinkFrequency,
                                                        ViReal64* reverseLinkFrequency);
ViStatus _VI_FUNC rscmwevs_ConfigureRFCarrierPowerLevel (ViSession instrumentHandle,
                                                         ViInt32 instance,
                                                         ViInt32 powerMode,
                                                         ViReal64 level);
ViStatus _VI_FUNC rscmwevs_ConfigureRFCarrierPilotState (ViSession instrumentHandle,
                                                         ViInt32 instance,
                                                         ViInt32 pilot,
                                                         ViBoolean activeOnAN,
                                                         ViBoolean assignedToAT);
ViStatus _VI_FUNC rscmwevs_QueryRFCarrierPilotATState (ViSession instrumentHandle,
                                                       ViInt32 instance,
                                                       ViBoolean* acquiredByAT);
ViStatus _VI_FUNC rscmwevs_ConfigureSessionLayer (ViSession instrumentHandle,
                                                  ViInt32 instance,
                                                  ViReal64 inactiveSessionTimeout,
                                                  ViBoolean subnetIncluded);
ViStatus _VI_FUNC rscmwevs_ConfigureConnectionLayer (ViSession instrumentHandle,
                                                     ViInt32 instance,
                                                     ViReal64 pilotDropThreshold,
                                                     ViInt32 reverseLinkFrameOffset,
                                                     ViBoolean redirectOverheadMessages);
ViStatus _VI_FUNC rscmwevs_ConfigureMACLayerT2PValueOptimization
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 t2PValueOptimization);
ViStatus _VI_FUNC rscmwevs_ConfigureMACLayerControlProtocol
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 dataRate,
              ViInt32 maxProbeSequences, ViInt32 interProbeBackoff,
              ViInt32 interProbeSequenceBackoff);
ViStatus _VI_FUNC rscmwevs_QueryMACLayerAccesSessionSeed (ViSession instrumentHandle,
                                                          ViInt32 instance,
                                                          ViReal64* sessionSeed);
ViStatus _VI_FUNC rscmwevs_ConfigureMACLayer (ViSession instrumentHandle,
                                              ViInt32 instance, ViInt32 subtype,
                                              ViInt32 DRCCover, ViInt32 DRCLength,
                                              ViReal64 DRCChannelGain,
                                              ViReal64 ACKChannelGain);
ViStatus _VI_FUNC rscmwevs_ConfigureReverseTrafficChannelMACDataRate
             (ViSession instrumentHandle, ViInt32 instance, ViReal64 data96Kbps,
              ViReal64 data192Kbps, ViReal64 data384Kbps, ViReal64 data768Kbps,
              ViReal64 data1536Kbps);
ViStatus 
    _VI_FUNC rscmwevs_ConfigureReverseTrafficChannelMACIncreaseTransition
        (ViSession instrumentHandle, ViInt32 instance, ViInt32 data96Kbps,
         ViInt32 data192Kbps, ViInt32 data384Kbps, ViInt32 data768Kbps);
ViStatus 
    _VI_FUNC rscmwevs_ConfigureReverseTrafficChannelMACDecreaseTransition
        (ViSession instrumentHandle, ViInt32 instance, ViInt32 data192Kbps,
         ViInt32 data384Kbps, ViInt32 data768Kbps, ViInt32 data1536Kbps);
ViStatus _VI_FUNC rscmwevs_ConfigureForwardTrafficChannelIndex
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 index);
ViStatus _VI_FUNC rscmwevs_QueryForwardTrafficChannel (ViSession instrumentHandle,
                                                       ViInt32 instance,
                                                       ViReal64* rate,
                                                       ViInt32* slots);
ViStatus _VI_FUNC rscmwevs_QueryForwardTrafficChannelLoopback
             (ViSession instrumentHandle, ViInt32 instance,
              ViBoolean* loopbackEnable);
ViStatus _VI_FUNC rscmwevs_ConfiguresACKTrafficChannel (ViSession instrumentHandle,
                                                        ViInt32 instance,
                                                        ViInt32 ackChFixedMode);
ViStatus _VI_FUNC rscmwevs_ConfigureReverseTrafficChannelIndex
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 minIndex,
              ViInt32 maxIndex);
ViStatus _VI_FUNC rscmwevs_QueryReverseTrafficChannelRate
             (ViSession instrumentHandle, ViInt32 instance, ViReal64* minDataRate,
              ViReal64* maxDataRate);
ViStatus _VI_FUNC rscmwevs_ConfigureForwardTrafficChannelAPacketType
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 packetType);
ViStatus _VI_FUNC rscmwevs_QueryForwardTrafficChannelA (ViSession instrumentHandle,
                                                        ViInt32 instance,
                                                        ViInt32* index,
                                                        ViInt32* packetSize,
                                                        ViReal64* dataRate,
                                                        ViInt32* slots);
ViStatus _VI_FUNC rscmwevs_QueryForwardTrafficChannelALoopback
             (ViSession instrumentHandle, ViInt32 instance,
              ViBoolean* loopbackEnable);
ViStatus _VI_FUNC rscmwevs_ConfiguresACKTrafficChannelA (ViSession instrumentHandle,
                                                         ViInt32 instance,
                                                         ViInt32 ackChFixedMode);
ViStatus _VI_FUNC rscmwevs_QueryACKTrafficChannelA (ViSession instrumentHandle,
                                                    ViInt32 instance,
                                                    ViBoolean* ACKChFixedModulation);
ViStatus _VI_FUNC rscmwevs_ConfigureReverseTrafficChannelAIndex
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 minIndex,
              ViInt32 maxIndex);
ViStatus _VI_FUNC rscmwevs_QueryReverseTrafficChannelARate
             (ViSession instrumentHandle, ViInt32 instance, ViReal64* minDataRate,
              ViReal64* maxDataRate);
ViStatus _VI_FUNC rscmwevs_ConfigureReverseTrafficTerminationTarget
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 terminationTarget);
ViStatus _VI_FUNC rscmwevs_ConfigurePacketPreferredApplication
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 packetApplication);
ViStatus _VI_FUNC rscmwevs_ConfigureForwardTrafficChannelAMAC
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 DSCValue,
              ViReal64 DSCChannelGainBase);
ViStatus _VI_FUNC rscmwevs_ConfigureForwardTrafficChannelBPacketType
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 packetType);
ViStatus _VI_FUNC rscmwevs_QueryForwardTrafficChannelB (ViSession instrumentHandle,
                                                        ViInt32 instance,
                                                        ViInt32* index,
                                                        ViInt32* packetSize,
                                                        ViReal64* dataRate,
                                                        ViInt32* slots);
ViStatus _VI_FUNC rscmwevs_QueryForwardTrafficChannelBLoopback
             (ViSession instrumentHandle, ViInt32 instance,
              ViBoolean* loopbackEnable);
ViStatus _VI_FUNC rscmwevs_ConfigureACKTrafficChannelB (ViSession instrumentHandle,
                                                        ViInt32 instance,
                                                        ViInt32 fixedMode);
ViStatus _VI_FUNC rscmwevs_QueryACKTrafficChannelB (ViSession instrumentHandle,
                                                    ViInt32 instance,
                                                    ViBoolean* fixedModulationType);
ViStatus _VI_FUNC rscmwevs_ConfigureReverseTrafficChannelBIndex
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 minIndex,
              ViInt32 maxIndex);
ViStatus _VI_FUNC rscmwevs_QueryReverseTrafficChannelBPacketSize
             (ViSession instrumentHandle, ViInt32 instance, ViReal64* minPacketSize,
              ViReal64* maxPacketSize);
ViStatus _VI_FUNC rscmwevs_ConfigureNetworkSystemParameters
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 release,
              ViInt32 systemID);
ViStatus _VI_FUNC rscmwevs_ConfigureNetworkAccessProperties
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 PNOffset,
              ViReal64 callLossDetectTime, ViReal64 ATForwardPacketActivity,
              ViBoolean interRATEnabled);
ViStatus _VI_FUNC rscmwevs_ConfigureNetworkSector (ViSession instrumentHandle,
                                                   ViInt32 instance,
                                                   ViInt32 colorCode,
                                                   ViInt32 subnetMask,
                                                   ViInt32 countryCode);
ViStatus _VI_FUNC rscmwevs_ConfigureNetworkANSI41 (ViSession instrumentHandle,
                                                   ViInt32 instance,
                                                   ViString sectorID,
                                                   ViInt32 numberOfParityBits);
ViStatus _VI_FUNC rscmwevs_QueryNetworkANSI41OverallID (ViSession instrumentHandle,
                                                        ViInt32 instance,
                                                        ViInt32 bufferSize,
                                                        ViChar _VI_FAR overallID[]);
ViStatus _VI_FUNC rscmwevs_ConfigureNetworkManual (ViSession instrumentHandle,
                                                   ViInt32 instance,
                                                   ViString overallID);
ViStatus _VI_FUNC rscmwevs_ConfigureNetworkAccessProbesState
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 accessProbes);
ViStatus _VI_FUNC rscmwevs_ConfigureNetworkAccessProbesPower
             (ViSession instrumentHandle, ViInt32 instance, ViReal64 initialAdjust,
              ViReal64 openLoopAdjust, ViReal64 probeIncrement,
              ViInt32 probesPerSequence);
ViStatus _VI_FUNC rscmwevs_ConfigureNetworkAccessProbesLengths
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 preambleLength,
              ViInt32 accessCycleDuration, ViInt32 preambleLengthSlots);
ViStatus _VI_FUNC rscmwevs_ConfigureNetworkAccessProbesSectorAccessMaxRate
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 sectorAccessMaxRate);
ViStatus _VI_FUNC rscmwevs_ConfigureNetworkSecuritySettings
             (ViSession instrumentHandle, ViInt32 instance, ViString secretKey,
              ViString operatorVariantKey, ViString authenticationManagementField,
              ViString sequenceNumber);
ViStatus _VI_FUNC rscmwevs_ConfigureNeighborCell (ViSession instrumentHandle,
                                                  ViInt32 instance,
                                                  ViReal64 rxLevelMinLTE,
                                                  ViReal64 treshServing,
                                                  ViReal64 maxReselectionTimer);
ViStatus _VI_FUNC rscmwevs_ConfigureAllNeighborCellLowThreshold
             (ViSession instrumentHandle, ViInt32 instance, ViBoolean setForAll,
              ViInt32 values);
ViStatus _VI_FUNC rscmwevs_ConfigureNeighborCellLowThreshold
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 technology,
              ViInt32 values);
ViStatus _VI_FUNC rscmwevs_Configure1xEVDOandCDMANeighborCells
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 technology,
              ViInt32 cellNumber, ViBoolean enable, ViInt32 bandClass,
              ViInt32 channel, ViInt32 cellID);
ViStatus _VI_FUNC rscmwevs_ConfigureLTENeighborCells (ViSession instrumentHandle,
                                                      ViInt32 instance,
                                                      ViInt32 cellNumber,
                                                      ViBoolean enable,
                                                      ViInt32 bandClass,
                                                      ViInt32 channel);
ViStatus _VI_FUNC rscmwevs_ConfigureLTENeighborCellsTreshX
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 cellNumber,
              ViInt32 treshX);
ViStatus _VI_FUNC rscmwevs_ConfigureFadingSimulator (ViSession instrumentHandle,
                                                     ViInt32 instance,
                                                     ViBoolean enableFadingSimulator,
                                                     ViInt32 profile,
                                                     ViInt32 startSeed,
                                                     ViInt32 insertionLossMode,
                                                     ViReal64 insertionLoss);
ViStatus _VI_FUNC rscmwevs_ConfigureFadingSimulatorRestartMode
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 restartMode);
ViStatus _VI_FUNC rscmwevs_RestartFadingSimulator (ViSession instrumentHandle,
                                                   ViInt32 instance);
ViStatus _VI_FUNC rscmwevs_QueryFadingSimulatorClippedSamples
             (ViSession instrumentHandle, ViInt32 instance,
              ViReal64* clippedSamples);
ViStatus _VI_FUNC rscmwevs_QueryInternalFadingNoisePowerValues
             (ViSession instrumentHandle, ViInt32 instance,
              ViReal64* noisePower_SystemBW, ViReal64* noisePower_TotalBW,
              ViReal64* signalNoisePower);
ViStatus _VI_FUNC rscmwevs_ConfigureFadingModuleAWGN (ViSession instrumentHandle,
                                                      ViInt32 instance,
                                                      ViBoolean enableFadingModuleAWGN,
                                                      ViReal64 minNoiseSystemBWRatio,
                                                      ViReal64 signalToNoiseRatio);
ViStatus _VI_FUNC rscmwevs_QueryFadingModuleAWGNNoiseBandwidth
             (ViSession instrumentHandle, ViInt32 instance,
              ViReal64* noiseBandwidth);
ViStatus _VI_FUNC rscmwevs_ConfigureMessageMonitoring (ViSession instrumentHandle,
                                                       ViInt32 instance,
                                                       ViBoolean signalingToLogging,
                                                       ViInt32 IPv4Address);
ViStatus _VI_FUNC rscmwevs_ConfigureGeneratorState (ViSession instrumentHandle,
                                                    ViInt32 instance,
                                                    ViBoolean signalState);
ViStatus _VI_FUNC rscmwevs_QueryGeneratorState (ViSession instrumentHandle,
                                                ViInt32 instance,
                                                ViBoolean* mainState,
                                                ViInt32* syncState);
ViStatus _VI_FUNC rscmwevs_ConfigureConnectionState (ViSession instrumentHandle,
                                                     ViInt32 instance,
                                                     ViInt32 action);
ViStatus _VI_FUNC rscmwevs_QueryConnectionState (ViSession instrumentHandle,
                                                 ViInt32 instance,
                                                 ViInt32* connectionState);
ViStatus _VI_FUNC rscmwevs_QueryPacketDataState (ViSession instrumentHandle,
                                                 ViInt32 instance,
                                                 ViInt32* connectionState);
ViStatus _VI_FUNC rscmwevs_ConfigureTestApplication (ViSession instrumentHandle,
                                                     ViInt32 instance,
                                                     ViInt32 testApplicationStream,
                                                     ViInt32 testApplicationMode);
ViStatus _VI_FUNC rscmwevs_ConfigureTestApplicationPreferredPacketMode
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 testApplicationMode);
ViStatus _VI_FUNC rscmwevs_QueryTestApplicationInformation
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViChar _VI_FAR result[]);
ViStatus _VI_FUNC rscmwevs_QueryInterRAT (ViSession instrumentHandle,
                                          ViInt32 instance, ViBoolean* interRAT);
ViStatus _VI_FUNC rscmwevs_QueryRXPower (ViSession instrumentHandle,
                                         ViInt32 instance, ViInt32* RXPower);
ViStatus _VI_FUNC rscmwevs_QueryActiveApplication (ViSession instrumentHandle,
                                                   ViInt32 instance,
                                                   ViInt32 arraySize,
                                                   ViChar _VI_FAR application[]);
ViStatus _VI_FUNC rscmwevs_QueryNegotiatedMode (ViSession instrumentHandle,
                                                ViInt32 instance,
                                                ViInt32* negotiatedMode);
ViStatus _VI_FUNC rscmwevs_QueryPhysicalLayerSubtype (ViSession instrumentHandle,
                                                      ViInt32 instance,
                                                      ViInt32* physicalLayerSubtype);
ViStatus _VI_FUNC rscmwevs_QueryUATI (ViSession instrumentHandle, ViInt32 instance,
                                      ViChar _VI_FAR UATI[]);
ViStatus _VI_FUNC rscmwevs_ConfigureTestESN (ViSession instrumentHandle,
                                             ViInt32 instance, ViString ESN);
ViStatus _VI_FUNC rscmwevs_QueryESN (ViSession instrumentHandle, ViInt32 instance,
                                     ViChar _VI_FAR ESN[]);
ViStatus _VI_FUNC rscmwevs_ConfigureTestMEID (ViSession instrumentHandle,
                                              ViInt32 instance, ViString MEID);
ViStatus _VI_FUNC rscmwevs_QueryMEID (ViSession instrumentHandle, ViInt32 instance,
                                      ViChar _VI_FAR MEID[]);
ViStatus _VI_FUNC rscmwevs_QueryeHRPD (ViSession instrumentHandle, ViInt32 instance,
                                       ViBoolean* eHRPD);
ViStatus _VI_FUNC rscmwevs_QueryControlChannelCycle (ViSession instrumentHandle,
                                                     ViInt32 instance,
                                                     ViInt32* preferredCtrlChannelCycle);
ViStatus _VI_FUNC rscmwevs_QueryControlChannelStatus (ViSession instrumentHandle,
                                                      ViInt32 instance,
                                                      ViBoolean* preferredCtrlChannelStatus);
ViStatus _VI_FUNC rscmwevs_QueryCarrierStatus (ViSession instrumentHandle,
                                               ViInt32 instance,
                                               ViInt32* activeFwdLinkCarriers,
                                               ViInt32* activeRevLinkCarriers);
ViStatus _VI_FUNC rscmwevs_QueryLongCodeMask (ViSession instrumentHandle,
                                              ViInt32 instance,
                                              ViChar _VI_FAR longCodeMaskI[],
                                              ViChar _VI_FAR longCodeMaskQ[]);
ViStatus _VI_FUNC rscmwevs_QueryMaxReverseBandwidth (ViSession instrumentHandle,
                                                     ViInt32 instance,
                                                     ViReal64* maxReverseBandwidth);
ViStatus _VI_FUNC rscmwevs_QueryDataApplicationUnitIPAddress
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 IPVersion,
              ViInt32 bufferSize, ViChar _VI_FAR IPAddress[]);
ViStatus _VI_FUNC rscmwevs_ConfigureHandoffTarget (ViSession instrumentHandle,
                                                   ViInt32 instance,
                                                   ViInt32 destinationBandClass,
                                                   ViInt32 destinationChannel);
ViStatus _VI_FUNC rscmwevs_ConfigureHandoffCarrierTarget (ViSession instrumentHandle,
                                                          ViInt32 instance,
                                                          ViInt32 carrier,
                                                          ViInt32 carrierChannel,
                                                          ViReal64 RFChannelOffset);
ViStatus _VI_FUNC rscmwevs_QueryHandoffCarrierLinkFrequency
             (ViSession instrumentHandle, ViInt32 instance,
              ViReal64* forwardLinkFrequency, ViReal64* reverseLinkFrequency);
ViStatus _VI_FUNC rscmwevs_ConfigureHandoffCarrierPilotStates
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 pilot,
              ViBoolean activeOnAN, ViBoolean assignedToAT);
ViStatus _VI_FUNC rscmwevs_InitiateHandoff (ViSession instrumentHandle,
                                            ViInt32 instance);
ViStatus _VI_FUNC rscmwevs_QueryEventLogLastEntry (ViSession instrumentHandle,
                                                   ViInt32 instance,
                                                   ViInt32 timestampBufferSize,
                                                   ViInt32 eventBufferSize,
                                                   ViChar _VI_FAR timeStamp[],
                                                   ViInt32* category,
                                                   ViChar _VI_FAR event[]);
ViStatus _VI_FUNC rscmwevs_QueryEventLogAllEntries (ViSession instrumentHandle,
                                                    ViInt32 instance,
                                                    ViInt32 arraySize,
                                                    ViChar _VI_FAR entries[]);
ViStatus _VI_FUNC rscmwevs_ConfigureRXQualitySelectedCarrierForResults
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 selectedCarrier);
ViStatus _VI_FUNC rscmwevs_ConfigureRXQualityMeasurementResults
             (ViSession instrumentHandle, ViInt32 instance,
              ViBoolean forwardLinkPER, ViBoolean forwardLinkPerformance,
              ViBoolean reverseLinkPER, ViBoolean reverseLinkPerformance);

ViStatus _VI_FUNC rscmwevs_ConfigureRXQualityMeasurementTimeout (ViSession instrumentHandle,
                                                                 ViInt32 instance,
                                                                 ViInt32 measurement,
                                                                 ViReal64 timeout);

ViStatus _VI_FUNC rscmwevs_ConfigureRXQualityMeasurementRepetition
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 measurement,
              ViInt32 repetition, ViReal64 updatePeriod);
ViStatus _VI_FUNC rscmwevs_ConfigureRXQualityPERMeasurementStopCondition
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 PERLinkType,
              ViInt32 stopCondition);
ViStatus _VI_FUNC rscmwevs_ConfigureRXQualityForwardPERMeasurementSentPackets
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 maxTestPacketsSent);
ViStatus _VI_FUNC rscmwevs_ConfigureRXQualityReversePERMeasurementSentPackets
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 maxPacketsSent);
ViStatus _VI_FUNC rscmwevs_ConfigureRXQualityThroughputMeasurementFrames
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 linkType,
              ViInt32 maxFrames);
ViStatus _VI_FUNC rscmwevs_ConfigureRXQualityMeasurementLimits
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 PERLinkType,
              ViReal64 maxPERLimit, ViReal64 minConfidenceLevel);
ViStatus _VI_FUNC rscmwevs_ConfigureRXQualityCarrierEvaluation
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 limitEvaluation);
ViStatus _VI_FUNC rscmwevs_RXQualityMeasurementInit (ViSession instrumentHandle,
                                                     ViInt32 instance,
                                                     ViInt32 measurement);
ViStatus _VI_FUNC rscmwevs_RXQualityMeasurementAbort (ViSession instrumentHandle,
                                                      ViInt32 instance,
                                                      ViInt32 measurement);
ViStatus _VI_FUNC rscmwevs_RXQualityMeasurementStop (ViSession instrumentHandle,
                                                     ViInt32 instance,
                                                     ViInt32 measurement);
ViStatus _VI_FUNC rscmwevs_RXQualityMeasurementClear (ViSession instrumentHandle,
                                                      ViInt32 instance);
ViStatus _VI_FUNC rscmwevs_ConfigureRXQualityRemoteDisplay
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 display);
ViStatus _VI_FUNC rscmwevs_QueryRXQualityMeasurementStatus
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 measurement,
              ViInt32* mainState, ViInt32* syncState, ViInt32* resourceState);
ViStatus _VI_FUNC rscmwevs_ReadRXQualityForwardLinkPERResults
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViInt32* reliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevs_FetchRXQualityForwardLinkPERResults
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViInt32* reliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevs_QueryRXQualityForwardLinkPERLimitCheckResults
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViInt32* reliability, ViInt32 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevs_FetchRXQualityForwardLinkPERMeasurementStatus
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViChar _VI_FAR results[]);
ViStatus 
    _VI_FUNC rscmwevs_FetchRXQualityForwardLinkPERMeasurementCarrierStatus
        (ViSession instrumentHandle, ViInt32 instance, ViInt32* reliability,
         ViInt32* status);
ViStatus _VI_FUNC rscmwevs_ReadRXQualityForwardLinkPerformanceResults
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 packetSize,
              ViInt32 arraySize, ViInt32* reliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevs_FetchRXQualityForwardLinkPerformanceResults
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 packetSize,
              ViInt32 arraySize, ViInt32* reliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevs_QueryRXQualityForwardLinkPerformanceLimitCheckResults
        (ViSession instrumentHandle, ViInt32 instance, ViInt32 packetSize,
         ViInt32 arraySize, ViInt32* reliability, ViInt32 _VI_FAR results[],
         ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevs_FetchRXQualityForwardLinkPerformanceMeasurementStatus
        (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
         ViChar _VI_FAR results[]);
ViStatus 
    _VI_FUNC rscmwevs_FetchRXQualityForwardLinkPerformanceMeasurementCarrierStatus
        (ViSession instrumentHandle, ViInt32 instance, ViInt32* reliability,
         ViInt32* status);
ViStatus _VI_FUNC rscmwevs_ReadRXQualityReverseLinkPERResults
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 dataRate,
              ViInt32 arraySize, ViInt32* reliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevs_FetchRXQualityReverseLinkPERResults
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 dataRate,
              ViInt32 arraySize, ViInt32* reliability, ViReal64 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevs_QueryRXQualityReverseLinkPERLimitCheckResults
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 dataRate,
              ViInt32 arraySize, ViInt32* reliability, ViInt32 _VI_FAR results[],
              ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevs_FetchRXQualityReverseLinkPERMeasurementStatus
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViChar _VI_FAR results[]);
ViStatus 
    _VI_FUNC rscmwevs_FetchRXQualityReverseLinkPERMeasurementCarrierStatus
        (ViSession instrumentHandle, ViInt32 instance, ViInt32* reliability,
         ViInt32* status);
ViStatus _VI_FUNC rscmwevs_ReadRXQualityReverseLinkPerformanceResults
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 dataRate,
              ViInt32 arraySize, ViInt32* reliability, ViInt32* packetSize,
              ViReal64 _VI_FAR results[], ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevs_FetchRXQualityReverseLinkPerformanceResults
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 dataRate,
              ViInt32 arraySize, ViInt32* reliability, ViInt32* packetSize,
              ViReal64 _VI_FAR results[], ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevs_QueryRXQualityReverseLinkPerformanceLimitCheckResults
        (ViSession instrumentHandle, ViInt32 instance, ViInt32 dataRate,
         ViInt32 arraySize, ViInt32* reliability, ViInt32* packetSize,
         ViInt32 _VI_FAR results[], ViInt32* returnedValues);
ViStatus 
    _VI_FUNC rscmwevs_FetchRXQualityReverseLinkPerformanceMeasurementStatus
        (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
         ViChar _VI_FAR results[]);
ViStatus 
    _VI_FUNC rscmwevs_FetchRXQualityReverseLinkPerformanceMeasurementCarrierStatus
        (ViSession instrumentHandle, ViInt32 instance, ViInt32* reliability,
         ViInt32* status);
ViStatus _VI_FUNC rscmwevs_ConfigureRXQualityDataRLPTableResultsState
             (ViSession instrumentHandle, ViInt32 instance,
              ViBoolean RLPAndIPStatistics);
ViStatus _VI_FUNC rscmwevs_QueryRXQualityDataRLPTableResults
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 resultType,
              ViInt32* RX, ViInt32* RXTotal, ViInt32* TX, ViInt32* TXTotal);
ViStatus _VI_FUNC rscmwevs_QueryRXQualityDataIPStatisticTableResults
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 resultType,
              ViInt32* RX, ViInt32* TX);
ViStatus _VI_FUNC rscmwevs_QueryRXQualityDataIPStatisticStatus
             (ViSession instrumentHandle, ViInt32 instance, ViInt32* status);
ViStatus _VI_FUNC rscmwevs_SetAttributeViInt32 (ViSession instrumentHandle,
                                                ViString repeatedCapabilityName,
                                                ViUInt32 attributeID,
                                                ViInt32 attributeValue);
ViStatus _VI_FUNC rscmwevs_SetAttributeViReal64 (ViSession instrumentHandle,
                                                 ViString repeatedCapabilityName,
                                                 ViUInt32 attributeID,
                                                 ViReal64 attributeValue);
ViStatus _VI_FUNC rscmwevs_SetAttributeViString (ViSession instrumentHandle,
                                                 ViString repeatedCapabilityName,
                                                 ViUInt32 attributeID,
                                                 ViString attributeValue);
ViStatus _VI_FUNC rscmwevs_SetAttributeViBoolean (ViSession instrumentHandle,
                                                  ViString repeatedCapabilityName,
                                                  ViUInt32 attributeID,
                                                  ViBoolean attributeValue);
ViStatus _VI_FUNC rscmwevs_SetAttributeViSession (ViSession instrumentHandle,
                                                  ViString repeatedCapabilityName,
                                                  ViUInt32 attributeID,
                                                  ViSession attributeValue);
ViStatus _VI_FUNC rscmwevs_GetAttributeRepeatedCapabilityIds
             (ViSession instrumentHandle, ViUInt32 attributeID, ViInt32 bufferSize,
              ViChar _VI_FAR repeatedCapabilityId_s[]);
ViStatus _VI_FUNC rscmwevs_GetAttributeRepeatedCapabilityIdNames
             (ViSession instrumentHandle, ViUInt32 attributeID,
              ViString repeatedCapabilityId, ViInt32 bufferSize,
              ViChar _VI_FAR repeatedCapabilityIdName_s[]);
ViStatus _VI_FUNC rscmwevs_GetAttributeViInt32 (ViSession instrumentHandle,
                                                ViString repeatedCapabilityName,
                                                ViUInt32 attributeID,
                                                ViInt32* attributeValue);
ViStatus _VI_FUNC rscmwevs_GetAttributeViReal64 (ViSession instrumentHandle,
                                                 ViString repeatedCapabilityName,
                                                 ViUInt32 attributeID,
                                                 ViReal64* attributeValue);
ViStatus _VI_FUNC rscmwevs_GetAttributeViString (ViSession instrumentHandle,
                                                 ViString repeatedCapabilityName,
                                                 ViUInt32 attributeID,
                                                 ViInt32 bufferSize,
                                                 ViChar _VI_FAR attributeValue[]);
ViStatus _VI_FUNC rscmwevs_GetAttributeViBoolean (ViSession instrumentHandle,
                                                  ViString repeatedCapabilityName,
                                                  ViUInt32 attributeID,
                                                  ViBoolean* attributeValue);
ViStatus _VI_FUNC rscmwevs_GetAttributeViSession (ViSession instrumentHandle,
                                                  ViString repeatedCapabilityName,
                                                  ViUInt32 attributeID,
                                                  ViSession* attributeValue);
ViStatus _VI_FUNC rscmwevs_CheckAttributeViInt32 (ViSession instrumentHandle,
                                                  ViString repeatedCapabilityName,
                                                  ViUInt32 attributeID,
                                                  ViInt32 attributeValue);
ViStatus _VI_FUNC rscmwevs_CheckAttributeViReal64 (ViSession instrumentHandle,
                                                   ViString repeatedCapabilityName,
                                                   ViUInt32 attributeID,
                                                   ViReal64 attributeValue);
ViStatus _VI_FUNC rscmwevs_CheckAttributeViString (ViSession instrumentHandle,
                                                   ViString repeatedCapabilityName,
                                                   ViUInt32 attributeID,
                                                   ViString attributeValue);
ViStatus _VI_FUNC rscmwevs_CheckAttributeViBoolean (ViSession instrumentHandle,
                                                    ViString repeatedCapabilityName,
                                                    ViUInt32 attributeID,
                                                    ViBoolean attributeValue);
ViStatus _VI_FUNC rscmwevs_CheckAttributeViSession (ViSession instrumentHandle,
                                                    ViString repeatedCapabilityName,
                                                    ViUInt32 attributeID,
                                                    ViSession attributeValue);
ViStatus _VI_FUNC rscmwevs_reset (ViSession instrumentHandle);
ViStatus _VI_FUNC rscmwevs_self_test (ViSession instrumentHandle,
                                      ViInt16* selfTestResult,
                                      ViChar _VI_FAR selfTestMessage[]);
ViStatus _VI_FUNC rscmwevs_revision_query (ViSession instrumentHandle,
                                           ViChar _VI_FAR instrumentDriverRevision[],
                                           ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC rscmwevs_SystemVersion (ViSession instrumentHandle,
                                          ViInt32 length,
                                          ViChar _VI_FAR systemVersion[]);
ViStatus _VI_FUNC rscmwevs_error_query (ViSession instrumentHandle,
                                        ViInt32* errorCode,
                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rscmwevs_ErrorList (ViSession instrumentHandle,
                                      ViInt32 bufferSize, ViChar _VI_FAR errors[]);
ViStatus _VI_FUNC rscmwevs_error_message (ViSession instrumentHandle,
                                          ViStatus errorCode,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rscmwevs_ReliabilityIndicator (ViSession instrumentHandle,
                                                 ViInt32 reliabilityCode,
                                                 ViChar _VI_FAR reliabilityMessage[]);
ViStatus _VI_FUNC rscmwevs_Preset (ViSession instrumentHandle);
ViStatus _VI_FUNC rscmwevs_ClearStatus (ViSession instrumentHandle);
ViStatus _VI_FUNC rscmwevs_IDQueryResponse (ViSession instrumentHandle,
                                            ViInt32 bufferSize,
                                            ViChar _VI_FAR IDQueryResponse[],
                                            ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwevs_ProcessAllPreviousCommands (ViSession instrumentHandle);
ViStatus _VI_FUNC rscmwevs_QueryOPC (ViSession instrumentHandle, ViInt32* OPC);
ViStatus _VI_FUNC rscmwevs_SetOPCTimeout (ViSession instrumentHandle,
                                          ViUInt32 OPCTimeout);
ViStatus _VI_FUNC rscmwevs_GetOPCTimeout (ViSession instrumentHandle,
                                          ViUInt32* OPCTimeout);
ViStatus _VI_FUNC rscmwevs_SetVISATimeout (ViSession instrumentHandle,
                                           ViUInt32 VISATimeout);
ViStatus _VI_FUNC rscmwevs_GetVISATimeout (ViSession instrumentHandle,
                                           ViUInt32* VISATimeout);
ViStatus _VI_FUNC rscmwevs_ConfigureErrorChecking (ViSession instrumentHandle,
                                                   ViBoolean optionChecking,
                                                   ViBoolean rangeChecking,
                                                   ViBoolean statusChecking);

ViStatus _VI_FUNC rscmwevs_GetError (ViSession instrumentHandle, ViStatus* code,
                                     ViInt32 bufferSize,
                                     ViChar _VI_FAR description[]);
ViStatus _VI_FUNC rscmwevs_ClearError (ViSession instrumentHandle);
ViStatus _VI_FUNC rscmwevs_WriteFromFileToInstrument (ViSession instrumentHandle,
                                                      ViString source,
                                                      ViString destination);
ViStatus _VI_FUNC rscmwevs_ReadToFileFromInstrument (ViSession instrumentHandle,
                                                     ViString source,
                                                     ViString destination);
ViStatus _VI_FUNC rscmwevs_WriteInstrData (ViSession instrumentHandle,
                                           ViString writeBuffer);
ViStatus _VI_FUNC rscmwevs_ReadInstrData (ViSession instrumentHandle,
                                          ViInt32 numberOfBytesToRead,
                                          ViChar _VI_FAR readBuffer[],
                                          ViUInt32* numBytesRead);
ViStatus _VI_FUNC rscmwevs_QueryViBoolean (ViSession instrumentHandle,
                                           ViString command, ViBoolean* value);
ViStatus _VI_FUNC rscmwevs_QueryViInt32 (ViSession instrumentHandle,
                                         ViString command, ViInt32* value);
ViStatus _VI_FUNC rscmwevs_QueryViReal64 (ViSession instrumentHandle,
                                          ViString command, ViReal64* value);
ViStatus _VI_FUNC rscmwevs_QueryViString (ViSession instrumentHandle,
                                          ViString command, ViInt32 bufferSize,
                                          ViChar _VI_FAR value[]);
ViStatus _VI_FUNC rscmwevs_close (ViSession instrumentHandle);

/****************************************************************************
 *------------------------ Error And Completion Codes ----------------------*
 ****************************************************************************/

#define RSCMWEVS_WARN_MEASURE_UNCALIBRATED    (RS_CLASS_WARN_BASE + 0x0001L)
#define RSCMWEVS_WARN_OVER_RANGE              (RS_CLASS_WARN_BASE + 0x0002L)

#define RSCMWEVS_ERROR_INCORRECT_STATE        (RS_CLASS_ERROR_BASE + 0x0003L)
#define RSCMWEVS_ERROR_INCORRECT_RESPONSE     (RS_CLASS_ERROR_BASE + 0x0002L)
#define RSCMWEVS_ERROR_MAX_TIME_EXCEEDED      (RS_CLASS_ERROR_BASE + 0x0001L)
#define RSCMWEVS_ERROR_RELIABILITY_INDICATOR  (RS_SPECIFIC_ERROR_BASE + 0x0004L) 

#define RSCMWEVS_WARNMSG_MEASURE_UNCALIBRATED "Uncalibrated measurement"
#define RSCMWEVS_WARNMSG_OVER_RANGE           "Measurement overrange"

#define RSCMWEVS_ERRMSG_INCORRECT_STATE       "Instrument in incorrect state"
#define RSCMWEVS_ERRMSG_INCORRECT_RESPONSE    "Response incorrect; report problem to R&S support!"
#define RSCMWEVS_ERRMSG_MAX_TIME_EXCEEDED     "Max Time Exceeded"
#define RSCMWEVS_ERRMSG_RELIABILITY_INDICATOR "Reliability Indicator error"

#define RSCMWEVS_ERROR_CODES_AND_MSGS \
    {RSCMWEVS_ERROR_INCORRECT_STATE,       RSCMWEVS_ERRMSG_INCORRECT_STATE},\
    {RSCMWEVS_ERROR_INCORRECT_RESPONSE,    RSCMWEVS_ERRMSG_INCORRECT_RESPONSE},\
    {RSCMWEVS_ERROR_MAX_TIME_EXCEEDED,     RSCMWEVS_ERRMSG_MAX_TIME_EXCEEDED},\
    {RSCMWEVS_ERROR_RELIABILITY_INDICATOR, RSCMWEVS_ERRMSG_RELIABILITY_INDICATOR}


/****************************************************************************
 *---------------------------- End Include File ----------------------------*
 ****************************************************************************/

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif
#endif /* __RSCMWEVS_HEADER */
